pub struct CallTreeNode {
pub id: Option<i64>,
pub hash: u32,
pub begin: i64,
pub end: i64,
pub children: Vec<CallTreeNode>,
}Expand description
A node in a call tree, representing a single scope instance.
Fields
id: Option<i64>The unique identifier of the scope instance.
hash: u32The hash of the scope description.
begin: i64The start time of the scope instance in nanoseconds.
end: i64The end time of the scope instance in nanoseconds.
children: Vec<CallTreeNode>The children of this node in the call tree.