delete_empty_streams_batch

Function delete_empty_streams_batch 

pub fn delete_empty_streams_batch(
    lake: &DataLakeConnection,
    expiration: DateTime<Utc>,
) -> impl Future<Output = Result<bool, Error>>
Deletes a batch of empty streams from the data lake. Returns true if there are more streams to delete, false otherwise.