pub fn make_count_from_histogram_udf() -> ScalarUDFExpand description
Creates a user-defined function to extract the count from a histogram.
pub fn make_count_from_histogram_udf() -> ScalarUDFCreates a user-defined function to extract the count from a histogram.