pub fn make_sum_from_histogram_udf() -> ScalarUDFExpand description
Creates a user-defined function to extract the sum from a histogram.
pub fn make_sum_from_histogram_udf() -> ScalarUDFCreates a user-defined function to extract the sum from a histogram.