pub struct HistogramAccumulator { /* private fields */ }Expand description
An accumulator for computing histograms.
Implementations
Sourceimpl HistogramAccumulator
impl HistogramAccumulator
pub fn new(start: f64, end: f64, nb_bins: usize) -> HistogramAccumulator
pub fn new_non_configured() -> HistogramAccumulator
Sourcepub fn configure(
&mut self,
histo_array: &HistogramArray,
) -> Result<(), DataFusionError>
pub fn configure( &mut self, histo_array: &HistogramArray, ) -> Result<(), DataFusionError>
if not configured, will take the first instance of the array as a template if already configured or if the array is empty, will do nothing
pub fn update_batch_scalars( &mut self, scalars: &PrimitiveArray<Float64Type>, ) -> Result<(), DataFusionError>
pub fn merge_histograms( &mut self, histo_array: &HistogramArray, ) -> Result<(), DataFusionError>