pub fn make_jsonb_array_length_udf() -> ScalarUDFExpand description
Creates a user-defined function to get the length of a JSONB array.
pub fn make_jsonb_array_length_udf() -> ScalarUDFCreates a user-defined function to get the length of a JSONB array.