pub fn list_view_sets(
view_factory: &ViewFactory,
) -> Result<Vec<ViewSetInfo>, Error>Expand description
List all view sets with their current schema information from the ViewFactory.
pub fn list_view_sets(
view_factory: &ViewFactory,
) -> Result<Vec<ViewSetInfo>, Error>List all view sets with their current schema information from the ViewFactory.