pub struct ImagesViewMaker {}Trait Implementations
Sourceimpl Debug for ImagesViewMaker
impl Debug for ImagesViewMaker
Sourceimpl ViewMaker for ImagesViewMaker
impl ViewMaker for ImagesViewMaker
Sourcefn make_view(&self, view_instance_id: &str) -> Result<Arc<dyn View>, Error>
fn make_view(&self, view_instance_id: &str) -> Result<Arc<dyn View>, Error>
Creates a new view with the given instance ID.
Sourcefn get_schema_hash(&self) -> Vec<u8> ⓘ
fn get_schema_hash(&self) -> Vec<u8> ⓘ
Returns the schema hash for views created by this maker.
Sourcefn get_schema(&self) -> Arc<Schema> ⓘ
fn get_schema(&self) -> Arc<Schema> ⓘ
Returns the schema for views created by this maker.