pub fn is_jit_partition_up_to_date(
pool: &Pool<Postgres>,
view_meta: ViewMetadata,
spec: &SourceDataBlocksInMemory,
) -> impl Future<Output = Result<bool, Error>>Expand description
is_jit_partition_up_to_date compares a partition spec with the partitions that exist to know if it should be recreated Checks if a JIT partition is up to date.