pub struct Partition {
pub view_metadata: ViewMetadata,
pub insert_time_range: TimeRange,
pub event_time_range: Option<TimeRange>,
pub updated: DateTime<Utc>,
pub file_path: Option<String>,
pub file_size: i64,
pub source_data_hash: Vec<u8>,
pub num_rows: i64,
}Expand description
Partition metadata (without embedded file_metadata for performance) Use load_partition_metadata() to load metadata on-demand when needed
Fields
view_metadata: ViewMetadataMetadata about the view this partition belongs to.
insert_time_range: TimeRangeThe insert time range for this partition.
event_time_range: Option<TimeRange>The event time range for this partition. None for empty partitions.
updated: DateTime<Utc>The last time this partition was updated.
file_path: Option<String>The path to the Parquet file for this partition. None for empty partitions.
file_size: i64The size of the Parquet file in bytes. 0 for empty partitions.
source_data_hash: Vec<u8>A hash of the source data that generated this partition.
num_rows: i64The number of rows in this partition. 0 for empty partitions.
Implementations
Sourceimpl Partition
impl Partition
Sourcepub fn min_event_time(&self) -> Option<DateTime<Utc>>
pub fn min_event_time(&self) -> Option<DateTime<Utc>>
Returns the min event time, if this partition has data.
Sourcepub fn max_event_time(&self) -> Option<DateTime<Utc>>
pub fn max_event_time(&self) -> Option<DateTime<Utc>>
Returns the max event time, if this partition has data.
Sourcepub fn begin_insert_time(&self) -> DateTime<Utc>
pub fn begin_insert_time(&self) -> DateTime<Utc>
Returns the beginning of the insert time range.
Sourcepub fn end_insert_time(&self) -> DateTime<Utc>
pub fn end_insert_time(&self) -> DateTime<Utc>
Returns the end of the insert time range.
Sourcepub fn validate(&self) -> Result<(), Error>
pub fn validate(&self) -> Result<(), Error>
Validates partition invariants. Returns error if partition is inconsistent.
Invariants:
- Non-empty partitions (num_rows > 0) MUST have both event_time_range and file_path
- Empty partitions (num_rows = 0) MUST NOT have event_time_range or file_path
- num_rows must not be negative