pub struct PartitionCache {
pub partitions: Vec<Partition>,
/* private fields */
}Expand description
PartitionCache allows to query partitions based on the insert_time range
Fields
partitions: Vec<Partition>Implementations
Sourceimpl PartitionCache
impl PartitionCache
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
Sourcepub fn fetch_overlapping_insert_range(
pool: &Pool<Postgres>,
insert_range: TimeRange,
) -> impl Future<Output = Result<PartitionCache, Error>>
pub fn fetch_overlapping_insert_range( pool: &Pool<Postgres>, insert_range: TimeRange, ) -> impl Future<Output = Result<PartitionCache, Error>>
fetches the partitions of all views matching the specified insert range
Sourcepub fn fetch_overlapping_insert_range_for_view(
pool: &Pool<Postgres>,
view_set_name: Arc<String>,
view_instance_id: Arc<String>,
insert_range: TimeRange,
) -> impl Future<Output = Result<PartitionCache, Error>>
pub fn fetch_overlapping_insert_range_for_view( pool: &Pool<Postgres>, view_set_name: Arc<String>, view_instance_id: Arc<String>, insert_range: TimeRange, ) -> impl Future<Output = Result<PartitionCache, Error>>
fetches the partitions of a single view instance matching the specified insert range
pub fn filter( &self, view_set_name: &str, view_instance_id: &str, file_schema_hash: &[u8], insert_range: TimeRange, ) -> PartitionCache
pub fn filter_insert_range(&self, insert_range: TimeRange) -> PartitionCache
pub fn filter_inside_range( &self, view_set_name: &str, view_instance_id: &str, insert_range: TimeRange, ) -> PartitionCache