pub fn register_extension_functions(ctx: &SessionContext)Expand description
register functions that are not depended on the lakehouse architecture
pub fn register_extension_functions(ctx: &SessionContext)register functions that are not depended on the lakehouse architecture