pub struct RetirePartitionByMetadata { /* private fields */ }Expand description
A scalar UDF that retires a single partition by its metadata.
This function retires partitions by their metadata identifiers (view_set_name, view_instance_id, begin_insert_time, end_insert_time). This works for both empty partitions (file_path=NULL) and non-empty partitions.
This is the preferred method for retiring partitions as it uses the partition’s natural identifiers rather than relying on file paths.
Implementations
Sourceimpl RetirePartitionByMetadata
impl RetirePartitionByMetadata
pub fn new(lake: Arc<DataLakeConnection>) -> RetirePartitionByMetadata