pub struct SqlBatchView { /* private fields */ }Expand description
SQL-defined view updated in batch
Implementations
Sourceimpl SqlBatchView
impl SqlBatchView
Sourcepub async fn new(
runtime: Arc<RuntimeEnv>,
view_set_name: Arc<String>,
min_event_time_column: Arc<String>,
max_event_time_column: Arc<String>,
count_src_query: Arc<String>,
extract_query: Arc<String>,
merge_partitions_query: Arc<String>,
lake: Arc<DataLakeConnection>,
view_factory: Arc<ViewFactory>,
session_configurator: Arc<dyn SessionConfigurator>,
update_group: Option<i32>,
max_partition_delta_from_source: TimeDelta,
max_partition_delta_from_merge: TimeDelta,
merger_maker: Option<&(dyn Fn(Arc<RuntimeEnv>, Arc<Schema>) -> Arc<dyn PartitionMerger> + Send + Sync + 'static)>,
) -> Result<SqlBatchView, Error>
pub async fn new( runtime: Arc<RuntimeEnv>, view_set_name: Arc<String>, min_event_time_column: Arc<String>, max_event_time_column: Arc<String>, count_src_query: Arc<String>, extract_query: Arc<String>, merge_partitions_query: Arc<String>, lake: Arc<DataLakeConnection>, view_factory: Arc<ViewFactory>, session_configurator: Arc<dyn SessionConfigurator>, update_group: Option<i32>, max_partition_delta_from_source: TimeDelta, max_partition_delta_from_merge: TimeDelta, merger_maker: Option<&(dyn Fn(Arc<RuntimeEnv>, Arc<Schema>) -> Arc<dyn PartitionMerger> + Send + Sync + 'static)>, ) -> Result<SqlBatchView, Error>
Arguments
runtime- datafusion runtimeview_set_name- name of the tablemin_event_time_column- min(column) should result in the first timestamp in a dataframemax_event_time_column- max(column) should result in the last timestamp in a dataframecount_src_query- used to count the rows of the underlying data to know if a cached partition is up to dateextract_query- used to extract the source data into a cached partitionmerge_partitions_query- used to merge multiple partitions into a single one (and user queries which are one multiple partitions by default)lake- data lakeview_factory- all views accessible to thecount_src_querysession_configurator- configurator for registering custom tables (e.g., JSON files)update_group- tells the daemon which view should be materialized and in what order