extract_properties_from_properties_column

Function extract_properties_from_properties_column 

pub fn extract_properties_from_properties_column(
    column: &dyn PropertiesColumnAccessor,
    row_index: usize,
) -> Result<HashMap<String, String>, Error>
Extract properties from a properties column accessor at the given row index. Returns an empty HashMap if the column value is null, otherwise deserializes the JSONB.