pub trait ColumnReader {
// Required methods
fn extract_column_from_row(
&self,
row: &PgRow,
struct_builder: &mut StructBuilder,
) -> Result<(), Error>;
fn field(&self) -> Field;
}Expand description
A trait for reading a column from a database row and writing it to an Arrow StructBuilder.