make_time_converter_from_latest_timing

Function make_time_converter_from_latest_timing 

pub fn make_time_converter_from_latest_timing(
    process: &ProcessMetadata,
    last_block_end_ticks: i64,
    last_block_end_time: DateTime<Utc>,
) -> Result<ConvertTicks, Error>
Creates a ConvertTicks using the latest timing information from the process. This should be used instead of per-block timing to ensure consistent tick conversion across all blocks from the same process.