parse_key_ring

Function parse_key_ring 

pub fn parse_key_ring(json: &str) -> Result<HashMap<Key, String>, Error>
Parses a JSON string into a KeyRing.

The JSON string is expected to be an array of objects, each with a name and key field.