pub struct Client { /* private fields */ }Expand description
Micromegas FlightSQL client
Implementations
Sourceimpl Client
impl Client
Sourcepub fn new(channel: Channel) -> Self
pub fn new(channel: Channel) -> Self
Creates a new client from a grpc channel
Arguments
channel- The gRPC channel to use for communication.
Sourcepub fn inner_mut(&mut self) -> &mut FlightSqlServiceClient<Channel>
pub fn inner_mut(&mut self) -> &mut FlightSqlServiceClient<Channel>
Returns a mutable reference to the inner FlightSqlServiceClient.
This allows direct access to the underlying FlightSQL client for advanced operations.
Sourcepub async fn query(
&mut self,
sql: String,
query_range: Option<TimeRange>,
) -> Result<Vec<RecordBatch>>
pub async fn query( &mut self, sql: String, query_range: Option<TimeRange>, ) -> Result<Vec<RecordBatch>>
Executes a SQL query and returns the results as a vector of RecordBatch.
Arguments
sql- The SQL query string to execute.query_range- An optionalTimeRangeto filter the query results by time.
Sourcepub async fn query_stream(
&mut self,
sql: String,
query_range: Option<TimeRange>,
) -> Result<FlightRecordBatchStream>
pub async fn query_stream( &mut self, sql: String, query_range: Option<TimeRange>, ) -> Result<FlightRecordBatchStream>
Executes a SQL query and returns the results as a FlightRecordBatchStream.
This function is useful for processing large query results incrementally.
Arguments
sql- The SQL query string to execute.query_range- An optionalTimeRangeto filter the query results by time.
Sourcepub async fn prepare_statement(
&mut self,
sql: String,
) -> Result<PreparedStatement>
pub async fn prepare_statement( &mut self, sql: String, ) -> Result<PreparedStatement>
Prepares a SQL statement and returns a PreparedStatement.
This function allows to compute the schema of a query without actually executing it.
Arguments
sql- The SQL query string to prepare.