budget_map_to_properties

Function budget_map_to_properties 

pub fn budget_map_to_properties(
    span_name_to_budget: &HashMap<String, String>,
) -> Result<ScalarValue>
Converts a map of span names to budget categories into a ScalarValue representing a list of properties.

This function is used to pass the budget mapping to DataFusion as a scalar value.