gen_frame_batches

Function gen_frame_batches 

pub fn gen_frame_batches(
    frames_record_batches: Vec<RecordBatch>,
) -> BoxStream<'static, Result<RecordBatch>>
Generates a stream of record batches from a vector of record batches.

This function takes a Vec<RecordBatch> and converts it into a BoxStream, optionally slicing large record batches into smaller ones.