get_main_thread_stream_id

Function get_main_thread_stream_id 

pub async fn get_main_thread_stream_id(
    client: &mut Client,
    process_id: &str,
    main_thread_name: &str,
    query_range: TimeRange,
) -> Result<String>
Retrieves the stream ID of the main thread for a given process.

This function queries the blocks table to find the stream_id associated with the main thread of a given process within a specified time range.