format_perfetto_trace

Function format_perfetto_trace 

pub async fn format_perfetto_trace(
    client: &mut Client,
    process_id: &str,
    query_range: TimeRange,
    span_types: SpanTypes,
) -> Result<Vec<u8>>
Formats a Perfetto trace with configurable span types using server-side perfetto_trace_chunks function.

This function queries the FlightSQL server using the perfetto_trace_chunks table function which generates Perfetto trace data server-side and streams it back as binary chunks.

Arguments

  • span_types - Types of spans to include: Thread, Async, or Both