#[repr(i32)]pub enum CaptureResultStatus {
StatusUnspecified = 0,
StatusOk = 1,
StatusEarlyMetadataError = 2,
StatusFinalMetadataError = 3,
StatusBufferError = 4,
StatusFlushError = 5,
}Expand description
The error status, if any, reported to the camera framework. Any status other than STATUS_OK indicates a dropped frame. Next Enum: 6
Variants
StatusUnspecified = 0
StatusOk = 1
StatusEarlyMetadataError = 2
Early metadata was returned to the camera framework with an error.
StatusFinalMetadataError = 3
Final metadata was returned to the camera framework with an error.
StatusBufferError = 4
One or more buffers were returned to the camera framework with an error.
StatusFlushError = 5
The frame was dropped as a result of a flush operation.
Implementations
Sourceimpl CaptureResultStatus
impl CaptureResultStatus
Sourcepub fn from_i32(value: i32) -> Option<CaptureResultStatus>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<CaptureResultStatus>
Converts an i32 to a CaptureResultStatus, or None if value is not a valid variant.
Sourceimpl CaptureResultStatus
impl CaptureResultStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<CaptureResultStatus>
pub fn from_str_name(value: &str) -> Option<CaptureResultStatus>
Creates an enum from field names used in the ProtoBuf definition.