pub struct CameraNodeProcessingDetails {
pub node_id: Option<i64>,
pub start_processing_ns: Option<i64>,
pub end_processing_ns: Option<i64>,
pub scheduling_latency_ns: Option<i64>,
}Expand description
A profiling event corresponding to a single node processing within the camera pipeline. Intuitively this corresponds to a single stage of processing to produce a camera frame. Next ID: 6
Fields
node_id: Option<i64>start_processing_ns: Option<i64>The timestamp at which node processing begins to run.
end_processing_ns: Option<i64>The timestamp at which node processing finishes running.
scheduling_latency_ns: Option<i64>The delay between inputs becoming ready and the node actually beginning to run.
Implementations
Sourceimpl CameraNodeProcessingDetails
impl CameraNodeProcessingDetails
Sourcepub fn node_id(&self) -> i64
pub fn node_id(&self) -> i64
Returns the value of node_id, or the default value if node_id is unset.
Sourcepub fn start_processing_ns(&self) -> i64
pub fn start_processing_ns(&self) -> i64
Returns the value of start_processing_ns, or the default value if start_processing_ns is unset.
Sourcepub fn end_processing_ns(&self) -> i64
pub fn end_processing_ns(&self) -> i64
Returns the value of end_processing_ns, or the default value if end_processing_ns is unset.
Sourcepub fn scheduling_latency_ns(&self) -> i64
pub fn scheduling_latency_ns(&self) -> i64
Returns the value of scheduling_latency_ns, or the default value if scheduling_latency_ns is unset.