pub struct CameraEdge {
pub output_node_id: Option<i64>,
pub output_id: Option<i64>,
pub input_node_id: Option<i64>,
pub input_id: Option<i64>,
pub vendor_data_version: Option<i32>,
pub vendor_data: Option<Vec<u8>>,
}Expand description
An adjacency list describing connections between CameraNodes, mapping nodes and their outputs to other nodes that consume them as inputs.
Fields
output_node_id: Option<i64>The pair of IDs identifying the node and output connected by this edge.
output_id: Option<i64>input_node_id: Option<i64>The pair of IDs identifying the node and input connected by this edge.
input_id: Option<i64>vendor_data_version: Option<i32>These fields capture vendor-specific additions to this proto message. In
practice vendor_data typically contains a serialized message of the
vendor’s design, and vendor_data_version is incremented each time there
is a backwards incompatible change made to the message.
vendor_data: Option<Vec<u8>>Implementations
Sourceimpl CameraEdge
impl CameraEdge
Sourcepub fn output_node_id(&self) -> i64
pub fn output_node_id(&self) -> i64
Returns the value of output_node_id, or the default value if output_node_id is unset.
Sourcepub fn output_id(&self) -> i64
pub fn output_id(&self) -> i64
Returns the value of output_id, or the default value if output_id is unset.
Sourcepub fn input_node_id(&self) -> i64
pub fn input_node_id(&self) -> i64
Returns the value of input_node_id, or the default value if input_node_id is unset.
Sourcepub fn input_id(&self) -> i64
pub fn input_id(&self) -> i64
Returns the value of input_id, or the default value if input_id is unset.
Sourcepub fn vendor_data_version(&self) -> i32
pub fn vendor_data_version(&self) -> i32
Returns the value of vendor_data_version, or the default value if vendor_data_version is unset.
Sourcepub fn vendor_data(&self) -> &[u8] ⓘ
pub fn vendor_data(&self) -> &[u8] ⓘ
Returns the value of vendor_data, or the default value if vendor_data is unset.