#[repr(i32)]pub enum TraceLevel {
None = 0,
Redacted = 1,
Complete = 2,
}Expand description
The level of tracing that should be applied to an event.
Variants
None = 0
Do not trace the input event.
Redacted = 1
Trace the event as a redacted event, where certain sensitive fields are omitted from the trace, including the coordinates of pointer events and the key/scan codes of key events.
Complete = 2
Trace the complete event.
Implementations
Sourceimpl TraceLevel
impl TraceLevel
Sourceimpl TraceLevel
impl TraceLevel
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<TraceLevel>
pub fn from_str_name(value: &str) -> Option<TraceLevel>
Creates an enum from field names used in the ProtoBuf definition.