pub struct NamedRule {
pub event_type: Option<i32>,
pub content_trigger_name_hash: Option<u64>,
}Expand description
Configuration of named trigger.
Fields
event_type: Option<i32>content_trigger_name_hash: Option<u64>If |event_type| is CONTENT_TRIGGER, then this stores the hash of the content-trigger that actually fired.
Implementations
Sourceimpl NamedRule
impl NamedRule
Sourcepub fn event_type(&self) -> EventType
pub fn event_type(&self) -> EventType
Returns the enum value of event_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_event_type(&mut self, value: EventType)
pub fn set_event_type(&mut self, value: EventType)
Sets event_type to the provided enum value.
Sourcepub fn content_trigger_name_hash(&self) -> u64
pub fn content_trigger_name_hash(&self) -> u64
Returns the value of content_trigger_name_hash, or the default value if content_trigger_name_hash is unset.