#[repr(i32)]pub enum BeginFrameArgsType {
Unspecified = 0,
Invalid = 1,
Normal = 2,
Missed = 3,
}Expand description
JSON format has a “type” field that was always just “BeginFrameArgs” we drop this in the proto representation, and instead make the JSON format “subtype” field become the type field.
Variants
Implementations
Sourceimpl BeginFrameArgsType
impl BeginFrameArgsType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<BeginFrameArgsType>
pub fn from_str_name(value: &str) -> Option<BeginFrameArgsType>
Creates an enum from field names used in the ProtoBuf definition.