#[repr(i32)]pub enum OldThreadState {
Initialized = 0,
Ready = 1,
Running = 2,
Standby = 3,
Terminated = 4,
Waiting = 5,
Transition = 6,
DeferredReady = 7,
}Expand description
State of the previous thread. The ordering is important as based on the OldThreadState definition from the link above. The following are the possible state values:
Variants
Initialized = 0
Ready = 1
Running = 2
Standby = 3
Terminated = 4
Waiting = 5
Transition = 6
DeferredReady = 7
Implementations
Sourceimpl OldThreadState
impl OldThreadState
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<OldThreadState>
pub fn from_str_name(value: &str) -> Option<OldThreadState>
Creates an enum from field names used in the ProtoBuf definition.