#[repr(i32)]pub enum OldThreadWaitMode {
KernelMode = 0,
UserMode = 1,
}Expand description
Wait mode for the previous thread. The ordering is important as based on the OldThreadWaitMode definition from the link above. The following are the possible values:
Variants
Implementations
Sourceimpl OldThreadWaitMode
impl OldThreadWaitMode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<OldThreadWaitMode>
pub fn from_str_name(value: &str) -> Option<OldThreadWaitMode>
Creates an enum from field names used in the ProtoBuf definition.