#[repr(i32)]pub enum BeginImplFrameState {
BeginImplFrameUnspecified = 0,
BeginImplFrameIdle = 1,
BeginImplFrameInsideBeginFrame = 2,
BeginImplFrameInsideDeadline = 3,
}Variants
BeginImplFrameUnspecified = 0
BeginImplFrameIdle = 1
BeginImplFrameInsideBeginFrame = 2
BeginImplFrameInsideDeadline = 3
Implementations
Sourceimpl BeginImplFrameState
impl BeginImplFrameState
Sourcepub fn from_i32(value: i32) -> Option<BeginImplFrameState>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<BeginImplFrameState>
Converts an i32 to a BeginImplFrameState, or None if value is not a valid variant.
Sourceimpl BeginImplFrameState
impl BeginImplFrameState
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<BeginImplFrameState>
pub fn from_str_name(value: &str) -> Option<BeginImplFrameState>
Creates an enum from field names used in the ProtoBuf definition.