#[repr(i32)]pub enum TreePriority {
Unspecified = 0,
SamePriorityForBothTrees = 1,
SmoothnessTakesPriority = 2,
NewContentTakesPriority = 3,
}Variants
Unspecified = 0
SamePriorityForBothTrees = 1
SmoothnessTakesPriority = 2
NewContentTakesPriority = 3
Implementations
Sourceimpl TreePriority
impl TreePriority
Sourceimpl TreePriority
impl TreePriority
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<TreePriority>
pub fn from_str_name(value: &str) -> Option<TreePriority>
Creates an enum from field names used in the ProtoBuf definition.