#[repr(i32)]pub enum FrameDropReason {
ReasonUnspecified = 0,
ReasonDisplayCompositor = 1,
ReasonMainThread = 2,
ReasonClientCompositor = 3,
}Variants
ReasonUnspecified = 0
ReasonDisplayCompositor = 1
Frame was dropped by the display-compositor. The display-compositor may drop a frame some times (e.g. the frame missed the deadline, or was blocked on surface-sync, etc.)
ReasonMainThread = 2
Frame was dropped because of the main-thread. The main-thread may cause a frame to be dropped, e.g. if the main-thread is running expensive javascript, or doing a lot of layout updates, etc.
ReasonClientCompositor = 3
Frame was dropped by the client compositor. The client compositor can drop some frames too (e.g. attempting to recover latency, missing the deadline, etc.).
Implementations
Sourceimpl FrameDropReason
impl FrameDropReason
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<FrameDropReason>
pub fn from_str_name(value: &str) -> Option<FrameDropReason>
Creates an enum from field names used in the ProtoBuf definition.