#[repr(i32)]pub enum State {
NoUpdateDesired = 0,
PresentedAll = 1,
PresentedPartial = 2,
Dropped = 3,
}Variants
NoUpdateDesired = 0
The frame did not have any updates to present.
PresentedAll = 1
The frame presented all the desired updates (i.e. any updates requested from both the compositor thread and main-threads were handled).
PresentedPartial = 2
The frame was presented with some updates, but also missed some updates (e.g. missed updates from the main-thread, but included updates from the compositor thread).
Dropped = 3
The frame was dropped, i.e. some updates were desired for the frame, but was not presented.
Implementations
Sourceimpl State
impl State
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<State>
pub fn from_str_name(value: &str) -> Option<State>
Creates an enum from field names used in the ProtoBuf definition.