#[repr(i32)]pub enum LatencyComponentType {
Show 15 variants
ComponentUnspecified = 0,
ComponentInputEventLatencyBeginRwh = 1,
ComponentInputEventLatencyScrollUpdateOriginal = 2,
ComponentInputEventLatencyFirstScrollUpdateOriginal = 3,
ComponentInputEventLatencyOriginal = 4,
ComponentInputEventLatencyUi = 5,
ComponentInputEventLatencyRendererMain = 6,
ComponentInputEventLatencyRenderingScheduledMain = 7,
ComponentInputEventLatencyRenderingScheduledImpl = 8,
ComponentInputEventLatencyScrollUpdateLastEvent = 9,
ComponentInputEventLatencyAckRwh = 10,
ComponentInputEventLatencyRendererSwap = 11,
ComponentDisplayCompositorReceivedFrame = 12,
ComponentInputEventGpuSwapBuffer = 13,
ComponentInputEventLatencyFrameSwap = 14,
}Expand description
This enum is a copy of LatencyComponentType enum in Chrome, located in ui/latency/latency_info.h, modulo added UNKNOWN value per protobuf practices.
Variants
ComponentUnspecified = 0
ComponentInputEventLatencyBeginRwh = 1
ComponentInputEventLatencyScrollUpdateOriginal = 2
ComponentInputEventLatencyFirstScrollUpdateOriginal = 3
ComponentInputEventLatencyOriginal = 4
ComponentInputEventLatencyUi = 5
ComponentInputEventLatencyRendererMain = 6
ComponentInputEventLatencyRenderingScheduledMain = 7
ComponentInputEventLatencyRenderingScheduledImpl = 8
ComponentInputEventLatencyScrollUpdateLastEvent = 9
ComponentInputEventLatencyAckRwh = 10
ComponentInputEventLatencyRendererSwap = 11
ComponentDisplayCompositorReceivedFrame = 12
ComponentInputEventGpuSwapBuffer = 13
ComponentInputEventLatencyFrameSwap = 14
Implementations
Sourceimpl LatencyComponentType
impl LatencyComponentType
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of LatencyComponentType.
Sourcepub fn from_i32(value: i32) -> Option<LatencyComponentType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<LatencyComponentType>
Converts an i32 to a LatencyComponentType, or None if value is not a valid variant.
Sourceimpl LatencyComponentType
impl LatencyComponentType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<LatencyComponentType>
pub fn from_str_name(value: &str) -> Option<LatencyComponentType>
Creates an enum from field names used in the ProtoBuf definition.