#[repr(i32)]pub enum Step {
Unspecified = 0,
SendInputEventUi = 3,
HandleInputEventImpl = 5,
DidHandleInputAndOverscroll = 8,
HandleInputEventMain = 4,
MainThreadScrollUpdate = 2,
HandleInputEventMainCommit = 1,
HandledInputEventMainOrImpl = 9,
HandledInputEventImpl = 10,
SwapBuffers = 6,
DrawAndSwap = 7,
FinishedSwapBuffers = 11,
}Expand description
NEXT ID: 12 All step are optional but the enum is ordered (not by number) below in the order we expect them to appear if they are emitted in trace in a blocking fashion.
Variants
Unspecified = 0
SendInputEventUi = 3
Emitted on the browser main thread.
HandleInputEventImpl = 5
Happens on the renderer’s compositor.
DidHandleInputAndOverscroll = 8
HandleInputEventMain = 4
Occurs on the Renderer’s main thread.
MainThreadScrollUpdate = 2
HandleInputEventMainCommit = 1
HandledInputEventMainOrImpl = 9
Could be emitted on both the renderer’s main OR compositor.
HandledInputEventImpl = 10
Optionally sometimes HANDLED_INPUT_EVENT_MAIN_OR_IMPL will proxy to the renderer’s compositor and this will be emitted.
SwapBuffers = 6
Renderer’s compositor.
DrawAndSwap = 7
Happens on the VizCompositor in the GPU process.
FinishedSwapBuffers = 11
Happens on the GPU main thread after the swap has completed.
See above for NEXT ID, enum steps are not ordered by tag number.
Implementations
Sourceimpl Step
impl Step
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Step>
pub fn from_str_name(value: &str) -> Option<Step>
Creates an enum from field names used in the ProtoBuf definition.