#[repr(i32)]pub enum BuiltinClocks {
Unknown = 0,
Realtime = 1,
RealtimeCoarse = 2,
Monotonic = 3,
MonotonicCoarse = 4,
MonotonicRaw = 5,
Boottime = 6,
BuiltinClockMaxId = 63,
}Expand description
DEPRECATED. This enum has moved to ../common/builtin_clock.proto.
Variants
Unknown = 0
Realtime = 1
RealtimeCoarse = 2
Monotonic = 3
MonotonicCoarse = 4
MonotonicRaw = 5
Boottime = 6
BuiltinClockMaxId = 63
Implementations
Sourceimpl BuiltinClocks
impl BuiltinClocks
Sourceimpl BuiltinClocks
impl BuiltinClocks
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<BuiltinClocks>
pub fn from_str_name(value: &str) -> Option<BuiltinClocks>
Creates an enum from field names used in the ProtoBuf definition.