pub struct Clock {
pub clock_id: Option<u32>,
pub timestamp: Option<u64>,
pub is_incremental: Option<bool>,
pub unit_multiplier_ns: Option<u64>,
}Fields
clock_id: Option<u32>Clock IDs have the following semantic: [1, 63]: Builtin types, see BuiltinClock from ../common/builtin_clock.proto. [64, 127]: User-defined clocks. These clocks are sequence-scoped. They are only valid within the same |trusted_packet_sequence_id| (i.e. only for TracePacket(s) emitted by the same TraceWriter that emitted the clock snapshot). [128, MAX]: Reserved for future use. The idea is to allow global clock IDs and setting this ID to hash(full_clock_name) & ~127.
timestamp: Option<u64>Absolute timestamp. Unit is ns unless specified otherwise by the unit_multiplier_ns field below.
is_incremental: Option<bool>When true each TracePacket’s timestamp should be interpreted as a delta from the last TracePacket’s timestamp (referencing this clock) emitted by the same packet_sequence_id. Should only be used for user-defined sequence-local clocks. The first packet timestamp after each ClockSnapshot that contains this clock is relative to the |timestamp| in the ClockSnapshot.
unit_multiplier_ns: Option<u64>Allows to specify a custom unit different than the default (ns) for this clock domain. A multiplier of 1000 means that a timestamp = 3 should be interpreted as 3000 ns = 3 us. All snapshots for the same clock within a trace need to use the same unit.
Implementations
Sourceimpl Clock
impl Clock
Sourcepub fn clock_id(&self) -> u32
pub fn clock_id(&self) -> u32
Returns the value of clock_id, or the default value if clock_id is unset.
Sourcepub fn timestamp(&self) -> u64
pub fn timestamp(&self) -> u64
Returns the value of timestamp, or the default value if timestamp is unset.
Sourcepub fn is_incremental(&self) -> bool
pub fn is_incremental(&self) -> bool
Returns the value of is_incremental, or the default value if is_incremental is unset.
Sourcepub fn unit_multiplier_ns(&self) -> u64
pub fn unit_multiplier_ns(&self) -> u64
Returns the value of unit_multiplier_ns, or the default value if unit_multiplier_ns is unset.