#[repr(i32)]pub enum BuiltinCounterType {
CounterUnspecified = 0,
CounterThreadTimeNs = 1,
CounterThreadInstructionCount = 2,
}Expand description
Built-in counters, usually with special meaning in the client library, trace processor, legacy JSON format, or UI. Trace processor will infer a track name from the enum value if none is provided in TrackDescriptor.
Variants
CounterUnspecified = 0
CounterThreadTimeNs = 1
implies UNIT_TIME_NS.
CounterThreadInstructionCount = 2
implies UNIT_COUNT.
Implementations
Sourceimpl BuiltinCounterType
impl BuiltinCounterType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<BuiltinCounterType>
pub fn from_str_name(value: &str) -> Option<BuiltinCounterType>
Creates an enum from field names used in the ProtoBuf definition.