#[repr(i32)]pub enum Unit {
Unspecified = 0,
TimeNs = 1,
Count = 2,
SizeBytes = 3,
}Expand description
Type of the values for the counters - to supply lower granularity units, see also |unit_multiplier|.
Variants
Implementations
Sourceimpl Unit
impl Unit
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Unit>
pub fn from_str_name(value: &str) -> Option<Unit>
Creates an enum from field names used in the ProtoBuf definition.