#[repr(i32)]pub enum SessionInitiator {
Unspecified = 0,
TrustedSystem = 1,
}Variants
Unspecified = 0
TrustedSystem = 1
This trace was initiated from a trusted system app has DUMP and USAGE_STATS permission. This system app is expected to not expose the trace to the user of the device. This is determined by checking the UID initiating the trace.
Implementations
Sourceimpl SessionInitiator
impl SessionInitiator
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<SessionInitiator>
pub fn from_str_name(value: &str) -> Option<SessionInitiator>
Creates an enum from field names used in the ProtoBuf definition.