pub enum ProtoTypeDescriptor {
ProtoTypeName(String),
ProtoTypeNameIid(u64),
}Expand description
Used to embed arbitrary proto messages (which are also typically used to represent typed TrackEvent arguments). |proto_type_name| or |proto_type_name_iid| are storing the full name of the proto messages (e.g. .perfetto.protos.DebugAnnotation) and |proto_value| contains the serialised proto messages. See |TracedValue::WriteProto| for more details.
Variants
Implementations
Sourceimpl ProtoTypeDescriptor
impl ProtoTypeDescriptor
Sourcepub fn merge(
field: &mut Option<ProtoTypeDescriptor>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<ProtoTypeDescriptor>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.