pub struct StateResidency {
pub entity_index: Option<i32>,
pub state_index: Option<i32>,
pub total_time_in_state_ms: Option<u64>,
pub total_state_entry_count: Option<u64>,
pub last_entry_timestamp_ms: Option<u64>,
}Fields
entity_index: Option<i32>Index corresponding to PowerEntityState.entity_index
state_index: Option<i32>Index corresponding to PowerEntityState.state_index
total_time_in_state_ms: Option<u64>Time since boot that this entity has been in this state
total_state_entry_count: Option<u64>Total number of times since boot that the entity has entered this state
last_entry_timestamp_ms: Option<u64>Timestamp of the last time the entity entered this state
Implementations
Sourceimpl StateResidency
impl StateResidency
Sourcepub fn entity_index(&self) -> i32
pub fn entity_index(&self) -> i32
Returns the value of entity_index, or the default value if entity_index is unset.
Sourcepub fn state_index(&self) -> i32
pub fn state_index(&self) -> i32
Returns the value of state_index, or the default value if state_index is unset.
Sourcepub fn total_time_in_state_ms(&self) -> u64
pub fn total_time_in_state_ms(&self) -> u64
Returns the value of total_time_in_state_ms, or the default value if total_time_in_state_ms is unset.
Sourcepub fn total_state_entry_count(&self) -> u64
pub fn total_state_entry_count(&self) -> u64
Returns the value of total_state_entry_count, or the default value if total_state_entry_count is unset.
Sourcepub fn last_entry_timestamp_ms(&self) -> u64
pub fn last_entry_timestamp_ms(&self) -> u64
Returns the value of last_entry_timestamp_ms, or the default value if last_entry_timestamp_ms is unset.