#[repr(i32)]pub enum AndroidLogId {
LidDefault = 0,
LidRadio = 1,
LidEvents = 2,
LidSystem = 3,
LidCrash = 4,
LidStats = 5,
LidSecurity = 6,
LidKernel = 7,
}Expand description
Values from NDK’s android/log.h.
Variants
LidDefault = 0
MAIN.
LidRadio = 1
LidEvents = 2
LidSystem = 3
LidCrash = 4
LidStats = 5
LidSecurity = 6
LidKernel = 7
Implementations
Sourceimpl AndroidLogId
impl AndroidLogId
Sourceimpl AndroidLogId
impl AndroidLogId
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<AndroidLogId>
pub fn from_str_name(value: &str) -> Option<AndroidLogId>
Creates an enum from field names used in the ProtoBuf definition.