#[repr(i32)]pub enum AndroidLogPriority {
PrioUnspecified = 0,
PrioUnused = 1,
PrioVerbose = 2,
PrioDebug = 3,
PrioInfo = 4,
PrioWarn = 5,
PrioError = 6,
PrioFatal = 7,
}Variants
PrioUnspecified = 0
PrioUnused = 1
_DEFAULT, but should never be seen in logs.
PrioVerbose = 2
PrioDebug = 3
PrioInfo = 4
PrioWarn = 5
PrioError = 6
PrioFatal = 7
Implementations
Sourceimpl AndroidLogPriority
impl AndroidLogPriority
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<AndroidLogPriority>
pub fn from_str_name(value: &str) -> Option<AndroidLogPriority>
Creates an enum from field names used in the ProtoBuf definition.