#[repr(i32)]pub enum ChromeCompositorSchedulerAction {
Show 14 variants
CcSchedulerActionUnspecified = 0,
CcSchedulerActionNone = 1,
CcSchedulerActionSendBeginMainFrame = 2,
CcSchedulerActionCommit = 3,
CcSchedulerActionActivateSyncTree = 4,
CcSchedulerActionDrawIfPossible = 5,
CcSchedulerActionDrawForced = 6,
CcSchedulerActionDrawAbort = 7,
CcSchedulerActionBeginLayerTreeFrameSinkCreation = 8,
CcSchedulerActionPrepareTiles = 9,
CcSchedulerActionInvalidateLayerTreeFrameSink = 10,
CcSchedulerActionPerformImplSideInvalidation = 11,
CcSchedulerActionNotifyBeginMainFrameNotExpectedUntil = 12,
CcSchedulerActionNotifyBeginMainFrameNotExpectedSoon = 13,
}Variants
CcSchedulerActionUnspecified = 0
CcSchedulerActionNone = 1
CcSchedulerActionSendBeginMainFrame = 2
CcSchedulerActionCommit = 3
CcSchedulerActionActivateSyncTree = 4
CcSchedulerActionDrawIfPossible = 5
CcSchedulerActionDrawForced = 6
CcSchedulerActionDrawAbort = 7
CcSchedulerActionBeginLayerTreeFrameSinkCreation = 8
CcSchedulerActionPrepareTiles = 9
CcSchedulerActionInvalidateLayerTreeFrameSink = 10
CcSchedulerActionPerformImplSideInvalidation = 11
CcSchedulerActionNotifyBeginMainFrameNotExpectedUntil = 12
CcSchedulerActionNotifyBeginMainFrameNotExpectedSoon = 13
Implementations
Sourceimpl ChromeCompositorSchedulerAction
impl ChromeCompositorSchedulerAction
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of ChromeCompositorSchedulerAction.
Sourcepub fn from_i32(value: i32) -> Option<ChromeCompositorSchedulerAction>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ChromeCompositorSchedulerAction>
Converts an i32 to a ChromeCompositorSchedulerAction, or None if value is not a valid variant.
Sourceimpl ChromeCompositorSchedulerAction
impl ChromeCompositorSchedulerAction
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<ChromeCompositorSchedulerAction>
pub fn from_str_name(value: &str) -> Option<ChromeCompositorSchedulerAction>
Creates an enum from field names used in the ProtoBuf definition.