#[repr(i32)]pub enum ChromeRailMode {
RailModeNone = 0,
RailModeResponse = 1,
RailModeAnimation = 2,
RailModeIdle = 3,
RailModeLoad = 4,
}Expand description
RAIL Mode is an indication of the kind of work that a Renderer is currently performing which is in turn used to prioritise work accordingly. A fuller description of these modes can be found https://web.dev/rail/
Variants
Implementations
Sourceimpl ChromeRailMode
impl ChromeRailMode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<ChromeRailMode>
pub fn from_str_name(value: &str) -> Option<ChromeRailMode>
Creates an enum from field names used in the ProtoBuf definition.