#[repr(i32)]pub enum FtraceParseStatus {
Show 18 variants
FtraceStatusUnspecified = 0,
FtraceStatusOk = 1,
FtraceStatusUnexpectedReadError = 2,
FtraceStatusPartialPageRead = 3,
FtraceStatusAbiInvalidPageHeader = 4,
FtraceStatusAbiShortEventHeader = 5,
FtraceStatusAbiNullPadding = 6,
FtraceStatusAbiShortPaddingLength = 7,
FtraceStatusAbiInvalidPaddingLength = 8,
FtraceStatusAbiShortTimeExtend = 9,
FtraceStatusAbiShortTimeStamp = 10,
FtraceStatusAbiShortDataLength = 11,
FtraceStatusAbiZeroDataLength = 12,
FtraceStatusAbiInvalidDataLength = 13,
FtraceStatusAbiShortEventId = 14,
FtraceStatusAbiEndOverflow = 15,
FtraceStatusShortCompactEvent = 16,
FtraceStatusInvalidEvent = 17,
}Variants
FtraceStatusUnspecified = 0
FtraceStatusOk = 1
Not written, used for convenience of implementation:
FtraceStatusUnexpectedReadError = 2
Issues with reading data out of the ftrace ring buffer:
FtraceStatusPartialPageRead = 3
FtraceStatusAbiInvalidPageHeader = 4
Ring buffer binary data not matching our understanding of the layout:
FtraceStatusAbiShortEventHeader = 5
FtraceStatusAbiNullPadding = 6
FtraceStatusAbiShortPaddingLength = 7
FtraceStatusAbiInvalidPaddingLength = 8
FtraceStatusAbiShortTimeExtend = 9
FtraceStatusAbiShortTimeStamp = 10
FtraceStatusAbiShortDataLength = 11
FtraceStatusAbiZeroDataLength = 12
FtraceStatusAbiInvalidDataLength = 13
FtraceStatusAbiShortEventId = 14
FtraceStatusAbiEndOverflow = 15
FtraceStatusShortCompactEvent = 16
Issues with parsing the event payload:
FtraceStatusInvalidEvent = 17
Implementations
Sourceimpl FtraceParseStatus
impl FtraceParseStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<FtraceParseStatus>
pub fn from_str_name(value: &str) -> Option<FtraceParseStatus>
Creates an enum from field names used in the ProtoBuf definition.