#[repr(i32)]pub enum HwcCompositionType {
HwcTypeUnspecified = 0,
HwcTypeClient = 1,
HwcTypeDevice = 2,
HwcTypeSolidColor = 3,
HwcTypeCursor = 4,
HwcTypeSideband = 5,
HwcTypeDisplayDecoration = 6,
}Expand description
Must match definition in the IComposerClient HAL
Variants
HwcTypeUnspecified = 0
Invalid composition type
HwcTypeClient = 1
Layer was composited by the client into the client target buffer
HwcTypeDevice = 2
Layer was composited by the device through hardware overlays
HwcTypeSolidColor = 3
Layer was composited by the device using a color
HwcTypeCursor = 4
Similar to DEVICE, but the layer position may have been asynchronously set through setCursorPosition
HwcTypeSideband = 5
Layer was composited by the device via a sideband stream
HwcTypeDisplayDecoration = 6
Layer was composited by hardware optimized for display decoration
Implementations
Sourceimpl HwcCompositionType
impl HwcCompositionType
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of HwcCompositionType.
Sourcepub fn from_i32(value: i32) -> Option<HwcCompositionType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<HwcCompositionType>
Use the TryFrom<i32> implementation instead
Converts an i32 to a HwcCompositionType, or None if value is not a valid variant.
Sourceimpl HwcCompositionType
impl HwcCompositionType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<HwcCompositionType>
pub fn from_str_name(value: &str) -> Option<HwcCompositionType>
Creates an enum from field names used in the ProtoBuf definition.