#[repr(i32)]pub enum MeminfoCounters {
Show 34 variants
MeminfoUnspecified = 0,
MeminfoMemTotal = 1,
MeminfoMemFree = 2,
MeminfoMemAvailable = 3,
MeminfoBuffers = 4,
MeminfoCached = 5,
MeminfoSwapCached = 6,
MeminfoActive = 7,
MeminfoInactive = 8,
MeminfoActiveAnon = 9,
MeminfoInactiveAnon = 10,
MeminfoActiveFile = 11,
MeminfoInactiveFile = 12,
MeminfoUnevictable = 13,
MeminfoMlocked = 14,
MeminfoSwapTotal = 15,
MeminfoSwapFree = 16,
MeminfoDirty = 17,
MeminfoWriteback = 18,
MeminfoAnonPages = 19,
MeminfoMapped = 20,
MeminfoShmem = 21,
MeminfoSlab = 22,
MeminfoSlabReclaimable = 23,
MeminfoSlabUnreclaimable = 24,
MeminfoKernelStack = 25,
MeminfoPageTables = 26,
MeminfoCommitLimit = 27,
MeminfoCommitedAs = 28,
MeminfoVmallocTotal = 29,
MeminfoVmallocUsed = 30,
MeminfoVmallocChunk = 31,
MeminfoCmaTotal = 32,
MeminfoCmaFree = 33,
}Expand description
Counter definitions for Linux’s /proc/meminfo.
Variants
MeminfoUnspecified = 0
MeminfoMemTotal = 1
MeminfoMemFree = 2
MeminfoMemAvailable = 3
MeminfoBuffers = 4
MeminfoCached = 5
MeminfoSwapCached = 6
MeminfoActive = 7
MeminfoInactive = 8
MeminfoActiveAnon = 9
MeminfoInactiveAnon = 10
MeminfoActiveFile = 11
MeminfoInactiveFile = 12
MeminfoUnevictable = 13
MeminfoMlocked = 14
MeminfoSwapTotal = 15
MeminfoSwapFree = 16
MeminfoDirty = 17
MeminfoWriteback = 18
MeminfoAnonPages = 19
MeminfoMapped = 20
MeminfoShmem = 21
MeminfoSlab = 22
MeminfoSlabReclaimable = 23
MeminfoSlabUnreclaimable = 24
MeminfoKernelStack = 25
MeminfoPageTables = 26
MeminfoCommitLimit = 27
MeminfoCommitedAs = 28
MeminfoVmallocTotal = 29
MeminfoVmallocUsed = 30
MeminfoVmallocChunk = 31
MeminfoCmaTotal = 32
MeminfoCmaFree = 33
Implementations
Sourceimpl MeminfoCounters
impl MeminfoCounters
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<MeminfoCounters>
pub fn from_str_name(value: &str) -> Option<MeminfoCounters>
Creates an enum from field names used in the ProtoBuf definition.