#[repr(i32)]pub enum KernelFlag {
Cswitch = 0,
Dispatcher = 1,
}Expand description
The KernelFlag represent list of kernel flags that we are intrested in. To get a more extensive list run ‘xperf -providers k’.
Variants
Implementations
Sourceimpl KernelFlag
impl KernelFlag
Sourceimpl KernelFlag
impl KernelFlag
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<KernelFlag>
pub fn from_str_name(value: &str) -> Option<KernelFlag>
Creates an enum from field names used in the ProtoBuf definition.