#[repr(i32)]pub enum JankType {
JankUnspecified = 0,
JankNone = 1,
JankSfScheduling = 2,
JankPredictionError = 4,
JankDisplayHal = 8,
JankSfCpuDeadlineMissed = 16,
JankSfGpuDeadlineMissed = 32,
JankAppDeadlineMissed = 64,
JankBufferStuffing = 128,
JankUnknown = 256,
JankSfStuffing = 512,
JankDropped = 1_024,
}Expand description
Specifies the reason(s) most likely to have caused the jank. Used as a bitmask.
Variants
JankUnspecified = 0
JankNone = 1
JankSfScheduling = 2
JankPredictionError = 4
JankDisplayHal = 8
JankSfCpuDeadlineMissed = 16
JankSfGpuDeadlineMissed = 32
JankAppDeadlineMissed = 64
JankBufferStuffing = 128
JankUnknown = 256
JankSfStuffing = 512
JankDropped = 1_024
Implementations
Sourceimpl JankType
impl JankType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<JankType>
pub fn from_str_name(value: &str) -> Option<JankType>
Creates an enum from field names used in the ProtoBuf definition.