#[repr(i32)]pub enum PredictionType {
PredictionUnspecified = 0,
PredictionValid = 1,
PredictionExpired = 2,
PredictionUnknown = 3,
}Expand description
Specifies if the predictions for the frame are still valid, expired or unknown.
Variants
Implementations
Sourceimpl PredictionType
impl PredictionType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<PredictionType>
pub fn from_str_name(value: &str) -> Option<PredictionType>
Creates an enum from field names used in the ProtoBuf definition.