#[repr(i32)]pub enum PresentType {
PresentUnspecified = 0,
PresentOnTime = 1,
PresentLate = 2,
PresentEarly = 3,
PresentDropped = 4,
PresentUnknown = 5,
}Expand description
Specifies how a frame was presented on screen w.r.t. timing. Can be different for SurfaceFrame and DisplayFrame.
Variants
PresentUnspecified = 0
PresentOnTime = 1
PresentLate = 2
PresentEarly = 3
PresentDropped = 4
PresentUnknown = 5
Implementations
Sourceimpl PresentType
impl PresentType
Sourceimpl PresentType
impl PresentType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<PresentType>
pub fn from_str_name(value: &str) -> Option<PresentType>
Creates an enum from field names used in the ProtoBuf definition.