pub struct ActualDisplayFrameStart {
pub cookie: Option<i64>,
pub token: Option<i64>,
pub pid: Option<i32>,
pub present_type: Option<i32>,
pub on_time_finish: Option<bool>,
pub gpu_composition: Option<bool>,
pub jank_type: Option<i32>,
pub prediction_type: Option<i32>,
pub jank_severity_type: Option<i32>,
}Expand description
Indicates the start of actual timeline slice for DisplayFrames. Also includes the jank information.
Fields
Cookie used to correlate between the start and end messages of the same frame. Since all values except the ts are same for start and end, cookie helps in preventing redundant data transmission. The same cookie is used only by start and end messages of a single frame and is otherwise unique.
token: Option<i64>Token received by SurfaceFlinger for its work this.token = SurfaceFrame.display_frame_token
pid: Option<i32>Pid of SurfaceFlinger. Used in creating the timeline tracks (and slices) inside the SurfaceFlinger process group.
present_type: Option<i32>on_time_finish: Option<bool>gpu_composition: Option<bool>jank_type: Option<i32>A bitmask of JankType. More than one reason can be attributed to a janky frame.
prediction_type: Option<i32>jank_severity_type: Option<i32>Implementations
Sourceimpl ActualDisplayFrameStart
impl ActualDisplayFrameStart
Returns the value of cookie, or the default value if cookie is unset.
Sourcepub fn present_type(&self) -> PresentType
pub fn present_type(&self) -> PresentType
Returns the enum value of present_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_present_type(&mut self, value: PresentType)
pub fn set_present_type(&mut self, value: PresentType)
Sets present_type to the provided enum value.
Sourcepub fn on_time_finish(&self) -> bool
pub fn on_time_finish(&self) -> bool
Returns the value of on_time_finish, or the default value if on_time_finish is unset.
Sourcepub fn gpu_composition(&self) -> bool
pub fn gpu_composition(&self) -> bool
Returns the value of gpu_composition, or the default value if gpu_composition is unset.
Sourcepub fn jank_type(&self) -> i32
pub fn jank_type(&self) -> i32
Returns the value of jank_type, or the default value if jank_type is unset.
Sourcepub fn prediction_type(&self) -> PredictionType
pub fn prediction_type(&self) -> PredictionType
Returns the enum value of prediction_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_prediction_type(&mut self, value: PredictionType)
pub fn set_prediction_type(&mut self, value: PredictionType)
Sets prediction_type to the provided enum value.
Sourcepub fn jank_severity_type(&self) -> JankSeverityType
pub fn jank_severity_type(&self) -> JankSeverityType
Returns the enum value of jank_severity_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_jank_severity_type(&mut self, value: JankSeverityType)
pub fn set_jank_severity_type(&mut self, value: JankSeverityType)
Sets jank_severity_type to the provided enum value.