pub struct ExpectedDisplayFrameStart {
pub cookie: Option<i64>,
pub token: Option<i64>,
pub pid: Option<i32>,
}Expand description
Indicates the start of expected timeline slice for DisplayFrames.
Fields
Cookie used to correlate between the start and end messages of the same frame. Since all values except the ts are same for start and end, cookie helps in preventing redundant data transmission. The same cookie is used only by start and end messages of a single frame and is otherwise unique.
token: Option<i64>Token received by SurfaceFlinger for its work this.token = SurfaceFrame.display_frame_token
pid: Option<i32>Pid of SurfaceFlinger. Used in creating the timeline tracks (and slices) inside the SurfaceFlinger process group.
Implementations