pub struct CompactSchedConfig {
pub enabled: Option<bool>,
}Expand description
Configuration for compact encoding of scheduler events. When enabled (and recording the relevant ftrace events), specific high-volume events are encoded in a denser format than normal.
Fields
enabled: Option<bool>If true, and sched_switch or sched_waking ftrace events are enabled, record those events in the compact format.
If the field is unset, the default is:
- perfetto v42.0+: enabled
- before: disabled
Implementations