pub struct CompactSched {
pub intern_table: Vec<String>,
pub switch_timestamp: Vec<u64>,
pub switch_prev_state: Vec<i64>,
pub switch_next_pid: Vec<i32>,
pub switch_next_prio: Vec<i32>,
pub switch_next_comm_index: Vec<u32>,
pub waking_timestamp: Vec<u64>,
pub waking_pid: Vec<i32>,
pub waking_target_cpu: Vec<i32>,
pub waking_prio: Vec<i32>,
pub waking_comm_index: Vec<u32>,
pub waking_common_flags: Vec<u32>,
}Expand description
Optionally-enabled compact encoding of a batch of scheduling events. Only a subset of events & their fields is recorded. All fields (except comms) are stored in a structure-of-arrays form, one entry in each repeated field per event.
Fields
intern_table: Vec<String>Interned table of unique strings for this bundle.
switch_timestamp: Vec<u64>Delta-encoded timestamps across all sched_switch events within this bundle. The first is absolute, each next one is relative to its predecessor.
switch_prev_state: Vec<i64>switch_next_pid: Vec<i32>switch_next_prio: Vec<i32>switch_next_comm_index: Vec<u32>One per event, index into |intern_table| corresponding to the next_comm field of the event.
waking_timestamp: Vec<u64>Delta-encoded timestamps across all sched_waking events within this bundle. The first is absolute, each next one is relative to its predecessor.
waking_pid: Vec<i32>waking_target_cpu: Vec<i32>waking_prio: Vec<i32>waking_comm_index: Vec<u32>One per event, index into |intern_table| corresponding to the comm field of the event.
waking_common_flags: Vec<u32>Trait Implementations
Sourceimpl Clone for CompactSched
impl Clone for CompactSched
Sourcefn clone(&self) -> CompactSched
fn clone(&self) -> CompactSched
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CompactSched
impl Debug for CompactSched
Sourceimpl Default for CompactSched
impl Default for CompactSched
Sourcefn default() -> CompactSched
fn default() -> CompactSched
Returns the “default value” for a type. Read more
Sourceimpl Message for CompactSched
impl Message for CompactSched
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for CompactSched
impl PartialEq for CompactSched
impl StructuralPartialEq for CompactSched