pub struct FtraceError {
pub timestamp: Option<u64>,
pub status: Option<i32>,
}Expand description
Errors encountered during parsing of the raw ftrace data. In case of ring buffer layout errors, the parser skips the rest of the offending kernel buffer page and continues from the next page. See also FtraceStats.ftrace_parse_errors, which collates all unique errors seen within the duration of the trace (even if the affected bundles get overwritten in ring buffer mode).
Fields
timestamp: Option<u64>Timestamp of the data that we’re unable to parse, in the ftrace clock domain. Currently, we use the base timestamp of the tracing page containing the bad record rather than the time of the record itself.
status: Option<i32>Implementations
Sourceimpl FtraceError
impl FtraceError
Sourcepub fn timestamp(&self) -> u64
pub fn timestamp(&self) -> u64
Returns the value of timestamp, or the default value if timestamp is unset.
Sourcepub fn status(&self) -> FtraceParseStatus
pub fn status(&self) -> FtraceParseStatus
Returns the enum value of status, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: FtraceParseStatus)
pub fn set_status(&mut self, value: FtraceParseStatus)
Sets status to the provided enum value.