#[repr(i32)]pub enum GpuCounterGroup {
Unclassified = 0,
System = 1,
Vertices = 2,
Fragments = 3,
Primitives = 4,
Memory = 5,
Compute = 6,
}Expand description
Logical groups for a counter. This is used in the UI to present the related counters together.
Variants
Unclassified = 0
System = 1
Vertices = 2
Fragments = 3
Primitives = 4
Memory = 5
Includes counters relating to caching and bandwidth.
Compute = 6
Implementations
Sourceimpl GpuCounterGroup
impl GpuCounterGroup
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<GpuCounterGroup>
pub fn from_str_name(value: &str) -> Option<GpuCounterGroup>
Creates an enum from field names used in the ProtoBuf definition.