pub struct GpuCounterBlock {
pub block_id: Option<u32>,
pub block_capacity: Option<u32>,
pub name: Option<String>,
pub description: Option<String>,
pub counter_ids: Vec<u32>,
}Expand description
Allow producer to group counters into block to represent counter islands. A capacity may be specified to indicate the number of counters that can be enable simultaneously in that block.
Fields
block_id: Option<u32>required. Unique ID for the counter group.
block_capacity: Option<u32>optional. Number of counters supported by the block. No limit if unset.
name: Option<String>optional. Name of block.
description: Option<String>optional. Description for the block.
counter_ids: Vec<u32>list of counters that are part of the block.
Implementations
Sourceimpl GpuCounterBlock
impl GpuCounterBlock
Sourcepub fn block_id(&self) -> u32
pub fn block_id(&self) -> u32
Returns the value of block_id, or the default value if block_id is unset.
Sourcepub fn block_capacity(&self) -> u32
pub fn block_capacity(&self) -> u32
Returns the value of block_capacity, or the default value if block_capacity is unset.
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Returns the value of description, or the default value if description is unset.