#[repr(i32)]pub enum BufferEventType {
Show 14 variants
Unspecified = 0,
Dequeue = 1,
Queue = 2,
Post = 3,
AcquireFence = 4,
Latch = 5,
HwcCompositionQueued = 6,
FallbackComposition = 7,
PresentFence = 8,
ReleaseFence = 9,
Modify = 10,
Detach = 11,
Attach = 12,
Cancel = 13,
}Variants
Unspecified = 0
Dequeue = 1
Queue = 2
Post = 3
AcquireFence = 4
Latch = 5
HwcCompositionQueued = 6
HWC will compose this buffer
FallbackComposition = 7
renderEngine composition
PresentFence = 8
ReleaseFence = 9
Modify = 10
Detach = 11
Attach = 12
Cancel = 13
Implementations
Sourceimpl BufferEventType
impl BufferEventType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<BufferEventType>
pub fn from_str_name(value: &str) -> Option<BufferEventType>
Creates an enum from field names used in the ProtoBuf definition.