pub struct BufferEvent {
pub frame_number: Option<u32>,
pub type: Option<i32>,
pub layer_name: Option<String>,
pub duration_ns: Option<u64>,
pub buffer_id: Option<u32>,
}Fields
frame_number: Option<u32>type: Option<i32>layer_name: Option<String>duration_ns: Option<u64>If no duration is set, the event is an instant event.
buffer_id: Option<u32>Unique buffer identifier.
Implementations
Sourceimpl BufferEvent
impl BufferEvent
Sourcepub fn frame_number(&self) -> u32
pub fn frame_number(&self) -> u32
Returns the value of frame_number, or the default value if frame_number is unset.
Sourcepub fn type(&self) -> BufferEventType
pub fn type(&self) -> BufferEventType
Returns the enum value of type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: BufferEventType)
pub fn set_type(&mut self, value: BufferEventType)
Sets type to the provided enum value.
Sourcepub fn layer_name(&self) -> &str
pub fn layer_name(&self) -> &str
Returns the value of layer_name, or the default value if layer_name is unset.
Sourcepub fn duration_ns(&self) -> u64
pub fn duration_ns(&self) -> u64
Returns the value of duration_ns, or the default value if duration_ns is unset.