pub struct ContinuousDumpConfig {
pub dump_phase_ms: Option<u32>,
pub dump_interval_ms: Option<u32>,
pub scan_pids_only_on_start: Option<bool>,
}Expand description
If dump_interval_ms != 0, the following configuration is used.
Fields
dump_phase_ms: Option<u32>ms to wait before first continuous dump. A dump is always created at the beginning of the trace.
dump_interval_ms: Option<u32>ms to wait between following dumps.
scan_pids_only_on_start: Option<bool>If true, scans all the processes to find process_cmdline and filter by
min_anonymous_memory_kb only at data source start. Default on Android
S-.
If false, rescans all the processes to find on every dump. Default on Android T+.
Implementations
Sourceimpl ContinuousDumpConfig
impl ContinuousDumpConfig
Sourcepub fn dump_phase_ms(&self) -> u32
pub fn dump_phase_ms(&self) -> u32
Returns the value of dump_phase_ms, or the default value if dump_phase_ms is unset.
Sourcepub fn dump_interval_ms(&self) -> u32
pub fn dump_interval_ms(&self) -> u32
Returns the value of dump_interval_ms, or the default value if dump_interval_ms is unset.
Sourcepub fn scan_pids_only_on_start(&self) -> bool
pub fn scan_pids_only_on_start(&self) -> bool
Returns the value of scan_pids_only_on_start, or the default value if scan_pids_only_on_start is unset.