#[repr(i32)]pub enum ChangesMsb {
Show 17 variants
EChangesMsbNone = 0,
EDestinationFrameChanged = 1,
ECachedBufferChanged = 2,
EBackgroundColorChanged = 4,
EMetadataChanged = 8,
EColorSpaceAgnosticChanged = 16,
EFrameRateSelectionPriority = 32,
EFrameRateChanged = 64,
EBackgroundBlurRadiusChanged = 128,
EProducerDisconnect = 256,
EFixedTransformHintChanged = 512,
EFrameNumberChanged = 1_024,
EBlurRegionsChanged = 2_048,
EAutoRefreshChanged = 4_096,
EStretchChanged = 8_192,
ETrustedOverlayChanged = 16_384,
EDropInputModeChanged = 32_768,
}Variants
EChangesMsbNone = 0
EDestinationFrameChanged = 1
ECachedBufferChanged = 2
EBackgroundColorChanged = 4
EMetadataChanged = 8
EColorSpaceAgnosticChanged = 16
EFrameRateSelectionPriority = 32
EFrameRateChanged = 64
EBackgroundBlurRadiusChanged = 128
EProducerDisconnect = 256
EFixedTransformHintChanged = 512
EFrameNumberChanged = 1_024
EBlurRegionsChanged = 2_048
EAutoRefreshChanged = 4_096
EStretchChanged = 8_192
ETrustedOverlayChanged = 16_384
EDropInputModeChanged = 32_768
Implementations
Sourceimpl ChangesMsb
impl ChangesMsb
Sourceimpl ChangesMsb
impl ChangesMsb
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<ChangesMsb>
pub fn from_str_name(value: &str) -> Option<ChangesMsb>
Creates an enum from field names used in the ProtoBuf definition.