BufferData

Struct BufferData 

pub struct BufferData {
    pub buffer_id: Option<u64>,
    pub width: Option<u32>,
    pub height: Option<u32>,
    pub frame_number: Option<u64>,
    pub flags: Option<u32>,
    pub cached_buffer_id: Option<u64>,
    pub pixel_format: Option<i32>,
    pub usage: Option<u64>,
}

Fields

buffer_id: Option<u64>width: Option<u32>height: Option<u32>frame_number: Option<u64>flags: Option<u32>cached_buffer_id: Option<u64>pixel_format: Option<i32>usage: Option<u64>

Implementations

Source

impl BufferData

pub fn buffer_id(&self) -> u64

Returns the value of buffer_id, or the default value if buffer_id is unset.

pub fn width(&self) -> u32

Returns the value of width, or the default value if width is unset.

pub fn height(&self) -> u32

Returns the value of height, or the default value if height is unset.

pub fn frame_number(&self) -> u64

Returns the value of frame_number, or the default value if frame_number is unset.

pub fn flags(&self) -> u32

Returns the value of flags, or the default value if flags is unset.

pub fn cached_buffer_id(&self) -> u64

Returns the value of cached_buffer_id, or the default value if cached_buffer_id is unset.

pub fn pixel_format(&self) -> PixelFormat

Returns the enum value of pixel_format, or the default if the field is unset or set to an invalid enum value.

pub fn set_pixel_format(&mut self, value: PixelFormat)

Sets pixel_format to the provided enum value.

pub fn usage(&self) -> u64

Returns the value of usage, or the default value if usage is unset.