pub struct ProcessSnapshot {
pub pid: Option<i32>,
pub allocator_dumps: Vec<MemoryNode>,
pub memory_edges: Vec<MemoryEdge>,
}Expand description
Memory snapshot of a process. The snapshot contains memory data that is from 2 different sources, namely system stats and instrumentation stats. The system memory usage stats come from the OS based on standard API available in the platform to query memory usage. The instrumentation stats are added by instrumenting specific piece of code which tracks memory allocations and deallocations made by a small sub-system within the application. The system stats of the global memory snapshot are recorded as part of ProcessStats and SmapsPacket fields in trace packet with the same timestamp.
Fields
pid: Option<i32>Process ID of the process
allocator_dumps: Vec<MemoryNode>memory_edges: Vec<MemoryEdge>Implementations