pub enum PacketContext {
Iid(u64),
Ctx(NetworkPacketEvent),
}Variants
Iid(u64)
The intern id for looking up the associated packet context.
Ctx(NetworkPacketEvent)
The inlined context for events in this bundle.
Implementations
Sourceimpl PacketContext
impl PacketContext
Sourcepub fn merge(
field: &mut Option<PacketContext>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<PacketContext>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.