#[repr(i32)]pub enum PerfClock {
UnknownPerfClock = 0,
Realtime = 1,
Monotonic = 2,
MonotonicRaw = 3,
Boottime = 4,
}Expand description
Subset of clocks that is supported by perf timestamping. CLOCK_TAI is excluded since it’s not expected to be used in practice, but would require additions to the trace clock synchronisation logic.
Variants
Implementations
Sourceimpl PerfClock
impl PerfClock
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<PerfClock>
pub fn from_str_name(value: &str) -> Option<PerfClock>
Creates an enum from field names used in the ProtoBuf definition.