pub struct RawEvent {
pub type: Option<u32>,
pub config: Option<u64>,
pub config1: Option<u64>,
pub config2: Option<u64>,
}Expand description
Syscall-level description of the event, propagated to the perf_event_attr struct. Primarily for local use-cases, since the event availability and encoding is hardware-specific.
Fields
type: Option<u32>config: Option<u64>config1: Option<u64>config2: Option<u64>Implementations