pub enum OptionalUnwindError {
UnwindError(i32),
}Expand description
If set, stack unwinding was incomplete due to an error. Unset values should be treated as UNWIND_ERROR_NONE.
Variants
Implementations
Sourceimpl OptionalUnwindError
impl OptionalUnwindError
Sourcepub fn merge(
field: &mut Option<OptionalUnwindError>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<OptionalUnwindError>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.