#[repr(i32)]pub enum SampleSkipReason {
ProfilerSkipUnknown = 0,
ProfilerSkipReadStage = 1,
ProfilerSkipUnwindStage = 2,
ProfilerSkipUnwindEnqueue = 3,
}Expand description
If set, indicates that the profiler encountered a sample that was relevant, but was skipped.
Variants
ProfilerSkipUnknown = 0
ProfilerSkipReadStage = 1
ProfilerSkipUnwindStage = 2
ProfilerSkipUnwindEnqueue = 3
Implementations
Sourceimpl SampleSkipReason
impl SampleSkipReason
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<SampleSkipReason>
pub fn from_str_name(value: &str) -> Option<SampleSkipReason>
Creates an enum from field names used in the ProtoBuf definition.