#[repr(i32)]pub enum EventGroup {
Unknown = 0,
LowBandwidth = 1,
HighAndLowBandwidth = 2,
}Expand description
Event group to record, as defined by the modem.
Variants
Unknown = 0
LowBandwidth = 1
Events suitable for low bandwidth tracing only.
HighAndLowBandwidth = 2
Events suitable for high and low bandwidth tracing.
Implementations
Sourceimpl EventGroup
impl EventGroup
Sourceimpl EventGroup
impl EventGroup
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<EventGroup>
pub fn from_str_name(value: &str) -> Option<EventGroup>
Creates an enum from field names used in the ProtoBuf definition.