#[repr(i32)]pub enum ChromeProcessType {
ProcessUnspecified = 0,
ProcessBrowser = 1,
ProcessRenderer = 2,
ProcessUtility = 3,
ProcessZygote = 4,
ProcessSandboxHelper = 5,
ProcessGpu = 6,
ProcessPpapiPlugin = 7,
ProcessPpapiBroker = 8,
}Expand description
See chromium’s content::ProcessType.
Variants
ProcessUnspecified = 0
ProcessBrowser = 1
ProcessRenderer = 2
ProcessUtility = 3
ProcessZygote = 4
ProcessSandboxHelper = 5
ProcessGpu = 6
ProcessPpapiPlugin = 7
ProcessPpapiBroker = 8
Implementations
Sourceimpl ChromeProcessType
impl ChromeProcessType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<ChromeProcessType>
pub fn from_str_name(value: &str) -> Option<ChromeProcessType>
Creates an enum from field names used in the ProtoBuf definition.