Process

Struct Process 

pub struct Process {
Show 23 fields pub pid: Option<i32>, pub threads: Vec<Thread>, pub vm_size_kb: Option<u64>, pub vm_rss_kb: Option<u64>, pub rss_anon_kb: Option<u64>, pub rss_file_kb: Option<u64>, pub rss_shmem_kb: Option<u64>, pub vm_swap_kb: Option<u64>, pub vm_locked_kb: Option<u64>, pub vm_hwm_kb: Option<u64>, pub oom_score_adj: Option<i64>, pub is_peak_rss_resettable: Option<bool>, pub chrome_private_footprint_kb: Option<u32>, pub chrome_peak_resident_set_kb: Option<u32>, pub fds: Vec<FdInfo>, pub smr_rss_kb: Option<u64>, pub smr_pss_kb: Option<u64>, pub smr_pss_anon_kb: Option<u64>, pub smr_pss_file_kb: Option<u64>, pub smr_pss_shmem_kb: Option<u64>, pub smr_swap_pss_kb: Option<u64>, pub runtime_user_mode: Option<u64>, pub runtime_kernel_mode: Option<u64>,
}

Fields

pid: Option<i32>threads: Vec<Thread>vm_size_kb: Option<u64>

See /proc/[pid]/status in man 5 proc for a description of these fields.

vm_rss_kb: Option<u64>rss_anon_kb: Option<u64>rss_file_kb: Option<u64>rss_shmem_kb: Option<u64>vm_swap_kb: Option<u64>vm_locked_kb: Option<u64>vm_hwm_kb: Option<u64>

When adding a new field remember to update kProcMemCounterSize in the trace processor.

oom_score_adj: Option<i64>is_peak_rss_resettable: Option<bool>

The peak resident set size is resettable in newer Posix kernels. This field specifies if reset is supported and if the writer had reset the peaks after each process stats recording.

chrome_private_footprint_kb: Option<u32>

Private, shared and swap footprint of the process as measured by Chrome. To know more about these metrics refer to: https://docs.google.com/document/d/1_WmgE1F5WUrhwkPqJis3dWyOiUmQKvpXp5cd4w86TvA

chrome_peak_resident_set_kb: Option<u32>fds: Vec<FdInfo>smr_rss_kb: Option<u64>

These fields are set only when scan_smaps_rollup=true

smr_pss_kb: Option<u64>smr_pss_anon_kb: Option<u64>smr_pss_file_kb: Option<u64>smr_pss_shmem_kb: Option<u64>smr_swap_pss_kb: Option<u64>runtime_user_mode: Option<u64>

Time spent scheduled in user mode in nanoseconds. Parsed from utime in /proc/pid/stat. Recorded if record_process_runtime config option is set. Resolution of “clock ticks”, usually 10ms.

runtime_kernel_mode: Option<u64>

Time spent scheduled in kernel mode in nanoseconds. Parsed from stime in /proc/pid/stat. Recorded if record_process_runtime config option is set. Resolution of “clock ticks”, usually 10ms.

Implementations

Source

impl Process

pub fn pid(&self) -> i32

Returns the value of pid, or the default value if pid is unset.

pub fn vm_size_kb(&self) -> u64

Returns the value of vm_size_kb, or the default value if vm_size_kb is unset.

pub fn vm_rss_kb(&self) -> u64

Returns the value of vm_rss_kb, or the default value if vm_rss_kb is unset.

pub fn rss_anon_kb(&self) -> u64

Returns the value of rss_anon_kb, or the default value if rss_anon_kb is unset.

pub fn rss_file_kb(&self) -> u64

Returns the value of rss_file_kb, or the default value if rss_file_kb is unset.

pub fn rss_shmem_kb(&self) -> u64

Returns the value of rss_shmem_kb, or the default value if rss_shmem_kb is unset.

pub fn vm_swap_kb(&self) -> u64

Returns the value of vm_swap_kb, or the default value if vm_swap_kb is unset.

pub fn vm_locked_kb(&self) -> u64

Returns the value of vm_locked_kb, or the default value if vm_locked_kb is unset.

pub fn vm_hwm_kb(&self) -> u64

Returns the value of vm_hwm_kb, or the default value if vm_hwm_kb is unset.

pub fn oom_score_adj(&self) -> i64

Returns the value of oom_score_adj, or the default value if oom_score_adj is unset.

pub fn is_peak_rss_resettable(&self) -> bool

Returns the value of is_peak_rss_resettable, or the default value if is_peak_rss_resettable is unset.

pub fn chrome_private_footprint_kb(&self) -> u32

Returns the value of chrome_private_footprint_kb, or the default value if chrome_private_footprint_kb is unset.

pub fn chrome_peak_resident_set_kb(&self) -> u32

Returns the value of chrome_peak_resident_set_kb, or the default value if chrome_peak_resident_set_kb is unset.

pub fn smr_rss_kb(&self) -> u64

Returns the value of smr_rss_kb, or the default value if smr_rss_kb is unset.

pub fn smr_pss_kb(&self) -> u64

Returns the value of smr_pss_kb, or the default value if smr_pss_kb is unset.

pub fn smr_pss_anon_kb(&self) -> u64

Returns the value of smr_pss_anon_kb, or the default value if smr_pss_anon_kb is unset.

pub fn smr_pss_file_kb(&self) -> u64

Returns the value of smr_pss_file_kb, or the default value if smr_pss_file_kb is unset.

pub fn smr_pss_shmem_kb(&self) -> u64

Returns the value of smr_pss_shmem_kb, or the default value if smr_pss_shmem_kb is unset.

pub fn runtime_user_mode(&self) -> u64

Returns the value of runtime_user_mode, or the default value if runtime_user_mode is unset.

pub fn runtime_kernel_mode(&self) -> u64

Returns the value of runtime_kernel_mode, or the default value if runtime_kernel_mode is unset.

pub fn smr_swap_pss_kb(&self) -> u64

Returns the value of smr_swap_pss_kb, or the default value if smr_swap_pss_kb is unset.