#[repr(i32)]pub enum Quirks {
Unspecified = 0,
DisableInitialDump = 1,
DisableOnDemand = 2,
}Variants
Unspecified = 0
DisableInitialDump = 1
This has been deprecated and ignored as per 2018-05-01. Full scan at startup is now disabled by default and can be re-enabled using the |scan_all_processes_on_start| arg.
DisableOnDemand = 2
Implementations
Sourceimpl Quirks
impl Quirks
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Quirks>
pub fn from_str_name(value: &str) -> Option<Quirks>
Creates an enum from field names used in the ProtoBuf definition.