pub struct Process {
pub pid: Option<i32>,
pub ppid: Option<i32>,
pub cmdline: Vec<String>,
pub uid: Option<i32>,
pub nspid: Vec<i32>,
pub process_start_from_boot: Option<u64>,
}Expand description
Representation of a process.
Fields
pid: Option<i32>The UNIX process ID, aka thread group ID (as per getpid()) in the root PID namespace.
ppid: Option<i32>The parent process ID, as per getppid().
cmdline: Vec<String>The command line for the process, as per /proc/pid/cmdline. If it is a kernel thread there will only be one cmdline field and it will contain /proc/pid/comm.
uid: Option<i32>The uid for the process, as per /proc/pid/status.
nspid: Vec<i32>The non-root-level process IDs if the process runs in a PID namespace. Read from the NSpid entry of /proc/pid/status, with the first element (root-level process ID) omitted.
process_start_from_boot: Option<u64>Timestamp of when the process was created, in nanoseconds from boot. Parsed from starttime in /proc/pid/stat. Recorded if record_process_age config option is set. Resolution of “clock ticks”, usually 10ms.
Implementations