ProcessHeapSamples

Struct ProcessHeapSamples 

pub struct ProcessHeapSamples {
Show 14 fields pub pid: Option<u64>, pub from_startup: Option<bool>, pub rejected_concurrent: Option<bool>, pub disconnected: Option<bool>, pub buffer_overran: Option<bool>, pub client_error: Option<i32>, pub buffer_corrupted: Option<bool>, pub hit_guardrail: Option<bool>, pub heap_name: Option<String>, pub sampling_interval_bytes: Option<u64>, pub orig_sampling_interval_bytes: Option<u64>, pub timestamp: Option<u64>, pub stats: Option<ProcessStats>, pub samples: Vec<HeapSample>,
}

Fields

pid: Option<u64>from_startup: Option<bool>

This process was profiled from startup. If false, this process was already running when profiling started.

rejected_concurrent: Option<bool>

This process was not profiled because a concurrent session was active. If this is true, samples will be empty.

disconnected: Option<bool>

This process disconnected while it was profiled. If false, the process outlived the profiling session.

buffer_overran: Option<bool>

If disconnected, this disconnect was caused by the client overrunning the buffer. Equivalent to client_error == CLIENT_ERROR_HIT_TIMEOUT on new S builds.

client_error: Option<i32>buffer_corrupted: Option<bool>

If disconnected, this disconnected was caused by the shared memory buffer being corrupted. THIS IS ALWAYS A BUG IN HEAPPROFD OR CLIENT MEMORY CORRUPTION.

hit_guardrail: Option<bool>

If disconnected, this disconnect was caused by heapprofd exceeding guardrails during this profiling session.

heap_name: Option<String>sampling_interval_bytes: Option<u64>orig_sampling_interval_bytes: Option<u64>timestamp: Option<u64>

Timestamp of the state of the target process that this dump represents. This can be different to the timestamp of the TracePackets for various reasons:

  • If disconnected is set above, this is the timestamp of last state heapprofd had of the process before it disconnected.
  • Otherwise, if the rate of events produced by the process is high, heapprofd might be behind.

TODO(fmayer): This is MONOTONIC_COARSE. Refactor ClockSnapshot::Clock to have a type enum that we can reuse here.

stats: Option<ProcessStats>

Metadata about heapprofd.

samples: Vec<HeapSample>

Implementations

Source

impl ProcessHeapSamples

pub fn pid(&self) -> u64

Returns the value of pid, or the default value if pid is unset.

pub fn from_startup(&self) -> bool

Returns the value of from_startup, or the default value if from_startup is unset.

pub fn rejected_concurrent(&self) -> bool

Returns the value of rejected_concurrent, or the default value if rejected_concurrent is unset.

pub fn disconnected(&self) -> bool

Returns the value of disconnected, or the default value if disconnected is unset.

pub fn buffer_overran(&self) -> bool

Returns the value of buffer_overran, or the default value if buffer_overran is unset.

pub fn buffer_corrupted(&self) -> bool

Returns the value of buffer_corrupted, or the default value if buffer_corrupted is unset.

pub fn timestamp(&self) -> u64

Returns the value of timestamp, or the default value if timestamp is unset.

pub fn hit_guardrail(&self) -> bool

Returns the value of hit_guardrail, or the default value if hit_guardrail is unset.

pub fn heap_name(&self) -> &str

Returns the value of heap_name, or the default value if heap_name is unset.

pub fn sampling_interval_bytes(&self) -> u64

Returns the value of sampling_interval_bytes, or the default value if sampling_interval_bytes is unset.

pub fn orig_sampling_interval_bytes(&self) -> u64

Returns the value of orig_sampling_interval_bytes, or the default value if orig_sampling_interval_bytes is unset.

pub fn client_error(&self) -> ClientError

Returns the enum value of client_error, or the default if the field is unset or set to an invalid enum value.

pub fn set_client_error(&mut self, value: ClientError)

Sets client_error to the provided enum value.