#[repr(i32)]pub enum StackUnwindError {
Show 16 variants
UnwindErrorUnknown = 0,
UnwindErrorNone = 1,
UnwindErrorMemoryInvalid = 2,
UnwindErrorUnwindInfo = 3,
UnwindErrorUnsupported = 4,
UnwindErrorInvalidMap = 5,
UnwindErrorMaxFramesExceeded = 6,
UnwindErrorRepeatedFrame = 7,
UnwindErrorInvalidElf = 8,
UnwindErrorSystemCall = 9,
UnwindErrorThreadTimeout = 10,
UnwindErrorThreadDoesNotExist = 11,
UnwindErrorBadArch = 12,
UnwindErrorMapsParse = 13,
UnwindErrorInvalidParameter = 14,
UnwindErrorPtraceCall = 15,
}Expand description
Enumeration of libunwindstack’s error codes. NB: the integral representations of the two enums are different.
Variants
UnwindErrorUnknown = 0
UnwindErrorNone = 1
UnwindErrorMemoryInvalid = 2
UnwindErrorUnwindInfo = 3
UnwindErrorUnsupported = 4
UnwindErrorInvalidMap = 5
UnwindErrorMaxFramesExceeded = 6
UnwindErrorRepeatedFrame = 7
UnwindErrorInvalidElf = 8
UnwindErrorSystemCall = 9
UnwindErrorThreadTimeout = 10
UnwindErrorThreadDoesNotExist = 11
UnwindErrorBadArch = 12
UnwindErrorMapsParse = 13
UnwindErrorInvalidParameter = 14
UnwindErrorPtraceCall = 15
Implementations
Sourceimpl StackUnwindError
impl StackUnwindError
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<StackUnwindError>
pub fn from_str_name(value: &str) -> Option<StackUnwindError>
Creates an enum from field names used in the ProtoBuf definition.