#[repr(i32)]pub enum TracingMode {
Default = 0,
EnableAll = 1,
}Variants
Default = 0
When using the DEFAULT tracing mode, only log groups and levels specified in the group_overrides are traced.
EnableAll = 1
When using the ENABLE_ALL tracing mode, all log groups and levels are traced, unless specified in the group_overrides.
Implementations
Sourceimpl TracingMode
impl TracingMode
Sourceimpl TracingMode
impl TracingMode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<TracingMode>
pub fn from_str_name(value: &str) -> Option<TracingMode>
Creates an enum from field names used in the ProtoBuf definition.