pub struct MessageData {
pub message_id: Option<u64>,
pub message: Option<String>,
pub level: Option<i32>,
pub group_id: Option<u32>,
}Fields
message_id: Option<u64>the id of the message that is logged in a ProtoLogMessage
message: Option<String>the string representation of the message
level: Option<i32>the level of the message
group_id: Option<u32>the id of the log group this message belongs to
Implementations
Sourceimpl MessageData
impl MessageData
Sourcepub fn message_id(&self) -> u64
pub fn message_id(&self) -> u64
Returns the value of message_id, or the default value if message_id is unset.
Sourcepub fn message(&self) -> &str
pub fn message(&self) -> &str
Returns the value of message, or the default value if message is unset.
Sourcepub fn level(&self) -> ProtoLogLevel
pub fn level(&self) -> ProtoLogLevel
Returns the enum value of level, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_level(&mut self, value: ProtoLogLevel)
pub fn set_level(&mut self, value: ProtoLogLevel)
Sets level to the provided enum value.