#[repr(i32)]pub enum AdjustReason {
IgnoreTheIncrement = 0,
ApplyIncrement = 1,
ApplyIncrementBoost = 2,
}Expand description
The reason for the priority boost. The ordering is important as based on the AdjustReason definition from the link above.
Variants
IgnoreTheIncrement = 0
ApplyIncrement = 1
Apply the increment, which will decay incrementally at the end of each quantum.
ApplyIncrementBoost = 2
Apply the increment as a boost that will decay in its entirety at quantum (typically for priority donation).
Implementations
Sourceimpl AdjustReason
impl AdjustReason
Sourceimpl AdjustReason
impl AdjustReason
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<AdjustReason>
pub fn from_str_name(value: &str) -> Option<AdjustReason>
Creates an enum from field names used in the ProtoBuf definition.