pub struct ActiveBufferProto {
pub width: Option<u32>,
pub height: Option<u32>,
pub stride: Option<u32>,
pub format: Option<i32>,
pub usage: Option<u64>,
}Fields
width: Option<u32>height: Option<u32>stride: Option<u32>format: Option<i32>usage: Option<u64>Implementations
Sourceimpl ActiveBufferProto
impl ActiveBufferProto
Sourcepub fn height(&self) -> u32
pub fn height(&self) -> u32
Returns the value of height, or the default value if height is unset.
Sourcepub fn stride(&self) -> u32
pub fn stride(&self) -> u32
Returns the value of stride, or the default value if stride is unset.