pub struct AndroidEnergyConsumer {
pub energy_consumer_id: Option<i32>,
pub ordinal: Option<i32>,
pub type: Option<String>,
pub name: Option<String>,
}Expand description
Energy consumer based on aidl class: android.hardware.power.stats.EnergyConsumer.
Fields
energy_consumer_id: Option<i32>Unique ID of this energy consumer. Matches the ID in a AndroidEnergyEstimationBreakdown.
ordinal: Option<i32>For a group of energy consumers of the same logical type, sorting by ordinal gives their physical order. Ordinals must be consecutive integers starting from 0.
type: Option<String>Type of this energy consumer.
name: Option<String>Unique name of this energy consumer. Vendor/device specific. Opaque to framework.
Implementations
Sourceimpl AndroidEnergyConsumer
impl AndroidEnergyConsumer