pub struct AndroidFsDatawriteStartFtraceEvent {
pub bytes: Option<i32>,
pub cmdline: Option<String>,
pub i_size: Option<i64>,
pub ino: Option<u64>,
pub offset: Option<i64>,
pub pathbuf: Option<String>,
pub pid: Option<i32>,
}Fields
bytes: Option<i32>cmdline: Option<String>i_size: Option<i64>ino: Option<u64>offset: Option<i64>pathbuf: Option<String>pid: Option<i32>Implementations
Sourceimpl AndroidFsDatawriteStartFtraceEvent
impl AndroidFsDatawriteStartFtraceEvent
Sourcepub fn cmdline(&self) -> &str
pub fn cmdline(&self) -> &str
Returns the value of cmdline, or the default value if cmdline is unset.
Sourcepub fn i_size(&self) -> i64
pub fn i_size(&self) -> i64
Returns the value of i_size, or the default value if i_size is unset.
Sourcepub fn offset(&self) -> i64
pub fn offset(&self) -> i64
Returns the value of offset, or the default value if offset is unset.