pub struct AndroidGameInterventionListConfig {
pub package_name_filter: Vec<String>,
}Expand description
Data source that lists game modes and game interventions of games on an Android device.
Fields
package_name_filter: Vec<String>If not empty, emit info about only the following list of package names (exact match, no regex). Otherwise, emit info about all packages.