pub struct AndroidPowerConfig {
pub battery_poll_ms: Option<u32>,
pub battery_counters: Vec<i32>,
pub collect_power_rails: Option<bool>,
pub collect_energy_estimation_breakdown: Option<bool>,
pub collect_entity_state_residency: Option<bool>,
}Fields
battery_poll_ms: Option<u32>battery_counters: Vec<i32>collect_power_rails: Option<bool>Where available enables per-power-rail measurements.
collect_energy_estimation_breakdown: Option<bool>Provides a breakdown of energy estimation for various subsystem (e.g. GPU). Available from Android S.
collect_entity_state_residency: Option<bool>Provides a breakdown of time in state for various subsystems. Available from Android U.
Implementations
Sourceimpl AndroidPowerConfig
impl AndroidPowerConfig
Sourcepub fn battery_poll_ms(&self) -> u32
pub fn battery_poll_ms(&self) -> u32
Returns the value of battery_poll_ms, or the default value if battery_poll_ms is unset.
Sourcepub fn battery_counters(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<BatteryCounters>>
pub fn battery_counters( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<BatteryCounters>>
Returns an iterator which yields the valid enum values contained in battery_counters.
Sourcepub fn push_battery_counters(&mut self, value: BatteryCounters)
pub fn push_battery_counters(&mut self, value: BatteryCounters)
Appends the provided enum value to battery_counters.
Sourcepub fn collect_power_rails(&self) -> bool
pub fn collect_power_rails(&self) -> bool
Returns the value of collect_power_rails, or the default value if collect_power_rails is unset.
Sourcepub fn collect_energy_estimation_breakdown(&self) -> bool
pub fn collect_energy_estimation_breakdown(&self) -> bool
Returns the value of collect_energy_estimation_breakdown, or the default value if collect_energy_estimation_breakdown is unset.
Sourcepub fn collect_entity_state_residency(&self) -> bool
pub fn collect_entity_state_residency(&self) -> bool
Returns the value of collect_entity_state_residency, or the default value if collect_entity_state_residency is unset.