pub struct BackgroundTracingMetadata {
pub triggered_rule: Option<TriggerRule>,
pub active_rules: Vec<TriggerRule>,
pub scenario_name_hash: Option<u32>,
}Expand description
Metadata related to background tracing scenarios, states and triggers.
Fields
triggered_rule: Option<TriggerRule>Specifies the rule that caused the trace to be uploaded.
active_rules: Vec<TriggerRule>List of all active triggers in current session, when trace was triggered.
scenario_name_hash: Option<u32>Hash of the scenario name.
Implementations
Sourceimpl BackgroundTracingMetadata
impl BackgroundTracingMetadata
Sourcepub fn scenario_name_hash(&self) -> u32
pub fn scenario_name_hash(&self) -> u32
Returns the value of scenario_name_hash, or the default value if scenario_name_hash is unset.