pub struct BatteryCounters {
pub charge_counter_uah: Option<i64>,
pub capacity_percent: Option<f32>,
pub current_ua: Option<i64>,
pub current_avg_ua: Option<i64>,
pub name: Option<String>,
pub energy_counter_uwh: Option<i64>,
pub voltage_uv: Option<i64>,
}Fields
charge_counter_uah: Option<i64>Battery capacity in microampere-hours(µAh). Also known as Coulomb counter.
capacity_percent: Option<f32>Remaining battery capacity percentage of total capacity
current_ua: Option<i64>Instantaneous battery current in microamperes(µA). Negative values indicate current being drained from the battery and positive values indicate current feeding the battery from a charge source (USB).
See https://perfetto.dev/docs/data-sources/battery-counters for more info.
current_avg_ua: Option<i64>Instantaneous battery current in microamperes(µA).
name: Option<String>Battery name, emitted only on multiple batteries.
energy_counter_uwh: Option<i64>Battery capacity in microwatt-hours(µWh).
voltage_uv: Option<i64>Battery voltage in microvolts(µV).
Implementations
Sourceimpl BatteryCounters
impl BatteryCounters
Sourcepub fn charge_counter_uah(&self) -> i64
pub fn charge_counter_uah(&self) -> i64
Returns the value of charge_counter_uah, or the default value if charge_counter_uah is unset.
Sourcepub fn capacity_percent(&self) -> f32
pub fn capacity_percent(&self) -> f32
Returns the value of capacity_percent, or the default value if capacity_percent is unset.
Sourcepub fn current_ua(&self) -> i64
pub fn current_ua(&self) -> i64
Returns the value of current_ua, or the default value if current_ua is unset.
Sourcepub fn current_avg_ua(&self) -> i64
pub fn current_avg_ua(&self) -> i64
Returns the value of current_avg_ua, or the default value if current_avg_ua is unset.
Sourcepub fn energy_counter_uwh(&self) -> i64
pub fn energy_counter_uwh(&self) -> i64
Returns the value of energy_counter_uwh, or the default value if energy_counter_uwh is unset.
Sourcepub fn voltage_uv(&self) -> i64
pub fn voltage_uv(&self) -> i64
Returns the value of voltage_uv, or the default value if voltage_uv is unset.