BlurRegion

Struct BlurRegion 

pub struct BlurRegion {
    pub blur_radius: Option<u32>,
    pub corner_radius_tl: Option<u32>,
    pub corner_radius_tr: Option<u32>,
    pub corner_radius_bl: Option<u32>,
    pub corner_radius_br: Option<f32>,
    pub alpha: Option<f32>,
    pub left: Option<i32>,
    pub top: Option<i32>,
    pub right: Option<i32>,
    pub bottom: Option<i32>,
}

Fields

blur_radius: Option<u32>corner_radius_tl: Option<u32>corner_radius_tr: Option<u32>corner_radius_bl: Option<u32>corner_radius_br: Option<f32>alpha: Option<f32>left: Option<i32>top: Option<i32>right: Option<i32>bottom: Option<i32>

Implementations

Source

impl BlurRegion

pub fn blur_radius(&self) -> u32

Returns the value of blur_radius, or the default value if blur_radius is unset.

pub fn corner_radius_tl(&self) -> u32

Returns the value of corner_radius_tl, or the default value if corner_radius_tl is unset.

pub fn corner_radius_tr(&self) -> u32

Returns the value of corner_radius_tr, or the default value if corner_radius_tr is unset.

pub fn corner_radius_bl(&self) -> u32

Returns the value of corner_radius_bl, or the default value if corner_radius_bl is unset.

pub fn corner_radius_br(&self) -> f32

Returns the value of corner_radius_br, or the default value if corner_radius_br is unset.

pub fn alpha(&self) -> f32

Returns the value of alpha, or the default value if alpha is unset.

pub fn left(&self) -> i32

Returns the value of left, or the default value if left is unset.

pub fn top(&self) -> i32

Returns the value of top, or the default value if top is unset.

pub fn right(&self) -> i32

Returns the value of right, or the default value if right is unset.

pub fn bottom(&self) -> i32

Returns the value of bottom, or the default value if bottom is unset.