pub struct ChromeLatencyInfo {
pub trace_id: Option<i64>,
pub step: Option<i32>,
pub frame_tree_node_id: Option<i32>,
pub component_info: Vec<ComponentInfo>,
pub is_coalesced: Option<bool>,
pub gesture_scroll_id: Option<i64>,
pub touch_id: Option<i64>,
}Fields
trace_id: Option<i64>step: Option<i32>frame_tree_node_id: Option<i32>component_info: Vec<ComponentInfo>is_coalesced: Option<bool>gesture_scroll_id: Option<i64>touch_id: Option<i64>Implementations
Sourceimpl ChromeLatencyInfo
impl ChromeLatencyInfo
Sourcepub fn trace_id(&self) -> i64
pub fn trace_id(&self) -> i64
Returns the value of trace_id, or the default value if trace_id is unset.
Sourcepub fn step(&self) -> Step
pub fn step(&self) -> Step
Returns the enum value of step, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn frame_tree_node_id(&self) -> i32
pub fn frame_tree_node_id(&self) -> i32
Returns the value of frame_tree_node_id, or the default value if frame_tree_node_id is unset.
Sourcepub fn is_coalesced(&self) -> bool
pub fn is_coalesced(&self) -> bool
Returns the value of is_coalesced, or the default value if is_coalesced is unset.
Sourcepub fn gesture_scroll_id(&self) -> i64
pub fn gesture_scroll_id(&self) -> i64
Returns the value of gesture_scroll_id, or the default value if gesture_scroll_id is unset.