pub struct ChromeLegacyJsonTrace {
pub type: Option<i32>,
pub data: Option<String>,
}Expand description
Subtraces produced in legacy json format by Chrome tracing agents not yet updated to support the new binary format, e.g. ETW and CrOS ARC. TODO(eseckler): Update these agents to become perfetto producers.
Fields
type: Option<i32>data: Option<String>Implementations