pub struct ChromePerformanceMarkTranslationTable {
pub site_hash_to_name: HashMap<u32, String>,
pub mark_hash_to_name: HashMap<u32, String>,
}Expand description
Chrome performance mark translation rules.
Fields
site_hash_to_name: HashMap<u32, String>mark_hash_to_name: HashMap<u32, String>Trait Implementations
Sourceimpl Clone for ChromePerformanceMarkTranslationTable
impl Clone for ChromePerformanceMarkTranslationTable
Sourcefn clone(&self) -> ChromePerformanceMarkTranslationTable
fn clone(&self) -> ChromePerformanceMarkTranslationTable
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ChromePerformanceMarkTranslationTable
impl Default for ChromePerformanceMarkTranslationTable
Sourcefn default() -> ChromePerformanceMarkTranslationTable
fn default() -> ChromePerformanceMarkTranslationTable
Returns the “default value” for a type. Read more
Sourceimpl Message for ChromePerformanceMarkTranslationTable
impl Message for ChromePerformanceMarkTranslationTable
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ChromePerformanceMarkTranslationTable
impl PartialEq for ChromePerformanceMarkTranslationTable
Sourcefn eq(&self, other: &ChromePerformanceMarkTranslationTable) -> bool
fn eq(&self, other: &ChromePerformanceMarkTranslationTable) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ChromePerformanceMarkTranslationTable