pub struct ChromeProcessDescriptor {
pub process_type: Option<i32>,
pub process_priority: Option<i32>,
pub legacy_sort_index: Option<i32>,
pub host_app_package_name: Option<String>,
pub crash_trace_id: Option<u64>,
}Expand description
Describes the attributes for a Chrome process. Must be paired with a ProcessDescriptor in the same TrackDescriptor.
Next id: 6.
Fields
process_type: Option<i32>process_priority: Option<i32>legacy_sort_index: Option<i32>To support old UI. New UI should determine default sorting by process_type.
host_app_package_name: Option<String>Name of the hosting app for WebView. Used to match renderer processes to their hosting apps.
crash_trace_id: Option<u64>The ID to link crashes to trace. Notes:
- The ID is per process. So, each trace may contain many IDs, and you need to look for the ID from crashed process to find the crash report.
- Having a “chrome-trace-id” in crash doesn’t necessarily mean we can get an uploaded trace, since uploads could have failed.
- On the other hand, if there was a crash during the session and trace was uploaded, it is very likely to find a crash report with the trace ID.
- This is not crash ID or trace ID. It is just a random 64-bit number recorded in both traces and crashes. It is possible to have collisions, though very rare.
Implementations
Sourceimpl ChromeProcessDescriptor
impl ChromeProcessDescriptor
Sourcepub fn process_type(&self) -> ProcessType
pub fn process_type(&self) -> ProcessType
Returns the enum value of process_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_process_type(&mut self, value: ProcessType)
pub fn set_process_type(&mut self, value: ProcessType)
Sets process_type to the provided enum value.
Sourcepub fn process_priority(&self) -> i32
pub fn process_priority(&self) -> i32
Returns the value of process_priority, or the default value if process_priority is unset.
Sourcepub fn legacy_sort_index(&self) -> i32
pub fn legacy_sort_index(&self) -> i32
Returns the value of legacy_sort_index, or the default value if legacy_sort_index is unset.
Sourcepub fn host_app_package_name(&self) -> &str
pub fn host_app_package_name(&self) -> &str
Returns the value of host_app_package_name, or the default value if host_app_package_name is unset.
Sourcepub fn crash_trace_id(&self) -> u64
pub fn crash_trace_id(&self) -> u64
Returns the value of crash_trace_id, or the default value if crash_trace_id is unset.