pub struct ChromeTraceEvent {Show 16 fields
pub name: Option<String>,
pub timestamp: Option<i64>,
pub phase: Option<i32>,
pub thread_id: Option<i32>,
pub duration: Option<i64>,
pub thread_duration: Option<i64>,
pub scope: Option<String>,
pub id: Option<u64>,
pub flags: Option<u32>,
pub category_group_name: Option<String>,
pub process_id: Option<i32>,
pub thread_timestamp: Option<i64>,
pub bind_id: Option<u64>,
pub args: Vec<Arg>,
pub name_index: Option<u32>,
pub category_group_name_index: Option<u32>,
}Expand description
Deprecated, use TrackEvent protos instead.
Fields
name: Option<String>timestamp: Option<i64>phase: Option<i32>thread_id: Option<i32>duration: Option<i64>thread_duration: Option<i64>scope: Option<String>id: Option<u64>flags: Option<u32>category_group_name: Option<String>process_id: Option<i32>thread_timestamp: Option<i64>bind_id: Option<u64>args: Vec<Arg>name_index: Option<u32>Takes precedence over respectively |name| and |category_group_name_index| if set, and are indices into |string_table|.
category_group_name_index: Option<u32>Implementations
Sourceimpl ChromeTraceEvent
impl ChromeTraceEvent
Sourcepub fn timestamp(&self) -> i64
pub fn timestamp(&self) -> i64
Returns the value of timestamp, or the default value if timestamp is unset.
Sourcepub fn thread_id(&self) -> i32
pub fn thread_id(&self) -> i32
Returns the value of thread_id, or the default value if thread_id is unset.
Sourcepub fn duration(&self) -> i64
pub fn duration(&self) -> i64
Returns the value of duration, or the default value if duration is unset.
Sourcepub fn thread_duration(&self) -> i64
pub fn thread_duration(&self) -> i64
Returns the value of thread_duration, or the default value if thread_duration is unset.
Sourcepub fn scope(&self) -> &str
pub fn scope(&self) -> &str
Returns the value of scope, or the default value if scope is unset.
Sourcepub fn category_group_name(&self) -> &str
pub fn category_group_name(&self) -> &str
Returns the value of category_group_name, or the default value if category_group_name is unset.
Sourcepub fn process_id(&self) -> i32
pub fn process_id(&self) -> i32
Returns the value of process_id, or the default value if process_id is unset.
Sourcepub fn thread_timestamp(&self) -> i64
pub fn thread_timestamp(&self) -> i64
Returns the value of thread_timestamp, or the default value if thread_timestamp is unset.
Sourcepub fn bind_id(&self) -> u64
pub fn bind_id(&self) -> u64
Returns the value of bind_id, or the default value if bind_id is unset.
Sourcepub fn name_index(&self) -> u32
pub fn name_index(&self) -> u32
Returns the value of name_index, or the default value if name_index is unset.
Sourcepub fn category_group_name_index(&self) -> u32
pub fn category_group_name_index(&self) -> u32
Returns the value of category_group_name_index, or the default value if category_group_name_index is unset.