pub struct ChromeTrigger {
pub trigger_name: Option<String>,
pub trigger_name_hash: Option<u32>,
}Expand description
Information about a specific trigger during a background tracing scenario Associated packet timestamps are useful to delimitate a scenario range in a trace. Triggers are also useful for filtering traces.
Fields
trigger_name: Option<String>Name of the trigger which was received.
trigger_name_hash: Option<u32>SHA1 hash of the trigger name.
Implementations
Sourceimpl ChromeTrigger
impl ChromeTrigger
Sourcepub fn trigger_name(&self) -> &str
pub fn trigger_name(&self) -> &str
Returns the value of trigger_name, or the default value if trigger_name is unset.
Sourcepub fn trigger_name_hash(&self) -> u32
pub fn trigger_name_hash(&self) -> u32
Returns the value of trigger_name_hash, or the default value if trigger_name_hash is unset.