pub struct ChromeUserEvent {
pub action: Option<String>,
pub action_hash: Option<u64>,
}Expand description
Details about a UI interaction initiated by the user, such as opening or closing a tab or a context menu.
Fields
action: Option<String>Name of the action, e.g. “NewTab”, “ShowBookmarkManager”, etc. (in Chrome, these are usually static strings known at compile time, or concatenations of multiple such static strings).
action_hash: Option<u64>MD5 hash of the action string.
Implementations