pub struct ClockSnapshot {
pub clocks: Vec<Clock>,
pub primary_trace_clock: Option<i32>,
}Expand description
A snapshot of clock readings to allow for trace alignment.
Fields
clocks: Vec<Clock>primary_trace_clock: Option<i32>The authoritative clock domain for the trace. Defaults to BOOTTIME, but can be overridden in TraceConfig’s builtin_data_sources. Trace processor will attempt to translate packet/event timestamps from various data sources (and their chosen clock domains) to this domain during import.
Implementations
Sourceimpl ClockSnapshot
impl ClockSnapshot
Sourcepub fn primary_trace_clock(&self) -> BuiltinClock
pub fn primary_trace_clock(&self) -> BuiltinClock
Returns the enum value of primary_trace_clock, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_primary_trace_clock(&mut self, value: BuiltinClock)
pub fn set_primary_trace_clock(&mut self, value: BuiltinClock)
Sets primary_trace_clock to the provided enum value.