pub struct EtwConfig {
pub kernel_flags: Vec<i32>,
}Expand description
Proto definition based on the struct _EVENT_TRACE_PROPERTIES definition See: https://learn.microsoft.com/en-us/windows/win32/api/evntrace/ ns-evntrace-event_trace_properties
Fields
kernel_flags: Vec<i32>The kernel_flags determines the flags that will be used by the etw tracing session. These kernel flags have been built to expose the useful events captured from the kernel mode only.
Implementations
Sourceimpl EtwConfig
impl EtwConfig
Sourcepub fn kernel_flags(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<KernelFlag>>
pub fn kernel_flags( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<KernelFlag>>
Returns an iterator which yields the valid enum values contained in kernel_flags.
Sourcepub fn push_kernel_flags(&mut self, value: KernelFlag)
pub fn push_kernel_flags(&mut self, value: KernelFlag)
Appends the provided enum value to kernel_flags.