pub struct EtwTraceEventBundle {
pub cpu: Option<u32>,
pub event: Vec<EtwTraceEvent>,
}Expand description
The result of tracing one or more etw event uses per-processor buffers where an in-use buffer is assigned to each processor at all times. Therefore, collecting multiple events they should already be synchronized.
Fields
cpu: Option<u32>event: Vec<EtwTraceEvent>Implementations