Ext4DaWritePagesFtraceEvent

Struct Ext4DaWritePagesFtraceEvent 

pub struct Ext4DaWritePagesFtraceEvent {
    pub dev: Option<u64>,
    pub ino: Option<u64>,
    pub first_page: Option<u64>,
    pub nr_to_write: Option<i64>,
    pub sync_mode: Option<i32>,
    pub b_blocknr: Option<u64>,
    pub b_size: Option<u32>,
    pub b_state: Option<u32>,
    pub io_done: Option<i32>,
    pub pages_written: Option<i32>,
}

Fields

dev: Option<u64>ino: Option<u64>first_page: Option<u64>nr_to_write: Option<i64>sync_mode: Option<i32>b_blocknr: Option<u64>b_size: Option<u32>b_state: Option<u32>io_done: Option<i32>pages_written: Option<i32>

Implementations

Source

impl Ext4DaWritePagesFtraceEvent

pub fn dev(&self) -> u64

Returns the value of dev, or the default value if dev is unset.

pub fn ino(&self) -> u64

Returns the value of ino, or the default value if ino is unset.

pub fn first_page(&self) -> u64

Returns the value of first_page, or the default value if first_page is unset.

pub fn nr_to_write(&self) -> i64

Returns the value of nr_to_write, or the default value if nr_to_write is unset.

pub fn sync_mode(&self) -> i32

Returns the value of sync_mode, or the default value if sync_mode is unset.

pub fn b_blocknr(&self) -> u64

Returns the value of b_blocknr, or the default value if b_blocknr is unset.

pub fn b_size(&self) -> u32

Returns the value of b_size, or the default value if b_size is unset.

pub fn b_state(&self) -> u32

Returns the value of b_state, or the default value if b_state is unset.

pub fn io_done(&self) -> i32

Returns the value of io_done, or the default value if io_done is unset.

pub fn pages_written(&self) -> i32

Returns the value of pages_written, or the default value if pages_written is unset.