Ext4MballocPreallocFtraceEvent

Struct Ext4MballocPreallocFtraceEvent 

pub struct Ext4MballocPreallocFtraceEvent {
    pub dev: Option<u64>,
    pub ino: Option<u64>,
    pub orig_logical: Option<u32>,
    pub orig_start: Option<i32>,
    pub orig_group: Option<u32>,
    pub orig_len: Option<i32>,
    pub result_logical: Option<u32>,
    pub result_start: Option<i32>,
    pub result_group: Option<u32>,
    pub result_len: Option<i32>,
}

Fields

dev: Option<u64>ino: Option<u64>orig_logical: Option<u32>orig_start: Option<i32>orig_group: Option<u32>orig_len: Option<i32>result_logical: Option<u32>result_start: Option<i32>result_group: Option<u32>result_len: Option<i32>

Implementations

Source

impl Ext4MballocPreallocFtraceEvent

pub fn dev(&self) -> u64

Returns the value of dev, or the default value if dev is unset.

pub fn ino(&self) -> u64

Returns the value of ino, or the default value if ino is unset.

pub fn orig_logical(&self) -> u32

Returns the value of orig_logical, or the default value if orig_logical is unset.

pub fn orig_start(&self) -> i32

Returns the value of orig_start, or the default value if orig_start is unset.

pub fn orig_group(&self) -> u32

Returns the value of orig_group, or the default value if orig_group is unset.

pub fn orig_len(&self) -> i32

Returns the value of orig_len, or the default value if orig_len is unset.

pub fn result_logical(&self) -> u32

Returns the value of result_logical, or the default value if result_logical is unset.

pub fn result_start(&self) -> i32

Returns the value of result_start, or the default value if result_start is unset.

pub fn result_group(&self) -> u32

Returns the value of result_group, or the default value if result_group is unset.

pub fn result_len(&self) -> i32

Returns the value of result_len, or the default value if result_len is unset.