pub struct FrameTimelineEvent {
pub event: Option<Event>,
}Expand description
Generated by SurfaceFlinger’s FrameTimeline (go/adaptive-scheduling-fr). Used in comparing the expected timeline of a frame to the actual timeline. Key terms: 1) DisplayFrame - represents SurfaceFlinger’s work on a frame(composited) 2) SurfaceFrame - represents App’s work on its frame 3) Timeline = start to end of a component’s(app/SF) work on a frame. SurfaceFlinger composites frames from many apps together, so One DisplayFrame can map to N SurfaceFrame(s) This relationship can be reconstructed by using DisplayFrame.token = SurfaceFrame.display_frame_token
Fields
event: Option<Event>Trait Implementations
Sourceimpl Clone for FrameTimelineEvent
impl Clone for FrameTimelineEvent
Sourcefn clone(&self) -> FrameTimelineEvent
fn clone(&self) -> FrameTimelineEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FrameTimelineEvent
impl Debug for FrameTimelineEvent
Sourceimpl Default for FrameTimelineEvent
impl Default for FrameTimelineEvent
Sourcefn default() -> FrameTimelineEvent
fn default() -> FrameTimelineEvent
Returns the “default value” for a type. Read more
Sourceimpl Message for FrameTimelineEvent
impl Message for FrameTimelineEvent
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for FrameTimelineEvent
impl PartialEq for FrameTimelineEvent
impl StructuralPartialEq for FrameTimelineEvent