pub struct GenericFtraceEvent {
pub event_name: Option<String>,
pub field: Vec<Field>,
}Expand description
This generic proto is used to output events in the trace when a specific proto for that event does not exist.
Fields
event_name: Option<String>field: Vec<Field>Implementations
Sourceimpl GenericFtraceEvent
impl GenericFtraceEvent
Sourcepub fn event_name(&self) -> &str
pub fn event_name(&self) -> &str
Returns the value of event_name, or the default value if event_name is unset.