pub struct GpuCounterDescriptor {
pub specs: Vec<GpuCounterSpec>,
pub blocks: Vec<GpuCounterBlock>,
pub min_sampling_period_ns: Option<u64>,
pub max_sampling_period_ns: Option<u64>,
pub supports_instrumented_sampling: Option<bool>,
}Expand description
Description of GPU counters. This message is sent by a GPU counter producer to specify the counters available in the hardware.
Fields
specs: Vec<GpuCounterSpec>blocks: Vec<GpuCounterBlock>min_sampling_period_ns: Option<u64>optional. Minimum sampling period supported by the producer in nanoseconds.
max_sampling_period_ns: Option<u64>optional. Maximum sampling period supported by the producer in nanoseconds.
supports_instrumented_sampling: Option<bool>optional. The producer supports counter sampling by instrumenting the command buffer.
Implementations
Sourceimpl GpuCounterDescriptor
impl GpuCounterDescriptor
Sourcepub fn min_sampling_period_ns(&self) -> u64
pub fn min_sampling_period_ns(&self) -> u64
Returns the value of min_sampling_period_ns, or the default value if min_sampling_period_ns is unset.
Sourcepub fn max_sampling_period_ns(&self) -> u64
pub fn max_sampling_period_ns(&self) -> u64
Returns the value of max_sampling_period_ns, or the default value if max_sampling_period_ns is unset.
Sourcepub fn supports_instrumented_sampling(&self) -> bool
pub fn supports_instrumented_sampling(&self) -> bool
Returns the value of supports_instrumented_sampling, or the default value if supports_instrumented_sampling is unset.