pub struct GpuRenderStageEvent {Show 15 fields
pub event_id: Option<u64>,
pub duration: Option<u64>,
pub hw_queue_iid: Option<u64>,
pub stage_iid: Option<u64>,
pub gpu_id: Option<i32>,
pub context: Option<u64>,
pub render_target_handle: Option<u64>,
pub submission_id: Option<u32>,
pub extra_data: Vec<ExtraData>,
pub render_pass_handle: Option<u64>,
pub render_subpass_index_mask: Vec<u64>,
pub command_buffer_handle: Option<u64>,
pub specifications: Option<Specifications>,
pub hw_queue_id: Option<i32>,
pub stage_id: Option<i32>,
}Expand description
next id: 15
Fields
event_id: Option<u64>required. Unique ID for the event.
duration: Option<u64>optional. Duration of the event in nanoseconds. If unset, this is a single time point event.
hw_queue_iid: Option<u64>required. ID to a hardware queue description in the specifications. InternedGpuRenderStageSpecification
stage_iid: Option<u64>required. ID to a render stage description in the specifications. InternedGpuRenderStageSpecification
gpu_id: Option<i32>optional. Identifier for GPU in a multi-gpu device.
context: Option<u64>required. Graphics context for the event. For OpenGL, this is the GL context. For Vulkan, this is the VkDevice.
render_target_handle: Option<u64>optional. The render target for this event. For OpenGL, this is the GL frame buffer handle. For Vulkan, this is the VkFrameBuffer handle.
submission_id: Option<u32>optional. Submission ID generated by the UMD. For OpenGL, the ID should map to an API submission (e.g., glFlush, glFinish, eglSwapBufffers) event. The set of submissions to the HW due to a single API submission should share the same ID. For Vulkan, it should map 1:1 with a vkQueueSubmit.
extra_data: Vec<ExtraData>render_pass_handle: Option<u64>optional. The Vulkan render pass handle.
render_subpass_index_mask: Vec<u64>optional. A bit mask representing which render subpasses contributed to this render stage event. Subpass index 0 is represented by setting the LSB of the mask. Additional mask can be added for subpass index greater than 63.
command_buffer_handle: Option<u64>optional. The Vulkan command buffer handle.
specifications: Option<Specifications>Deprecated. Use hw_queue_iid and stage_iid to refer to InternedGpuRenderStageSpecification instead.
hw_queue_id: Option<i32>Deprecated. Use hw_queue_iid instead;
stage_id: Option<i32>Deprecated. Use stage_iid instead;
Implementations
Sourceimpl GpuRenderStageEvent
impl GpuRenderStageEvent
Sourcepub fn event_id(&self) -> u64
pub fn event_id(&self) -> u64
Returns the value of event_id, or the default value if event_id is unset.
Sourcepub fn duration(&self) -> u64
pub fn duration(&self) -> u64
Returns the value of duration, or the default value if duration is unset.
Sourcepub fn hw_queue_id(&self) -> i32
pub fn hw_queue_id(&self) -> i32
Returns the value of hw_queue_id, or the default value if hw_queue_id is unset.
Sourcepub fn stage_id(&self) -> i32
pub fn stage_id(&self) -> i32
Returns the value of stage_id, or the default value if stage_id is unset.
Sourcepub fn context(&self) -> u64
pub fn context(&self) -> u64
Returns the value of context, or the default value if context is unset.
Sourcepub fn render_target_handle(&self) -> u64
pub fn render_target_handle(&self) -> u64
Returns the value of render_target_handle, or the default value if render_target_handle is unset.
Sourcepub fn render_pass_handle(&self) -> u64
pub fn render_pass_handle(&self) -> u64
Returns the value of render_pass_handle, or the default value if render_pass_handle is unset.
Sourcepub fn submission_id(&self) -> u32
pub fn submission_id(&self) -> u32
Returns the value of submission_id, or the default value if submission_id is unset.
Sourcepub fn gpu_id(&self) -> i32
pub fn gpu_id(&self) -> i32
Returns the value of gpu_id, or the default value if gpu_id is unset.
Sourcepub fn command_buffer_handle(&self) -> u64
pub fn command_buffer_handle(&self) -> u64
Returns the value of command_buffer_handle, or the default value if command_buffer_handle is unset.
Sourcepub fn hw_queue_iid(&self) -> u64
pub fn hw_queue_iid(&self) -> u64
Returns the value of hw_queue_iid, or the default value if hw_queue_iid is unset.