pub struct HeapGraph {
pub pid: Option<i32>,
pub objects: Vec<HeapGraphObject>,
pub roots: Vec<HeapGraphRoot>,
pub types: Vec<HeapGraphType>,
pub field_names: Vec<InternedString>,
pub location_names: Vec<InternedString>,
pub continued: Option<bool>,
pub index: Option<u64>,
}Fields
pid: Option<i32>objects: Vec<HeapGraphObject>This contains all objects at the time this dump was taken. Some of these will be live, some of those unreachable (garbage). To find the live objects, the client needs to build the transitive closure of objects reachable from |roots|. All objects not contained within that transitive closure are garbage that has not yet been collected.
roots: Vec<HeapGraphRoot>Roots at the time this dump was taken. All live objects are reachable from the roots. All other objects are garbage.
types: Vec<HeapGraphType>Types used in HeapGraphObjects.
field_names: Vec<InternedString>Field names for references in managed heap graph.
location_names: Vec<InternedString>Paths of files used in managed heap graph.
continued: Option<bool>index: Option<u64>Implementations