pub struct HeapGraphObject {
pub type_id: Option<u64>,
pub self_size: Option<u64>,
pub reference_field_id_base: Option<u64>,
pub reference_field_id: Vec<u64>,
pub reference_object_id: Vec<u64>,
pub native_allocation_registry_size_field: Option<i64>,
pub identifier: Option<Identifier>,
}Fields
type_id: Option<u64>Index for InternedData.types for the name of the type of this object.
self_size: Option<u64>Bytes occupied by this objects.
reference_field_id_base: Option<u64>Add this to all non-zero values in reference_object_id. This is used to get more compact varint encoding.
The name is confusing, but this has always been used as a base for reference_object_id. The field should be named reference_object_id_base.
reference_field_id: Vec<u64>Indices for InternedData.field_names for the name of the field referring to the object. For Android S+ and for instances of normal classes (e.g. not instances of java.lang.Class or arrays), this is instead set in the corresponding HeapGraphType, and this is left empty.
reference_object_id: Vec<u64>Ids of the Object that is referred to.
native_allocation_registry_size_field: Option<i64>If this object is an instance of libcore.util.NativeAllocationRegistry,
the value of the size field.
N.B. This is not the native size of this object.
identifier: Option<Identifier>Implementations
Sourceimpl HeapGraphObject
impl HeapGraphObject
Sourcepub fn type_id(&self) -> u64
pub fn type_id(&self) -> u64
Returns the value of type_id, or the default value if type_id is unset.
Sourcepub fn self_size(&self) -> u64
pub fn self_size(&self) -> u64
Returns the value of self_size, or the default value if self_size is unset.
Sourcepub fn reference_field_id_base(&self) -> u64
pub fn reference_field_id_base(&self) -> u64
Returns the value of reference_field_id_base, or the default value if reference_field_id_base is unset.
Sourcepub fn native_allocation_registry_size_field(&self) -> i64
pub fn native_allocation_registry_size_field(&self) -> i64
Returns the value of native_allocation_registry_size_field, or the default value if native_allocation_registry_size_field is unset.