HeapGraphType

Struct HeapGraphType 

pub struct HeapGraphType {
    pub id: Option<u64>,
    pub location_id: Option<u64>,
    pub class_name: Option<String>,
    pub object_size: Option<u64>,
    pub superclass_id: Option<u64>,
    pub reference_field_id: Vec<u64>,
    pub kind: Option<i32>,
    pub classloader_id: Option<u64>,
}

Fields

id: Option<u64>

TODO(fmayer): Consider removing this and using the index in the repeaed field to save space.

location_id: Option<u64>class_name: Option<String>object_size: Option<u64>

Size of objects of this type.

superclass_id: Option<u64>reference_field_id: Vec<u64>

Indices for InternedData.field_names for the names of the fields of instances of this class. This does NOT include the fields from superclasses. The consumer of this data needs to walk all super classes to get a full lists of fields. Objects always write the fields in order of most specific class to the furthest up superclass.

kind: Option<i32>classloader_id: Option<u64>

Implementations

Source

impl HeapGraphType

pub fn id(&self) -> u64

Returns the value of id, or the default value if id is unset.

pub fn location_id(&self) -> u64

Returns the value of location_id, or the default value if location_id is unset.

pub fn class_name(&self) -> &str

Returns the value of class_name, or the default value if class_name is unset.

pub fn object_size(&self) -> u64

Returns the value of object_size, or the default value if object_size is unset.

pub fn superclass_id(&self) -> u64

Returns the value of superclass_id, or the default value if superclass_id is unset.

pub fn kind(&self) -> Kind

Returns the enum value of kind, or the default if the field is unset or set to an invalid enum value.

pub fn set_kind(&mut self, value: Kind)

Sets kind to the provided enum value.

pub fn classloader_id(&self) -> u64

Returns the value of classloader_id, or the default value if classloader_id is unset.