pub struct InodeFileMap {
pub block_device_id: Option<u64>,
pub mount_points: Vec<String>,
pub entries: Vec<Entry>,
}Expand description
Represents the mapping between inode numbers in a block device and their path on the filesystem
Fields
block_device_id: Option<u64>mount_points: Vec<String>The mount points of the block device, e.g. [“system”].
entries: Vec<Entry>The list of all the entries from the block device
Implementations
Sourceimpl InodeFileMap
impl InodeFileMap
Sourcepub fn block_device_id(&self) -> u64
pub fn block_device_id(&self) -> u64
Returns the value of block_device_id, or the default value if block_device_id is unset.