pub struct InternedString {
pub iid: Option<u64>,
pub str: Option<Vec<u8>>,
}Expand description
The interning fields in this file can refer to 2 different intern tables, depending on the message they are used in. If the interned fields are present in ProfilePacket proto, then the intern tables included in the ProfilePacket should be used. If the intered fields are present in the StreamingProfilePacket proto, then the intern tables included in all of the previous InternedData message with same sequence ID should be used. TODO(fmayer): Move to the intern tables to a common location.
Fields
iid: Option<u64>str: Option<Vec<u8>>Implementations