pub struct InternedV8String {
pub iid: Option<u64>,
pub encoded_string: Option<EncodedString>,
}Expand description
Interned version of V8String
Fields
iid: Option<u64>encoded_string: Option<EncodedString>We inline the fields in V8String here to save some bytes in the serialized proto format. Interning is about saving bytes so this makes sense here.
Implementations