pub struct LayersSnapshotProto {
pub elapsed_realtime_nanos: Option<i64>,
pub where: Option<String>,
pub layers: Option<LayersProto>,
pub hwc_blob: Option<String>,
pub excludes_composition_state: Option<bool>,
pub missed_entries: Option<u32>,
pub displays: Vec<DisplayProto>,
pub vsync_id: Option<i64>,
}Fields
elapsed_realtime_nanos: Option<i64>elapsed realtime in nanos since boot of when this entry was logged
where: Option<String>SurfaceFlinger’s stage where the snapshot was triggered. Currently either “visibleRegionsDirty” or “bufferLatched”.
layers: Option<LayersProto>hwc_blob: Option<String>Blob for the current HWC information for all layers, reported by dumpsys. Example: “maxDownScale: 4, maxFullWidth: 8192, HWState: 1, AssignedState: 3, …”
excludes_composition_state: Option<bool>Excludes state sent during composition like visible region and composition type.
missed_entries: Option<u32>Number of missed entries since the last entry was recorded.
displays: Vec<DisplayProto>vsync_id: Option<i64>Implementations
Sourceimpl LayersSnapshotProto
impl LayersSnapshotProto
Sourcepub fn elapsed_realtime_nanos(&self) -> i64
pub fn elapsed_realtime_nanos(&self) -> i64
Returns the value of elapsed_realtime_nanos, or the default value if elapsed_realtime_nanos is unset.
Sourcepub fn where(&self) -> &str
pub fn where(&self) -> &str
Returns the value of where, or the default value if where is unset.
Sourcepub fn hwc_blob(&self) -> &str
pub fn hwc_blob(&self) -> &str
Returns the value of hwc_blob, or the default value if hwc_blob is unset.
Sourcepub fn excludes_composition_state(&self) -> bool
pub fn excludes_composition_state(&self) -> bool
Returns the value of excludes_composition_state, or the default value if excludes_composition_state is unset.
Sourcepub fn missed_entries(&self) -> u32
pub fn missed_entries(&self) -> u32
Returns the value of missed_entries, or the default value if missed_entries is unset.