pub struct MmShrinkSlabEndFtraceEvent {
pub new_scan: Option<i64>,
pub retval: Option<i32>,
pub shr: Option<u64>,
pub shrink: Option<u64>,
pub total_scan: Option<i64>,
pub unused_scan: Option<i64>,
pub nid: Option<i32>,
}Fields
new_scan: Option<i64>retval: Option<i32>shr: Option<u64>shrink: Option<u64>total_scan: Option<i64>unused_scan: Option<i64>nid: Option<i32>Implementations
Sourceimpl MmShrinkSlabEndFtraceEvent
impl MmShrinkSlabEndFtraceEvent
Sourcepub fn new_scan(&self) -> i64
pub fn new_scan(&self) -> i64
Returns the value of new_scan, or the default value if new_scan is unset.
Sourcepub fn retval(&self) -> i32
pub fn retval(&self) -> i32
Returns the value of retval, or the default value if retval is unset.
Sourcepub fn shrink(&self) -> u64
pub fn shrink(&self) -> u64
Returns the value of shrink, or the default value if shrink is unset.
Sourcepub fn total_scan(&self) -> i64
pub fn total_scan(&self) -> i64
Returns the value of total_scan, or the default value if total_scan is unset.
Sourcepub fn unused_scan(&self) -> i64
pub fn unused_scan(&self) -> i64
Returns the value of unused_scan, or the default value if unused_scan is unset.