MmShrinkSlabStartFtraceEvent

Struct MmShrinkSlabStartFtraceEvent 

pub struct MmShrinkSlabStartFtraceEvent {
    pub cache_items: Option<u64>,
    pub delta: Option<u64>,
    pub gfp_flags: Option<u32>,
    pub lru_pgs: Option<u64>,
    pub nr_objects_to_shrink: Option<i64>,
    pub pgs_scanned: Option<u64>,
    pub shr: Option<u64>,
    pub shrink: Option<u64>,
    pub total_scan: Option<u64>,
    pub nid: Option<i32>,
    pub priority: Option<i32>,
}

Fields

cache_items: Option<u64>delta: Option<u64>gfp_flags: Option<u32>lru_pgs: Option<u64>nr_objects_to_shrink: Option<i64>pgs_scanned: Option<u64>shr: Option<u64>shrink: Option<u64>total_scan: Option<u64>nid: Option<i32>priority: Option<i32>

Implementations

Source

impl MmShrinkSlabStartFtraceEvent

pub fn cache_items(&self) -> u64

Returns the value of cache_items, or the default value if cache_items is unset.

pub fn delta(&self) -> u64

Returns the value of delta, or the default value if delta is unset.

pub fn gfp_flags(&self) -> u32

Returns the value of gfp_flags, or the default value if gfp_flags is unset.

pub fn lru_pgs(&self) -> u64

Returns the value of lru_pgs, or the default value if lru_pgs is unset.

pub fn nr_objects_to_shrink(&self) -> i64

Returns the value of nr_objects_to_shrink, or the default value if nr_objects_to_shrink is unset.

pub fn pgs_scanned(&self) -> u64

Returns the value of pgs_scanned, or the default value if pgs_scanned is unset.

pub fn shr(&self) -> u64

Returns the value of shr, or the default value if shr is unset.

pub fn shrink(&self) -> u64

Returns the value of shrink, or the default value if shrink is unset.

pub fn total_scan(&self) -> u64

Returns the value of total_scan, or the default value if total_scan is unset.

pub fn nid(&self) -> i32

Returns the value of nid, or the default value if nid is unset.

pub fn priority(&self) -> i32

Returns the value of priority, or the default value if priority is unset.