pub struct NapiGroReceiveEntryFtraceEvent {Show 19 fields
pub data_len: Option<u32>,
pub gso_size: Option<u32>,
pub gso_type: Option<u32>,
pub hash: Option<u32>,
pub ip_summed: Option<u32>,
pub l4_hash: Option<u32>,
pub len: Option<u32>,
pub mac_header: Option<i32>,
pub mac_header_valid: Option<u32>,
pub name: Option<String>,
pub napi_id: Option<u32>,
pub nr_frags: Option<u32>,
pub protocol: Option<u32>,
pub queue_mapping: Option<u32>,
pub skbaddr: Option<u64>,
pub truesize: Option<u32>,
pub vlan_proto: Option<u32>,
pub vlan_tagged: Option<u32>,
pub vlan_tci: Option<u32>,
}Fields
data_len: Option<u32>gso_size: Option<u32>gso_type: Option<u32>hash: Option<u32>ip_summed: Option<u32>l4_hash: Option<u32>len: Option<u32>mac_header: Option<i32>mac_header_valid: Option<u32>name: Option<String>napi_id: Option<u32>nr_frags: Option<u32>protocol: Option<u32>queue_mapping: Option<u32>skbaddr: Option<u64>truesize: Option<u32>vlan_proto: Option<u32>vlan_tagged: Option<u32>vlan_tci: Option<u32>Implementations
Sourceimpl NapiGroReceiveEntryFtraceEvent
impl NapiGroReceiveEntryFtraceEvent
Sourcepub fn data_len(&self) -> u32
pub fn data_len(&self) -> u32
Returns the value of data_len, or the default value if data_len is unset.
Sourcepub fn gso_size(&self) -> u32
pub fn gso_size(&self) -> u32
Returns the value of gso_size, or the default value if gso_size is unset.
Sourcepub fn gso_type(&self) -> u32
pub fn gso_type(&self) -> u32
Returns the value of gso_type, or the default value if gso_type is unset.
Sourcepub fn ip_summed(&self) -> u32
pub fn ip_summed(&self) -> u32
Returns the value of ip_summed, or the default value if ip_summed is unset.
Sourcepub fn l4_hash(&self) -> u32
pub fn l4_hash(&self) -> u32
Returns the value of l4_hash, or the default value if l4_hash is unset.
Sourcepub fn mac_header(&self) -> i32
pub fn mac_header(&self) -> i32
Returns the value of mac_header, or the default value if mac_header is unset.
Sourcepub fn mac_header_valid(&self) -> u32
pub fn mac_header_valid(&self) -> u32
Returns the value of mac_header_valid, or the default value if mac_header_valid is unset.
Sourcepub fn napi_id(&self) -> u32
pub fn napi_id(&self) -> u32
Returns the value of napi_id, or the default value if napi_id is unset.
Sourcepub fn nr_frags(&self) -> u32
pub fn nr_frags(&self) -> u32
Returns the value of nr_frags, or the default value if nr_frags is unset.
Sourcepub fn protocol(&self) -> u32
pub fn protocol(&self) -> u32
Returns the value of protocol, or the default value if protocol is unset.
Sourcepub fn queue_mapping(&self) -> u32
pub fn queue_mapping(&self) -> u32
Returns the value of queue_mapping, or the default value if queue_mapping is unset.
Sourcepub fn skbaddr(&self) -> u64
pub fn skbaddr(&self) -> u64
Returns the value of skbaddr, or the default value if skbaddr is unset.
Sourcepub fn truesize(&self) -> u32
pub fn truesize(&self) -> u32
Returns the value of truesize, or the default value if truesize is unset.
Sourcepub fn vlan_proto(&self) -> u32
pub fn vlan_proto(&self) -> u32
Returns the value of vlan_proto, or the default value if vlan_proto is unset.
Sourcepub fn vlan_tagged(&self) -> u32
pub fn vlan_tagged(&self) -> u32
Returns the value of vlan_tagged, or the default value if vlan_tagged is unset.