pub struct PerfSampleDefaults {
pub timebase: Option<Timebase>,
pub process_shard_count: Option<u32>,
pub chosen_process_shard: Option<u32>,
}Expand description
Submessage for TracePacketDefaults.
Fields
timebase: Option<Timebase>The sampling timebase. Might not be identical to the data source config if the implementation decided to default/override some parameters.
process_shard_count: Option<u32>If the config requested process sharding, report back the count and which of those bins was selected. Never changes for the duration of a trace.
chosen_process_shard: Option<u32>Implementations
Sourceimpl PerfSampleDefaults
impl PerfSampleDefaults
Sourcepub fn process_shard_count(&self) -> u32
pub fn process_shard_count(&self) -> u32
Returns the value of process_shard_count, or the default value if process_shard_count is unset.
Sourcepub fn chosen_process_shard(&self) -> u32
pub fn chosen_process_shard(&self) -> u32
Returns the value of chosen_process_shard, or the default value if chosen_process_shard is unset.