pub struct PixelModemEvents {
pub events: Vec<Vec<u8>>,
pub event_time_nanos: Vec<u64>,
}Fields
events: Vec<Vec<u8>>Pigweed-format dehydrated events.
event_time_nanos: Vec<u64>Timestamps of the events, converted to CLOCK_BOOTTIME. The first
timestamp is the absolute timestamp of the first event. Subsequent
timestamps are deltas from the previous timestamp.
The nth entry from events gets the nth entry here.