ProcessDescriptor

Struct ProcessDescriptor 

pub struct ProcessDescriptor {
    pub pid: Option<i32>,
    pub cmdline: Vec<String>,
    pub process_name: Option<String>,
    pub process_priority: Option<i32>,
    pub start_timestamp_ns: Option<i64>,
    pub chrome_process_type: Option<i32>,
    pub legacy_sort_index: Option<i32>,
    pub process_labels: Vec<String>,
}
Describes a process’s attributes. Emitted as part of a TrackDescriptor, usually by the process’s main thread.

Next id: 9.

Fields

pid: Option<i32>cmdline: Vec<String>process_name: Option<String>process_priority: Option<i32>start_timestamp_ns: Option<i64>

Process start time in nanoseconds. The timestamp refers to the trace clock by default. Other clock IDs provided in TracePacket are not supported.

chrome_process_type: Option<i32>legacy_sort_index: Option<i32>

To support old UI. New UI should determine default sorting by process_type.

process_labels: Vec<String>

Labels can be used to further describe properties of the work performed by the process. For example, these can be used by Chrome renderer process to provide titles of frames being rendered.

Implementations

Source

impl ProcessDescriptor

pub fn pid(&self) -> i32

Returns the value of pid, or the default value if pid is unset.

pub fn legacy_sort_index(&self) -> i32

Returns the value of legacy_sort_index, or the default value if legacy_sort_index is unset.

pub fn chrome_process_type(&self) -> ChromeProcessType

Returns the enum value of chrome_process_type, or the default if the field is unset or set to an invalid enum value.

pub fn set_chrome_process_type(&mut self, value: ChromeProcessType)

Sets chrome_process_type to the provided enum value.

pub fn process_priority(&self) -> i32

Returns the value of process_priority, or the default value if process_priority is unset.

pub fn process_name(&self) -> &str

Returns the value of process_name, or the default value if process_name is unset.

pub fn start_timestamp_ns(&self) -> i64

Returns the value of start_timestamp_ns, or the default value if start_timestamp_ns is unset.