pub struct ProcessStats {
pub processes: Vec<Process>,
pub collection_end_timestamp: Option<u64>,
}Expand description
Per-process periodically sampled stats. These samples are wrapped in a dedicated message (as opposite to be fields in process_tree.proto) because they are dumped at a different rate than cmdline and thread list. Note: not all of these stats will be present in every ProcessStats message and sometimes processes may be missing. This is because counters are cached to reduce emission of counters which do not change.
Fields
processes: Vec<Process>collection_end_timestamp: Option<u64>The time at which we finish collecting this batch of samples; the top-level packet timestamp is the time at which we begin collection.
Implementations
Sourceimpl ProcessStats
impl ProcessStats
Sourcepub fn collection_end_timestamp(&self) -> u64
pub fn collection_end_timestamp(&self) -> u64
Returns the value of collection_end_timestamp, or the default value if collection_end_timestamp is unset.