pub struct ProfiledFrameSymbols {
pub frame_iid: Option<u64>,
pub function_name_id: Vec<u64>,
pub file_name_id: Vec<u64>,
pub line_number: Vec<u32>,
}Expand description
A symbol field that is emitted after the trace is written. These tables would be appended as the last packets in the trace that the profiler will use, so that the actual trace need not be rewritten to symbolize the profiles.
Fields
frame_iid: Option<u64>Use the frame id as the interning key for the symbols.
function_name_id: Vec<u64>key to InternedString
file_name_id: Vec<u64>key to InternedString
line_number: Vec<u32>Implementations