pub struct ProtoLogConfig {
pub group_overrides: Vec<ProtoLogGroup>,
pub tracing_mode: Option<i32>,
}Expand description
Custom configuration for the “android.protolog” data source. ProtoLog is a logging mechanism that is intented to be more efficient than logcat. This configures what logs to capture in the tracing instance.
Fields
group_overrides: Vec<ProtoLogGroup>Specified the configurations for each of the logging groups. If none is specified for a group the defaults will be used.
tracing_mode: Option<i32>Specified what tracing mode to use for the tracing instance.
Implementations
Sourceimpl ProtoLogConfig
impl ProtoLogConfig
Sourcepub fn tracing_mode(&self) -> TracingMode
pub fn tracing_mode(&self) -> TracingMode
Returns the enum value of tracing_mode, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_tracing_mode(&mut self, value: TracingMode)
pub fn set_tracing_mode(&mut self, value: TracingMode)
Sets tracing_mode to the provided enum value.