pub struct ProtoLogMessage {
pub message_id: Option<u64>,
pub str_param_iids: Vec<u32>,
pub sint64_params: Vec<i64>,
pub double_params: Vec<f64>,
pub boolean_params: Vec<i32>,
pub stacktrace_iid: Option<u32>,
}Expand description
represents a single log entry
Fields
message_id: Option<u64>log statement identifier, created from message string and log level.
str_param_iids: Vec<u32>string parameters passed to the log call that have been interned.
sint64_params: Vec<i64>integer parameters passed to the log call.
double_params: Vec<f64>floating point parameters passed to the log call.
boolean_params: Vec<i32>boolean parameters passed to the log call.
stacktrace_iid: Option<u32>id of the interned stacktrace string (only dumped if explicitly confuigured to do so)
Implementations
Sourceimpl ProtoLogMessage
impl ProtoLogMessage
Sourcepub fn message_id(&self) -> u64
pub fn message_id(&self) -> u64
Returns the value of message_id, or the default value if message_id is unset.
Sourcepub fn stacktrace_iid(&self) -> u32
pub fn stacktrace_iid(&self) -> u32
Returns the value of stacktrace_iid, or the default value if stacktrace_iid is unset.