pub struct ReadyThreadEtwEvent {
pub t_thread_id: Option<u32>,
pub adjust_reason: Option<i32>,
pub adjust_increment: Option<i32>,
pub flag: Option<i32>,
}Expand description
Proto definition based on the Thread_v2 CSwitch class definition See: https://learn.microsoft.com/en-us/windows/win32/etw/readythread
Fields
t_thread_id: Option<u32>The thread identifier of the thread being readied for execution.
adjust_reason: Option<i32>adjust_increment: Option<i32>The value by which the priority is being adjusted.
flag: Option<i32>Implementations
Sourceimpl ReadyThreadEtwEvent
impl ReadyThreadEtwEvent
Sourcepub fn t_thread_id(&self) -> u32
pub fn t_thread_id(&self) -> u32
Returns the value of t_thread_id, or the default value if t_thread_id is unset.
Sourcepub fn adjust_reason(&self) -> AdjustReason
pub fn adjust_reason(&self) -> AdjustReason
Returns the enum value of adjust_reason, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_adjust_reason(&mut self, value: AdjustReason)
pub fn set_adjust_reason(&mut self, value: AdjustReason)
Sets adjust_reason to the provided enum value.
Sourcepub fn adjust_increment(&self) -> i32
pub fn adjust_increment(&self) -> i32
Returns the value of adjust_increment, or the default value if adjust_increment is unset.