SdeSdePerfCrtcUpdateFtraceEvent

Struct SdeSdePerfCrtcUpdateFtraceEvent 

pub struct SdeSdePerfCrtcUpdateFtraceEvent {
    pub bw_ctl_ebi: Option<u64>,
    pub bw_ctl_llcc: Option<u64>,
    pub bw_ctl_mnoc: Option<u64>,
    pub core_clk_rate: Option<u32>,
    pub crtc: Option<u32>,
    pub params: Option<i32>,
    pub per_pipe_ib_ebi: Option<u64>,
    pub per_pipe_ib_llcc: Option<u64>,
    pub per_pipe_ib_mnoc: Option<u64>,
    pub stop_req: Option<u32>,
    pub update_bus: Option<u32>,
    pub update_clk: Option<u32>,
}

Fields

bw_ctl_ebi: Option<u64>bw_ctl_llcc: Option<u64>bw_ctl_mnoc: Option<u64>core_clk_rate: Option<u32>crtc: Option<u32>params: Option<i32>per_pipe_ib_ebi: Option<u64>per_pipe_ib_llcc: Option<u64>per_pipe_ib_mnoc: Option<u64>stop_req: Option<u32>update_bus: Option<u32>update_clk: Option<u32>

Implementations

Source

impl SdeSdePerfCrtcUpdateFtraceEvent

pub fn bw_ctl_ebi(&self) -> u64

Returns the value of bw_ctl_ebi, or the default value if bw_ctl_ebi is unset.

pub fn bw_ctl_llcc(&self) -> u64

Returns the value of bw_ctl_llcc, or the default value if bw_ctl_llcc is unset.

pub fn bw_ctl_mnoc(&self) -> u64

Returns the value of bw_ctl_mnoc, or the default value if bw_ctl_mnoc is unset.

pub fn core_clk_rate(&self) -> u32

Returns the value of core_clk_rate, or the default value if core_clk_rate is unset.

pub fn crtc(&self) -> u32

Returns the value of crtc, or the default value if crtc is unset.

pub fn params(&self) -> i32

Returns the value of params, or the default value if params is unset.

pub fn per_pipe_ib_ebi(&self) -> u64

Returns the value of per_pipe_ib_ebi, or the default value if per_pipe_ib_ebi is unset.

pub fn per_pipe_ib_llcc(&self) -> u64

Returns the value of per_pipe_ib_llcc, or the default value if per_pipe_ib_llcc is unset.

pub fn per_pipe_ib_mnoc(&self) -> u64

Returns the value of per_pipe_ib_mnoc, or the default value if per_pipe_ib_mnoc is unset.

pub fn stop_req(&self) -> u32

Returns the value of stop_req, or the default value if stop_req is unset.

pub fn update_bus(&self) -> u32

Returns the value of update_bus, or the default value if update_bus is unset.

pub fn update_clk(&self) -> u32

Returns the value of update_clk, or the default value if update_clk is unset.