ShellTransition

Struct ShellTransition 

pub struct ShellTransition {
Show 17 fields pub id: Option<i32>, pub create_time_ns: Option<i64>, pub send_time_ns: Option<i64>, pub dispatch_time_ns: Option<i64>, pub merge_time_ns: Option<i64>, pub merge_request_time_ns: Option<i64>, pub shell_abort_time_ns: Option<i64>, pub wm_abort_time_ns: Option<i64>, pub finish_time_ns: Option<i64>, pub start_transaction_id: Option<u64>, pub finish_transaction_id: Option<u64>, pub handler: Option<i32>, pub type: Option<i32>, pub targets: Vec<Target>, pub merge_target: Option<i32>, pub flags: Option<i32>, pub starting_window_remove_time_ns: Option<i64>,
}
ShellTransition messages record information about the shell transitions in the system. This is used to track the animations that are created and execute through the shell transition system.

Fields

id: Option<i32>

The unique identifier of the transition.

create_time_ns: Option<i64>

The time the transition was created on the WM side (using SystemClock.elapsedRealtimeNanos())

send_time_ns: Option<i64>

The time the transition was sent from the WM side to shell (using SystemClock.elapsedRealtimeNanos())

dispatch_time_ns: Option<i64>

The time the transition was dispatched by shell to execute (using SystemClock.elapsedRealtimeNanos())

merge_time_ns: Option<i64>

If the transition merge was accepted by the transition handler, this contains the time the transition was merged into transition with id merge_target. (using SystemClock.elapsedRealtimeNanos())

merge_request_time_ns: Option<i64>

The time shell proposed the transition should be merged to the transition handler into transition with id merge_target. (using SystemClock.elapsedRealtimeNanos()).

shell_abort_time_ns: Option<i64>

If the transition was aborted on the shell side, this is the time that occurred. (using SystemClock.elapsedRealtimeNanos())

wm_abort_time_ns: Option<i64>

If the transition was aborted on the wm side, this is the time that occurred. (using SystemClock.elapsedRealtimeNanos())

finish_time_ns: Option<i64>

The time WM considers the transition to be complete. (using SystemClock.elapsedRealtimeNanos())

start_transaction_id: Option<u64>

The id of the transaction that WM proposed to use as the starting transaction. It contains all the layer changes required to setup the transition and should be executed right at the start of the transition by the transition handler.

finish_transaction_id: Option<u64>

The if of the transaction that WM proposed to use as the finish transaction. It contains all the layer changes required to set the final state of the transition.

handler: Option<i32>

The id of the handler that executed the transition. A HandlerMappings message in the trace will contain the mapping of id to a string representation of the handler.

type: Option<i32>

The transition type of this transition (e.g. TO_FRONT, OPEN, CLOSE).

targets: Vec<Target>

The list of targets that are part of this transition.

merge_target: Option<i32>

The id of the transition we have requested to merge or have merged this transition into.

flags: Option<i32>

The flags set on this transition.

starting_window_remove_time_ns: Option<i64>

The time the starting window was removed. Tracked because this can happen after the transition finishes, but the app may not yet be visible until the starting window is removed. So in a sense the transition is not finished until the starting window is removed. (b/284302118) (using SystemClock.elapsedRealtimeNanos())

Implementations

Source

impl ShellTransition

pub fn id(&self) -> i32

Returns the value of id, or the default value if id is unset.

pub fn create_time_ns(&self) -> i64

Returns the value of create_time_ns, or the default value if create_time_ns is unset.

pub fn send_time_ns(&self) -> i64

Returns the value of send_time_ns, or the default value if send_time_ns is unset.

pub fn dispatch_time_ns(&self) -> i64

Returns the value of dispatch_time_ns, or the default value if dispatch_time_ns is unset.

pub fn merge_time_ns(&self) -> i64

Returns the value of merge_time_ns, or the default value if merge_time_ns is unset.

pub fn merge_request_time_ns(&self) -> i64

Returns the value of merge_request_time_ns, or the default value if merge_request_time_ns is unset.

pub fn shell_abort_time_ns(&self) -> i64

Returns the value of shell_abort_time_ns, or the default value if shell_abort_time_ns is unset.

pub fn wm_abort_time_ns(&self) -> i64

Returns the value of wm_abort_time_ns, or the default value if wm_abort_time_ns is unset.

pub fn finish_time_ns(&self) -> i64

Returns the value of finish_time_ns, or the default value if finish_time_ns is unset.

pub fn start_transaction_id(&self) -> u64

Returns the value of start_transaction_id, or the default value if start_transaction_id is unset.

pub fn finish_transaction_id(&self) -> u64

Returns the value of finish_transaction_id, or the default value if finish_transaction_id is unset.

pub fn handler(&self) -> i32

Returns the value of handler, or the default value if handler is unset.

pub fn type(&self) -> i32

Returns the value of type, or the default value if type is unset.

pub fn merge_target(&self) -> i32

Returns the value of merge_target, or the default value if merge_target is unset.

pub fn flags(&self) -> i32

Returns the value of flags, or the default value if flags is unset.

pub fn starting_window_remove_time_ns(&self) -> i64

Returns the value of starting_window_remove_time_ns, or the default value if starting_window_remove_time_ns is unset.