pub struct StatsdTracingConfig {
pub push_atom_id: Vec<i32>,
pub raw_push_atom_id: Vec<i32>,
pub pull_config: Vec<StatsdPullAtomConfig>,
}Expand description
This file is named ‘statsd_tracing_config.proto’ rather than ‘statsd_config.proto’ (which would be more consistent with the other config protos) so it doesn’t show up and confuse folks looking for the existing statsd_config.proto for configuring statsd itself. Same for the config proto itself.
Fields
push_atom_id: Vec<i32>This is for the common case of the atom id being known in the enum AtomId.
raw_push_atom_id: Vec<i32>Escape hatch for Atom IDs that are not yet in the AtomId enum (e.g. non-upstream atoms that don’t exist in AOSP).
pull_config: Vec<StatsdPullAtomConfig>Implementations