pub struct SurfaceFlingerLayersConfig {
pub mode: Option<i32>,
pub trace_flags: Vec<i32>,
}Expand description
Custom configuration for the “android.surfaceflinger.layers” data source.
Fields
mode: Option<i32>trace_flags: Vec<i32>Implementations
Sourceimpl SurfaceFlingerLayersConfig
impl SurfaceFlingerLayersConfig
Sourcepub fn mode(&self) -> Mode
pub fn mode(&self) -> Mode
Returns the enum value of mode, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn trace_flags(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<TraceFlag>>
pub fn trace_flags( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<TraceFlag>>
Returns an iterator which yields the valid enum values contained in trace_flags.
Sourcepub fn push_trace_flags(&mut self, value: TraceFlag)
pub fn push_trace_flags(&mut self, value: TraceFlag)
Appends the provided enum value to trace_flags.