pub struct SystemInfo {
pub utsname: Option<Utsname>,
pub android_build_fingerprint: Option<String>,
pub android_soc_model: Option<String>,
pub tracing_service_version: Option<String>,
pub android_sdk_version: Option<u64>,
pub page_size: Option<u32>,
pub num_cpus: Option<u32>,
pub timezone_off_mins: Option<i32>,
pub hz: Option<i64>,
}Fields
utsname: Option<Utsname>android_build_fingerprint: Option<String>android_soc_model: Option<String>The SoC model from which trace is collected
tracing_service_version: Option<String>The version of traced (the same returned by traced --version).
This is a human readable string with and its format varies depending on
the build system and the repo (standalone vs AOSP).
This is intended for human debugging only.
android_sdk_version: Option<u64>The Android SDK vesion (e.g. 21 for L, 31 for S etc). Introduced in Android T.
page_size: Option<u32>Kernel page size - sysconf(_SC_PAGESIZE).
num_cpus: Option<u32>Number of cpus - sysconf(_SC_NPROCESSORS_CONF). Might be different to the number of online cpus. Introduced in perfetto v44.
timezone_off_mins: Option<i32>The timezone offset from UTC, as per strftime(“%z”), in minutes. Introduced in v38 / Android V.
hz: Option<i64>Ticks per second - sysconf(_SC_CLK_TCK). Not serialised as of perfetto v44.
Implementations
Sourceimpl SystemInfo
impl SystemInfo
Sourcepub fn android_build_fingerprint(&self) -> &str
pub fn android_build_fingerprint(&self) -> &str
Returns the value of android_build_fingerprint, or the default value if android_build_fingerprint is unset.
Sourcepub fn tracing_service_version(&self) -> &str
pub fn tracing_service_version(&self) -> &str
Returns the value of tracing_service_version, or the default value if tracing_service_version is unset.
Sourcepub fn android_sdk_version(&self) -> u64
pub fn android_sdk_version(&self) -> u64
Returns the value of android_sdk_version, or the default value if android_sdk_version is unset.
Sourcepub fn page_size(&self) -> u32
pub fn page_size(&self) -> u32
Returns the value of page_size, or the default value if page_size is unset.
Sourcepub fn timezone_off_mins(&self) -> i32
pub fn timezone_off_mins(&self) -> i32
Returns the value of timezone_off_mins, or the default value if timezone_off_mins is unset.
Sourcepub fn num_cpus(&self) -> u32
pub fn num_cpus(&self) -> u32
Returns the value of num_cpus, or the default value if num_cpus is unset.
Sourcepub fn android_soc_model(&self) -> &str
pub fn android_soc_model(&self) -> &str
Returns the value of android_soc_model, or the default value if android_soc_model is unset.