pub struct SystemInfoConfig {}Expand description
This data-source does a one-off recording of system information when the trace starts. Currently this includes:
- Values of /sys/devices/system/cpu/cpu*/cpufreq/scaling_available_frequencies This datasource has no configuration options at present.