pub struct TracePacketDefaults {
pub timestamp_clock_id: Option<u32>,
pub track_event_defaults: Option<TrackEventDefaults>,
pub perf_sample_defaults: Option<PerfSampleDefaults>,
pub v8_code_defaults: Option<V8CodeDefaults>,
}Expand description
Default values for TracePacket fields that hold for a particular TraceWriter packet sequence. This message contains a subset of the TracePacket fields with matching IDs. When provided, these fields define the default values that should be applied, at import time, to all TracePacket(s) with the same |trusted_packet_sequence_id|, unless otherwise specified in each packet.
Should be reemitted whenever incremental state is cleared on the sequence.
Fields
timestamp_clock_id: Option<u32>track_event_defaults: Option<TrackEventDefaults>Default values for TrackEvents (e.g. default track).
perf_sample_defaults: Option<PerfSampleDefaults>Defaults for perf profiler packets (PerfSample).
v8_code_defaults: Option<V8CodeDefaults>Defaults for V8 code packets (V8JsCode, V8InternalCode, V8WasmCode, V8RegexpCode)
Implementations
Sourceimpl TracePacketDefaults
impl TracePacketDefaults
Sourcepub fn timestamp_clock_id(&self) -> u32
pub fn timestamp_clock_id(&self) -> u32
Returns the value of timestamp_clock_id, or the default value if timestamp_clock_id is unset.