pub struct TraceUuid {
pub msb: Option<i64>,
pub lsb: Option<i64>,
}Expand description
A random unique ID that identifies the trace. This message has been introduced in v32. Prior to that, the UUID was only (optionally) present in the TraceConfig.trace_uuid_msb/lsb fields. This has been moved to a standalone packet to deal with new use-cases for go/gapless-aot, where the same tracing session can be serialized several times, in which case the UUID is changed on each snapshot and does not match the one in the TraceConfig.
Fields
msb: Option<i64>lsb: Option<i64>Implementations