pub struct TransactionTraceFile {
pub magic_number: Option<u64>,
pub entry: Vec<TransactionTraceEntry>,
pub real_to_elapsed_time_offset_nanos: Option<u64>,
pub version: Option<u32>,
}Expand description
Message used by Winscope to process legacy trace files. Represents a file full of surface flinger transactions. Encoded, it should start with 0x54 0x4E 0x58 0x54 0x52 0x41 0x43 0x45 (.TNXTRACE), such that they can be easily identified.
Fields
magic_number: Option<u64>Must be the first field, set to value in MagicNumber
entry: Vec<TransactionTraceEntry>real_to_elapsed_time_offset_nanos: Option<u64>offset between real-time clock and elapsed time clock in nanoseconds. Calculated as: systemTime(SYSTEM_TIME_REALTIME) - systemTime(SYSTEM_TIME_MONOTONIC)
version: Option<u32>Implementations
Sourceimpl TransactionTraceFile
impl TransactionTraceFile
Sourcepub fn magic_number(&self) -> u64
pub fn magic_number(&self) -> u64
Returns the value of magic_number, or the default value if magic_number is unset.
Sourcepub fn real_to_elapsed_time_offset_nanos(&self) -> u64
pub fn real_to_elapsed_time_offset_nanos(&self) -> u64
Returns the value of real_to_elapsed_time_offset_nanos, or the default value if real_to_elapsed_time_offset_nanos is unset.