pub struct Trigger {
pub trigger_name: Option<String>,
pub producer_name: Option<String>,
pub trusted_producer_uid: Option<i32>,
}Expand description
When a TracingSession receives a trigger it records the boot time nanoseconds in the TracePacket’s timestamp field as well as the name of the producer that triggered it. We emit this data so filtering can be done on triggers received in the trace.
Fields
trigger_name: Option<String>Name of the trigger which was received.
producer_name: Option<String>The actual producer that activated |trigger|.
trusted_producer_uid: Option<i32>The verified UID of the producer.
Implementations
Sourceimpl Trigger
impl Trigger
Sourcepub fn trigger_name(&self) -> &str
pub fn trigger_name(&self) -> &str
Returns the value of trigger_name, or the default value if trigger_name is unset.
Sourcepub fn producer_name(&self) -> &str
pub fn producer_name(&self) -> &str
Returns the value of producer_name, or the default value if producer_name is unset.
Sourcepub fn trusted_producer_uid(&self) -> i32
pub fn trusted_producer_uid(&self) -> i32
Returns the value of trusted_producer_uid, or the default value if trusted_producer_uid is unset.