pub struct UfshcdCommandFtraceEvent {
pub dev_name: Option<String>,
pub doorbell: Option<u32>,
pub intr: Option<u32>,
pub lba: Option<u64>,
pub opcode: Option<u32>,
pub str: Option<String>,
pub tag: Option<u32>,
pub transfer_len: Option<i32>,
pub group_id: Option<u32>,
pub str_t: Option<u32>,
}Fields
dev_name: Option<String>doorbell: Option<u32>intr: Option<u32>lba: Option<u64>opcode: Option<u32>str: Option<String>tag: Option<u32>transfer_len: Option<i32>group_id: Option<u32>str_t: Option<u32>Implementations
Sourceimpl UfshcdCommandFtraceEvent
impl UfshcdCommandFtraceEvent
Sourcepub fn dev_name(&self) -> &str
pub fn dev_name(&self) -> &str
Returns the value of dev_name, or the default value if dev_name is unset.
Sourcepub fn doorbell(&self) -> u32
pub fn doorbell(&self) -> u32
Returns the value of doorbell, or the default value if doorbell is unset.
Sourcepub fn opcode(&self) -> u32
pub fn opcode(&self) -> u32
Returns the value of opcode, or the default value if opcode is unset.
Sourcepub fn transfer_len(&self) -> i32
pub fn transfer_len(&self) -> i32
Returns the value of transfer_len, or the default value if transfer_len is unset.