pub struct Utsname {
pub sysname: Option<String>,
pub version: Option<String>,
pub release: Option<String>,
pub machine: Option<String>,
}Fields
sysname: Option<String>version: Option<String>release: Option<String>machine: Option<String>Implementations
Sourceimpl Utsname
impl Utsname
Sourcepub fn sysname(&self) -> &str
pub fn sysname(&self) -> &str
Returns the value of sysname, or the default value if sysname is unset.
Sourcepub fn version(&self) -> &str
pub fn version(&self) -> &str
Returns the value of version, or the default value if version is unset.