pub struct V8Config {
pub log_script_sources: Option<bool>,
pub log_instructions: Option<bool>,
}Fields
log_script_sources: Option<bool>Whether to log the actual content of scripts (e.g. content of the JS file that was compiled to generate code). ATTENTION: This could considerably increase the size of the resuling trace file.
log_instructions: Option<bool>Whether to log the generated code for jitted functions (machine code or bytecode). ATTENTION: This could considerably increase the size of the resuling trace file.
Implementations
Sourceimpl V8Config
impl V8Config
Sourcepub fn log_script_sources(&self) -> bool
pub fn log_script_sources(&self) -> bool
Returns the value of log_script_sources, or the default value if log_script_sources is unset.
Sourcepub fn log_instructions(&self) -> bool
pub fn log_instructions(&self) -> bool
Returns the value of log_instructions, or the default value if log_instructions is unset.