pub struct V8JsCode {
pub v8_isolate_iid: Option<u64>,
pub tid: Option<u32>,
pub v8_js_function_iid: Option<u64>,
pub tier: Option<i32>,
pub instruction_start: Option<u64>,
pub instruction_size_bytes: Option<u64>,
pub instructions: Option<Instructions>,
}Fields
v8_isolate_iid: Option<u64>tid: Option<u32>v8_js_function_iid: Option<u64>tier: Option<i32>instruction_start: Option<u64>instruction_size_bytes: Option<u64>instructions: Option<Instructions>Implementations
Sourceimpl V8JsCode
impl V8JsCode
Sourcepub fn v8_isolate_iid(&self) -> u64
pub fn v8_isolate_iid(&self) -> u64
Returns the value of v8_isolate_iid, or the default value if v8_isolate_iid is unset.
Sourcepub fn v8_js_function_iid(&self) -> u64
pub fn v8_js_function_iid(&self) -> u64
Returns the value of v8_js_function_iid, or the default value if v8_js_function_iid is unset.
Sourcepub fn tier(&self) -> Tier
pub fn tier(&self) -> Tier
Returns the enum value of tier, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn instruction_start(&self) -> u64
pub fn instruction_start(&self) -> u64
Returns the value of instruction_start, or the default value if instruction_start is unset.
Sourcepub fn instruction_size_bytes(&self) -> u64
pub fn instruction_size_bytes(&self) -> u64
Returns the value of instruction_size_bytes, or the default value if instruction_size_bytes is unset.