Vb2V4l2QbufFtraceEvent

Struct Vb2V4l2QbufFtraceEvent 

pub struct Vb2V4l2QbufFtraceEvent {
Show 15 fields pub field: Option<u32>, pub flags: Option<u32>, pub minor: Option<i32>, pub sequence: Option<u32>, pub timecode_flags: Option<u32>, pub timecode_frames: Option<u32>, pub timecode_hours: Option<u32>, pub timecode_minutes: Option<u32>, pub timecode_seconds: Option<u32>, pub timecode_type: Option<u32>, pub timecode_userbits0: Option<u32>, pub timecode_userbits1: Option<u32>, pub timecode_userbits2: Option<u32>, pub timecode_userbits3: Option<u32>, pub timestamp: Option<i64>,
}

Fields

field: Option<u32>flags: Option<u32>minor: Option<i32>sequence: Option<u32>timecode_flags: Option<u32>timecode_frames: Option<u32>timecode_hours: Option<u32>timecode_minutes: Option<u32>timecode_seconds: Option<u32>timecode_type: Option<u32>timecode_userbits0: Option<u32>timecode_userbits1: Option<u32>timecode_userbits2: Option<u32>timecode_userbits3: Option<u32>timestamp: Option<i64>

Implementations

Source

impl Vb2V4l2QbufFtraceEvent

pub fn field(&self) -> u32

Returns the value of field, or the default value if field is unset.

pub fn flags(&self) -> u32

Returns the value of flags, or the default value if flags is unset.

pub fn minor(&self) -> i32

Returns the value of minor, or the default value if minor is unset.

pub fn sequence(&self) -> u32

Returns the value of sequence, or the default value if sequence is unset.

pub fn timecode_flags(&self) -> u32

Returns the value of timecode_flags, or the default value if timecode_flags is unset.

pub fn timecode_frames(&self) -> u32

Returns the value of timecode_frames, or the default value if timecode_frames is unset.

pub fn timecode_hours(&self) -> u32

Returns the value of timecode_hours, or the default value if timecode_hours is unset.

pub fn timecode_minutes(&self) -> u32

Returns the value of timecode_minutes, or the default value if timecode_minutes is unset.

pub fn timecode_seconds(&self) -> u32

Returns the value of timecode_seconds, or the default value if timecode_seconds is unset.

pub fn timecode_type(&self) -> u32

Returns the value of timecode_type, or the default value if timecode_type is unset.

pub fn timecode_userbits0(&self) -> u32

Returns the value of timecode_userbits0, or the default value if timecode_userbits0 is unset.

pub fn timecode_userbits1(&self) -> u32

Returns the value of timecode_userbits1, or the default value if timecode_userbits1 is unset.

pub fn timecode_userbits2(&self) -> u32

Returns the value of timecode_userbits2, or the default value if timecode_userbits2 is unset.

pub fn timecode_userbits3(&self) -> u32

Returns the value of timecode_userbits3, or the default value if timecode_userbits3 is unset.

pub fn timestamp(&self) -> i64

Returns the value of timestamp, or the default value if timestamp is unset.