VulkanMemoryEvent

Struct VulkanMemoryEvent 

pub struct VulkanMemoryEvent {
Show 14 fields pub source: Option<i32>, pub operation: Option<i32>, pub timestamp: Option<i64>, pub pid: Option<u32>, pub memory_address: Option<u64>, pub memory_size: Option<u64>, pub caller_iid: Option<u64>, pub allocation_scope: Option<i32>, pub annotations: Vec<VulkanMemoryEventAnnotation>, pub device: Option<u64>, pub device_memory: Option<u64>, pub memory_type: Option<u32>, pub heap: Option<u32>, pub object_handle: Option<u64>,
}
Each VulkanMemoryEvent encompasses information regarding one single function call that results in reserving, binding or freeing host or GPU memory. There is a special message type, ANNOTATIONS, which is used to communicate information that are not directly related to a memory event, nonetheless are essential to understand the memory usage. An example is the size and memory types of the memory heaps.

Next reserved id: 10 (up to 15). Next id: 21.

Fields

source: Option<i32>operation: Option<i32>timestamp: Option<i64>pid: Option<u32>memory_address: Option<u64>memory_size: Option<u64>caller_iid: Option<u64>

Interned string. Original string value is stored in function_names from protos/perfetto/trace/interned_data/interned_data.proto.

allocation_scope: Option<i32>annotations: Vec<VulkanMemoryEventAnnotation>

Extra related information, e.g., create configs, etc.

device: Option<u64>

Field IDs used for device memory (low sampling rate)

device_memory: Option<u64>memory_type: Option<u32>heap: Option<u32>object_handle: Option<u64>

Implementations

Source

impl VulkanMemoryEvent

pub fn source(&self) -> Source

Returns the enum value of source, or the default if the field is unset or set to an invalid enum value.

pub fn set_source(&mut self, value: Source)

Sets source to the provided enum value.

pub fn operation(&self) -> Operation

Returns the enum value of operation, or the default if the field is unset or set to an invalid enum value.

pub fn set_operation(&mut self, value: Operation)

Sets operation to the provided enum value.

pub fn timestamp(&self) -> i64

Returns the value of timestamp, or the default value if timestamp is unset.

pub fn pid(&self) -> u32

Returns the value of pid, or the default value if pid is unset.

pub fn memory_address(&self) -> u64

Returns the value of memory_address, or the default value if memory_address is unset.

pub fn memory_size(&self) -> u64

Returns the value of memory_size, or the default value if memory_size is unset.

pub fn caller_iid(&self) -> u64

Returns the value of caller_iid, or the default value if caller_iid is unset.

pub fn allocation_scope(&self) -> AllocationScope

Returns the enum value of allocation_scope, or the default if the field is unset or set to an invalid enum value.

pub fn set_allocation_scope(&mut self, value: AllocationScope)

Sets allocation_scope to the provided enum value.

pub fn device(&self) -> u64

Returns the value of device, or the default value if device is unset.

pub fn device_memory(&self) -> u64

Returns the value of device_memory, or the default value if device_memory is unset.

pub fn memory_type(&self) -> u32

Returns the value of memory_type, or the default value if memory_type is unset.

pub fn heap(&self) -> u32

Returns the value of heap, or the default value if heap is unset.

pub fn object_handle(&self) -> u64

Returns the value of object_handle, or the default value if object_handle is unset.