pub struct VulkanMemoryEventAnnotation {
pub key_iid: Option<u64>,
pub value: Option<Value>,
}Expand description
All the information that cannot be sent within a VulkanMemoryEvent message, are sent as annotations to the main memory event. One example is the properties of the object that consumes the allocated memory, for example, a buffer or an image. key_iid and string_iid are both interned strings. Original string value is stored in vulkan_memory_keys from protos/perfetto/trace/interned_data/interned_data.proto.
Fields
key_iid: Option<u64>value: Option<Value>Implementations