pub struct WorkqueueQueueWorkFtraceEvent {
pub work: Option<u64>,
pub function: Option<u64>,
pub workqueue: Option<u64>,
pub req_cpu: Option<u32>,
pub cpu: Option<u32>,
}Fields
work: Option<u64>function: Option<u64>workqueue: Option<u64>req_cpu: Option<u32>cpu: Option<u32>Implementations
Sourceimpl WorkqueueQueueWorkFtraceEvent
impl WorkqueueQueueWorkFtraceEvent
Sourcepub fn function(&self) -> u64
pub fn function(&self) -> u64
Returns the value of function, or the default value if function is unset.
Sourcepub fn workqueue(&self) -> u64
pub fn workqueue(&self) -> u64
Returns the value of workqueue, or the default value if workqueue is unset.