#[repr(i32)]pub enum Mode {
Unspecified = 0,
Continuous = 1,
Active = 2,
}Variants
Unspecified = 0
Continuous = 1
Default mode (applied by SurfaceFlinger if no mode is specified). SurfaceFlinger writes its internal ring buffer of transactions every time the data source is flushed. The ring buffer contains the SurfaceFlinger’s initial state and the latest transactions.
Active = 2
SurfaceFlinger writes the initial state and then each incoming transaction until the data source is stopped.
Implementations
Sourceimpl Mode
impl Mode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Mode>
pub fn from_str_name(value: &str) -> Option<Mode>
Creates an enum from field names used in the ProtoBuf definition.