#[repr(i32)]pub enum PsiResource {
Unspecified = 0,
CpuSome = 1,
CpuFull = 2,
IoSome = 3,
IoFull = 4,
MemorySome = 5,
MemoryFull = 6,
}Expand description
Type of resource that may have exhibited pressure stalls. * _SOME indicates some resource tasks stalled. * _FULL indicates all non-idle resource tasks stalled simultaneously.
Variants
Implementations
Sourceimpl PsiResource
impl PsiResource
Sourceimpl PsiResource
impl PsiResource
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<PsiResource>
pub fn from_str_name(value: &str) -> Option<PsiResource>
Creates an enum from field names used in the ProtoBuf definition.