pub struct MeminfoValue {
pub key: Option<i32>,
pub value: Option<u64>,
}Expand description
Counters from /proc/meminfo. Values are in KB.
Fields
key: Option<i32>value: Option<u64>Implementations
Sourceimpl MeminfoValue
impl MeminfoValue
Sourcepub fn key(&self) -> MeminfoCounters
pub fn key(&self) -> MeminfoCounters
Returns the enum value of key, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_key(&mut self, value: MeminfoCounters)
pub fn set_key(&mut self, value: MeminfoCounters)
Sets key to the provided enum value.