pub struct PsiSample {
pub resource: Option<i32>,
pub total_ns: Option<u64>,
}Expand description
Reading from /proc/pressure/*.
Fields
resource: Option<i32>total_ns: Option<u64>Total absolute stall time (in nanos) for a given resource. While PSI readings are in micros, we store in nanos for consistency with most other time-based counters.
Implementations
Sourceimpl PsiSample
impl PsiSample
Sourcepub fn resource(&self) -> PsiResource
pub fn resource(&self) -> PsiResource
Returns the enum value of resource, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_resource(&mut self, value: PsiResource)
pub fn set_resource(&mut self, value: PsiResource)
Sets resource to the provided enum value.