pub struct VmstatValue {
pub key: Option<i32>,
pub value: Option<u64>,
}Expand description
Counter from /proc/vmstat. Units are often pages, not KB.
Fields
key: Option<i32>value: Option<u64>Implementations
Sourceimpl VmstatValue
impl VmstatValue
Sourcepub fn key(&self) -> VmstatCounters
pub fn key(&self) -> VmstatCounters
Returns the enum value of key, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_key(&mut self, value: VmstatCounters)
pub fn set_key(&mut self, value: VmstatCounters)
Sets key to the provided enum value.