#[repr(i32)]pub enum ChromeThreadType {
Show 14 variants
ChromeThreadUnspecified = 0,
ChromeThreadMain = 1,
ChromeThreadIo = 2,
ChromeThreadPoolBgWorker = 3,
ChromeThreadPoolFgWorker = 4,
ChromeThreadPoolFbBlocking = 5,
ChromeThreadPoolBgBlocking = 6,
ChromeThreadPoolService = 7,
ChromeThreadCompositor = 8,
ChromeThreadVizCompositor = 9,
ChromeThreadCompositorWorker = 10,
ChromeThreadServiceWorker = 11,
ChromeThreadMemoryInfra = 50,
ChromeThreadSamplingProfiler = 51,
}Variants
ChromeThreadUnspecified = 0
ChromeThreadMain = 1
ChromeThreadIo = 2
ChromeThreadPoolBgWorker = 3
Scheduler:
ChromeThreadPoolFgWorker = 4
ChromeThreadPoolFbBlocking = 5
ChromeThreadPoolBgBlocking = 6
ChromeThreadPoolService = 7
ChromeThreadCompositor = 8
Compositor:
ChromeThreadVizCompositor = 9
ChromeThreadCompositorWorker = 10
ChromeThreadServiceWorker = 11
Renderer:
ChromeThreadMemoryInfra = 50
Tracing related threads:
ChromeThreadSamplingProfiler = 51
Implementations
Sourceimpl ChromeThreadType
impl ChromeThreadType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<ChromeThreadType>
pub fn from_str_name(value: &str) -> Option<ChromeThreadType>
Creates an enum from field names used in the ProtoBuf definition.