BuiltinDataSource

Struct BuiltinDataSource 

pub struct BuiltinDataSource {
    pub disable_clock_snapshotting: Option<bool>,
    pub disable_trace_config: Option<bool>,
    pub disable_system_info: Option<bool>,
    pub disable_service_events: Option<bool>,
    pub primary_trace_clock: Option<i32>,
    pub snapshot_interval_ms: Option<u32>,
    pub prefer_suspend_clock_for_snapshot: Option<bool>,
    pub disable_chunk_usage_histograms: Option<bool>,
}
Config for disabling builtin data sources in the tracing service.

Fields

disable_clock_snapshotting: Option<bool>

Disable emitting clock timestamps into the trace.

disable_trace_config: Option<bool>

Disable echoing the original trace config in the trace.

disable_system_info: Option<bool>

Disable emitting system info (build fingerprint, cpuinfo, etc).

disable_service_events: Option<bool>

Disable emitting events for data-source state changes (e.g. the marker for all data sources having ACKed the start of the trace).

primary_trace_clock: Option<i32>

The authoritative clock domain for the trace. Defaults to BOOTTIME. See also ClockSnapshot’s primary_trace_clock. The configured value is written into the trace as part of the ClockSnapshots emitted by the service. Trace processor will attempt to translate packet/event timestamps from various data sources (and their chosen clock domains) to this domain during import. Added in Android R.

snapshot_interval_ms: Option<u32>

Time interval in between snapshotting of sync markers, clock snapshots, stats, and other periodic service-emitted events. Note that the service only keeps track of the first and the most recent snapshot until ReadBuffers() is called.

prefer_suspend_clock_for_snapshot: Option<bool>

Hints to the service that a suspend-aware (i.e. counting time in suspend) clock should be used for periodic snapshots of service-emitted events. This means, if a snapshot should have happened during suspend, it will happen immediately after the device resumes.

Choosing a clock like this is done on best-effort basis; not all platforms (e.g. Windows) expose a clock which can be used for periodic tasks counting suspend. If such a clock is not available, the service falls back to the best-available alternative.

Introduced in Android S. TODO(lalitm): deprecate this in T and make this the default if nothing crashes in S.

disable_chunk_usage_histograms: Option<bool>

Disables the reporting of per-trace-writer histograms in TraceStats.

Implementations

Source

impl BuiltinDataSource

pub fn disable_clock_snapshotting(&self) -> bool

Returns the value of disable_clock_snapshotting, or the default value if disable_clock_snapshotting is unset.

pub fn disable_trace_config(&self) -> bool

Returns the value of disable_trace_config, or the default value if disable_trace_config is unset.

pub fn disable_system_info(&self) -> bool

Returns the value of disable_system_info, or the default value if disable_system_info is unset.

pub fn disable_service_events(&self) -> bool

Returns the value of disable_service_events, or the default value if disable_service_events is unset.

pub fn primary_trace_clock(&self) -> BuiltinClock

Returns the enum value of primary_trace_clock, or the default if the field is unset or set to an invalid enum value.

pub fn set_primary_trace_clock(&mut self, value: BuiltinClock)

Sets primary_trace_clock to the provided enum value.

pub fn snapshot_interval_ms(&self) -> u32

Returns the value of snapshot_interval_ms, or the default value if snapshot_interval_ms is unset.

pub fn prefer_suspend_clock_for_snapshot(&self) -> bool

Returns the value of prefer_suspend_clock_for_snapshot, or the default value if prefer_suspend_clock_for_snapshot is unset.

pub fn disable_chunk_usage_histograms(&self) -> bool

Returns the value of disable_chunk_usage_histograms, or the default value if disable_chunk_usage_histograms is unset.