pub struct CmdTraceStartDelay {
pub min_delay_ms: Option<u32>,
pub max_delay_ms: Option<u32>,
}Expand description
If set, delays the start of tracing by a random duration. The duration is chosen from a uniform distribution between the specified minimum and maximum. Note: this delay is implemented by perfetto_cmd not by traced so will not work if you communicate with traced directly over the consumer API. Introduced in Android T.
Fields
min_delay_ms: Option<u32>max_delay_ms: Option<u32>Implementations
Sourceimpl CmdTraceStartDelay
impl CmdTraceStartDelay
Sourcepub fn min_delay_ms(&self) -> u32
pub fn min_delay_ms(&self) -> u32
Returns the value of min_delay_ms, or the default value if min_delay_ms is unset.
Sourcepub fn max_delay_ms(&self) -> u32
pub fn max_delay_ms(&self) -> u32
Returns the value of max_delay_ms, or the default value if max_delay_ms is unset.