IncidentReportConfig

Struct IncidentReportConfig 

pub struct IncidentReportConfig {
    pub destination_package: Option<String>,
    pub destination_class: Option<String>,
    pub privacy_level: Option<i32>,
    pub skip_incidentd: Option<bool>,
    pub skip_dropbox: Option<bool>,
}
Android-only. Not for general use. If set, saves the trace into an incident. This field is read by perfetto_cmd, rather than the tracing service. This field must be set when passing the –upload flag to perfetto_cmd.

In this message, either:

  • all of |destination_package|, |destination_class| and |privacy_level| must be set.
  • |skip_incidentd| must be explicitly set to true.

Fields

destination_package: Option<String>destination_class: Option<String>privacy_level: Option<i32>

Level of filtering in the requested incident. See |Destination| in frameworks/base/core/proto/android/privacy.proto.

skip_incidentd: Option<bool>

If true, then skips saving the trace to incidentd.

This flag is useful in testing (e.g. Perfetto-statsd integration tests) or when we explicitly don’t want traces to go to incidentd even when they usually would (e.g. configs deployed using statsd but only used for inclusion in bugreports using |bugreport_score|).

The motivation for having this flag, instead of just not setting |incident_report_config|, is prevent accidents where |incident_report_config| is omitted by mistake.

skip_dropbox: Option<bool>
👎Deprecated

If true, do not write the trace into dropbox (i.e. incident only). Otherwise, write to both dropbox and incident. TODO(lalitm): remove this field as we no longer use Dropbox.

Implementations

Source

impl IncidentReportConfig

pub fn destination_package(&self) -> &str

Returns the value of destination_package, or the default value if destination_package is unset.

pub fn destination_class(&self) -> &str

Returns the value of destination_class, or the default value if destination_class is unset.

pub fn privacy_level(&self) -> i32

Returns the value of privacy_level, or the default value if privacy_level is unset.

pub fn skip_dropbox(&self) -> bool

Returns the value of skip_dropbox, or the default value if skip_dropbox is unset.

pub fn skip_incidentd(&self) -> bool

Returns the value of skip_incidentd, or the default value if skip_incidentd is unset.