IncrementalStateConfig

Struct IncrementalStateConfig 

pub struct IncrementalStateConfig {
    pub clear_period_ms: Option<u32>,
}
Configuration for trace contents that reference earlier trace data. For example, a data source might intern strings, and emit packets containing {interned id : string} pairs. Future packets from that data source can then use the interned ids instead of duplicating the raw string contents. The trace parser will then need to use that interning table to fully interpret the rest of the trace.

Fields

clear_period_ms: Option<u32>

If nonzero, notify eligible data sources to clear their incremental state periodically, with the given period. The notification is sent only to data sources that have |handles_incremental_state_clear| set in their DataSourceDescriptor. The notification requests that the data source stops referring to past trace contents. This is particularly useful when tracing in ring buffer mode, where it is not exceptional to overwrite old trace data.

Warning: this time-based global clearing is likely to be removed in the future, to be replaced with a smarter way of sending the notifications only when necessary.

Implementations

Source

impl IncrementalStateConfig

pub fn clear_period_ms(&self) -> u32

Returns the value of clear_period_ms, or the default value if clear_period_ms is unset.