pub struct ProducerConfig {
pub producer_name: Option<String>,
pub shm_size_kb: Option<u32>,
pub page_size_kb: Option<u32>,
}Fields
producer_name: Option<String>Identifies the producer for which this config is for.
shm_size_kb: Option<u32>Specifies the preferred size of the shared memory buffer. If the size is larger than the max size, the max will be used. If it is smaller than the page size or doesn’t fit pages evenly into it, it will fall back to the size specified by the producer or finally the default shared memory size.
page_size_kb: Option<u32>Specifies the preferred size of each page in the shared memory buffer. Must be an integer multiple of 4K.
Implementations
Sourceimpl ProducerConfig
impl ProducerConfig
Sourcepub fn producer_name(&self) -> &str
pub fn producer_name(&self) -> &str
Returns the value of producer_name, or the default value if producer_name is unset.
Sourcepub fn shm_size_kb(&self) -> u32
pub fn shm_size_kb(&self) -> u32
Returns the value of shm_size_kb, or the default value if shm_size_kb is unset.
Sourcepub fn page_size_kb(&self) -> u32
pub fn page_size_kb(&self) -> u32
Returns the value of page_size_kb, or the default value if page_size_kb is unset.