pub struct TraceFilter {
pub bytecode: Option<Vec<u8>>,
pub bytecode_v2: Option<Vec<u8>>,
pub string_filter_chain: Option<StringFilterChain>,
}Expand description
When set applies a post-filter to the trace contents using the filter
provided. The filter is applied at ReadBuffers() time and works both in the
case of IPC readback and write_into_file. This filter can be generated
using tools/proto_filter -s schema.proto -F filter_out.bytes or
-T filter_out.escaped_string (for .pbtx). See go/trace-filtering for
design.
Introduced in Android S, but it was broken (b/195065199). Reintroduced in Android T with a different field number. Updated in Android U with a new bytecode version which supports string filtering.
========================= Filter bytecode.
Fields
bytecode: Option<Vec<u8>>The bytecode as implemented in Android T.
bytecode_v2: Option<Vec<u8>>The bytecode as implemented in Android U. Adds support for string filtering.
string_filter_chain: Option<StringFilterChain>Implementations