pub enum OptionalTrustedPacketSequenceId {
TrustedPacketSequenceId(u32),
}Expand description
Service-assigned identifier of the packet sequence this packet belongs to. Uniquely identifies a producer + writer pair within the tracing session. A value of zero denotes an invalid ID. Keep in sync with TrustedPacket.trusted_packet_sequence_id.
Variants
Implementations
Sourceimpl OptionalTrustedPacketSequenceId
impl OptionalTrustedPacketSequenceId
Sourcepub fn merge(
field: &mut Option<OptionalTrustedPacketSequenceId>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<OptionalTrustedPacketSequenceId>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.