pub struct FilterStats {
pub input_packets: Option<u64>,
pub input_bytes: Option<u64>,
pub output_bytes: Option<u64>,
pub errors: Option<u64>,
pub time_taken_ns: Option<u64>,
pub bytes_discarded_per_buffer: Vec<u64>,
}Expand description
This is set only when the TraceConfig specifies a TraceFilter.
Fields
input_packets: Option<u64>input_bytes: Option<u64>output_bytes: Option<u64>errors: Option<u64>time_taken_ns: Option<u64>bytes_discarded_per_buffer: Vec<u64>The number of bytes discarded by the filter (i.e. output - input). The array has one entry for each buffer defined in the config (unless no packets for that buffer were seen and hence filtered). Note: the SUM(bytes_discarded_per_buffer) will be <= but not == the total (output_bytes - input_bytes) because the filter might also discard server-generated synthetic packets, that have no buffer index.
Implementations
Sourceimpl FilterStats
impl FilterStats
Sourcepub fn input_packets(&self) -> u64
pub fn input_packets(&self) -> u64
Returns the value of input_packets, or the default value if input_packets is unset.
Sourcepub fn input_bytes(&self) -> u64
pub fn input_bytes(&self) -> u64
Returns the value of input_bytes, or the default value if input_bytes is unset.
Sourcepub fn output_bytes(&self) -> u64
pub fn output_bytes(&self) -> u64
Returns the value of output_bytes, or the default value if output_bytes is unset.
Sourcepub fn errors(&self) -> u64
pub fn errors(&self) -> u64
Returns the value of errors, or the default value if errors is unset.
Sourcepub fn time_taken_ns(&self) -> u64
pub fn time_taken_ns(&self) -> u64
Returns the value of time_taken_ns, or the default value if time_taken_ns is unset.