pub struct WriterStats {
pub sequence_id: Option<u64>,
pub buffer: Option<u32>,
pub chunk_payload_histogram_counts: Vec<u64>,
pub chunk_payload_histogram_sum: Vec<i64>,
}Expand description
Per TraceWriter stat. Each {producer, trace writer} tuple is publicly visible as a unique sequence ID in the trace.
Fields
sequence_id: Option<u64>This matches the TracePacket.trusted_packet_sequence_id and is used to correlate the stats with the actual packet types.
buffer: Option<u32>The buffer index (0..N, as defined in the TraceConfig).
chunk_payload_histogram_counts: Vec<u64>These two arrays have the same cardinality and match the cardinality of
chunk_payload_histogram_def + 1 (for the overflow bucket, see below).
sum contains the SUM(entries) and counts contains the COUNT(entries)
for each bucket.
chunk_payload_histogram_sum: Vec<i64>Implementations
Sourceimpl WriterStats
impl WriterStats