pub enum NameField {
NameIid(u64),
Name(String),
}Expand description
Optional name of the event for its display in trace viewer. May be left unspecified for events with typed arguments.
Note that metrics should not rely on event names, as they are prone to changing. Instead, they should use typed arguments to identify the events they are interested in.
Variants
Implementations
Sourceimpl NameField
impl NameField
Sourcepub fn merge(
field: &mut Option<NameField>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<NameField>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.