pub enum SourceLocationField {
SourceLocation(SourceLocation),
SourceLocationIid(u64),
}Expand description
This field is used only if the source location represents the function that executes during this event.
Variants
Implementations
Sourceimpl SourceLocationField
impl SourceLocationField
Sourcepub fn merge(
field: &mut Option<SourceLocationField>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<SourceLocationField>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.