pub enum ThreadInstructionCount {
ThreadInstructionCountDelta(i64),
ThreadInstructionCountAbsolute(i64),
}Expand description
Deprecated. Use |extra_counter_values| and |extra_counter_track_uuids| to encode thread instruction count instead.
Value of the instruction counter for the current thread.
Variants
ThreadInstructionCountDelta(i64)
Same encoding as |thread_time| field above.
ThreadInstructionCountAbsolute(i64)
Implementations
Sourceimpl ThreadInstructionCount
impl ThreadInstructionCount
Sourcepub fn merge(
field: &mut Option<ThreadInstructionCount>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<ThreadInstructionCount>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.