pub enum ThreadTime {
ThreadTimeDeltaUs(i64),
ThreadTimeAbsoluteUs(i64),
}Expand description
Deprecated. Use |extra_counter_values| and |extra_counter_track_uuids| to encode thread time instead.
CPU time for the current thread (e.g., CLOCK_THREAD_CPUTIME_ID) in microseconds.
Variants
ThreadTimeDeltaUs(i64)
Delta timestamp value since the last TrackEvent or ThreadDescriptor. To calculate the absolute timestamp value, sum up all delta values of the preceding TrackEvents since the last ThreadDescriptor and add the sum to the |reference_timestamp| in ThreadDescriptor. This value should always be positive.
ThreadTimeAbsoluteUs(i64)
This is a one-off absolute value that does not affect delta timestamp computation in subsequent TrackEvents.
Implementations
Sourceimpl ThreadTime
impl ThreadTime
Sourcepub fn merge(
field: &mut Option<ThreadTime>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<ThreadTime>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.