#[repr(i32)]pub enum MagicNumber {
Invalid = 0,
L = 1_415_073_364,
H = 1_162_035_538,
}Expand description
constant; MAGIC_NUMBER = (long) MAGIC_NUMBER_H << 32 | MagicNumber.MAGIC_NUMBER_L (this is needed because enums have to be 32 bits and there’s no nice way to put 64bit constants into .proto files.
Variants
Invalid = 0
L = 1_415_073_364
TNXT (little-endian ASCII)
H = 1_162_035_538
RACE (little-endian ASCII)
Implementations
Sourceimpl MagicNumber
impl MagicNumber
Sourceimpl MagicNumber
impl MagicNumber
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<MagicNumber>
pub fn from_str_name(value: &str) -> Option<MagicNumber>
Creates an enum from field names used in the ProtoBuf definition.