pub enum Selector {
Pid(u32),
Cmdline(String),
}Variants
Pid(u32)
The pid of the process to highlight. This is useful for UIs to focus on tracks of a particular process in the trace.
If more than one process in a trace has the same pid, it is UI implementation specific how the process to be focused will be chosen.
Cmdline(String)
The command line of the process to highlight; for most Android apps, this is the package name of the app. This is useful for UIs to focus on a particular app in the trace.
If more than one process hasthe same cmdline, it is UI implementation specific how the process to be focused will be chosen.
Implementations
Sourceimpl Selector
impl Selector
Sourcepub fn merge(
field: &mut Option<Selector>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Selector>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.