pub struct CronTask { /* private fields */ }Expand description
Represents a task scheduled to run periodically.
Implementations
Sourceimpl CronTask
impl CronTask
Sourcepub fn new(
name: String,
period: TimeDelta,
offset: TimeDelta,
callback: Arc<dyn TaskCallback>,
) -> Result<Self>
pub fn new( name: String, period: TimeDelta, offset: TimeDelta, callback: Arc<dyn TaskCallback>, ) -> Result<Self>
Creates a new CronTask.
The next_run time is calculated based on the current time, period, and offset.
Sourcepub fn get_next_run(&self) -> DateTime<Utc>
pub fn get_next_run(&self) -> DateTime<Utc>
Returns the next scheduled run time for the task.
This value is updated after each successful spawn operation.