pub fn register_routes(router: Router) -> RouterExpand description
Registers the ingestion routes with the given Axum Router.
This function adds routes for /ingestion/insert_process,
/ingestion/insert_stream, and /ingestion/insert_block.
pub fn register_routes(router: Router) -> RouterRegisters the ingestion routes with the given Axum Router.
This function adds routes for /ingestion/insert_process,
/ingestion/insert_stream, and /ingestion/insert_block.