pub fn key_from_string<'de, D>(deserializer: D) -> Result<Key, D::Error>where
D: Deserializer<'de>,Expand description
Deserializes a string into a Key.
This function is used by serde to deserialize the key from a JSON string.
pub fn key_from_string<'de, D>(deserializer: D) -> Result<Key, D::Error>where
D: Deserializer<'de>,Deserializes a string into a Key.
This function is used by serde to deserialize the key from a JSON string.