get_global_views_with_update_group

Function get_global_views_with_update_group 

pub fn get_global_views_with_update_group(
    view_factory: &ViewFactory,
) -> Vec<Arc<dyn View>>
Retrieves a list of global views that have an associated update group.

This function filters the global views provided by the view_factory, returning only those that are part of an update group.