pub struct Block {
pub block_id: Uuid,
pub stream_id: Uuid,
pub process_id: Uuid,
pub begin_time: String,
pub begin_ticks: i64,
pub end_time: String,
pub end_ticks: i64,
pub payload: BlockPayload,
pub object_offset: i64,
pub nb_objects: i32,
}Expand description
Block metadata sent by instrumented processes.
A block represents a chunk of telemetry data from a single stream. It contains timing information, references to the process and stream, and the actual payload of telemetry events.
Fields
block_id: Uuidstream_id: Uuidprocess_id: Uuidbegin_time: Stringwe send both RFC3339 times and ticks to be able to calibrate the tick
begin_ticks: i64end_time: Stringend_ticks: i64payload: BlockPayloadobject_offset: i64nb_objects: i32Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Block
impl<'de> Deserialize<'de> for Block
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<Block, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Block, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for Block
impl Serialize for Block
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more