pub struct BlockPayload {
pub dependencies: Vec<u8>,
pub objects: Vec<u8>,
}Expand description
Payload sent by instrumented processes, containing serialized dependencies and objects.
The dependencies field contains the serialized data for all the
UserDefinedType that are required to deserialize the objects.
Fields
dependencies: Vec<u8>objects: Vec<u8>Trait Implementations
Sourceimpl Clone for BlockPayload
impl Clone for BlockPayload
Sourcefn clone(&self) -> BlockPayload
fn clone(&self) -> BlockPayload
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BlockPayload
impl Debug for BlockPayload
Sourceimpl<'de> Deserialize<'de> for BlockPayload
impl<'de> Deserialize<'de> for BlockPayload
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<BlockPayload, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<BlockPayload, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for BlockPayload
impl Serialize for BlockPayload
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more