pub struct StreamInfo {
pub process_id: Uuid,
pub stream_id: Uuid,
pub dependencies_metadata: Vec<UserDefinedType>,
pub objects_metadata: Vec<UserDefinedType>,
pub tags: Vec<String>,
pub properties: HashMap<String, String>,
}Expand description
Contains information about a telemetry stream.
This struct is sent once at the beginning of a stream and provides metadata about the stream, such as the process and stream IDs, dependencies, and other properties.
Fields
process_id: Uuidstream_id: Uuiddependencies_metadata: Vec<UserDefinedType>objects_metadata: Vec<UserDefinedType>properties: HashMap<String, String>Trait Implementations
Sourceimpl Debug for StreamInfo
impl Debug for StreamInfo
Sourceimpl<'de> Deserialize<'de> for StreamInfo
impl<'de> Deserialize<'de> for StreamInfo
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<StreamInfo, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<StreamInfo, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for StreamInfo
impl Serialize for StreamInfo
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more