pub struct CompositeSink { /* private fields */ }Expand description
An EventSink that dispatches events to multiple other EventSinks.
This allows for fanning out telemetry events to different sinks, each with its own filtering and processing logic.
Implementations
Sourceimpl CompositeSink
impl CompositeSink
Sourcepub fn new(
sinks: Vec<(LevelFilter, Box<dyn EventSink>)>,
target_max_level: Vec<(String, LevelFilter)>,
max_level_override: Option<LevelFilter>,
) -> CompositeSink
pub fn new( sinks: Vec<(LevelFilter, Box<dyn EventSink>)>, target_max_level: Vec<(String, LevelFilter)>, max_level_override: Option<LevelFilter>, ) -> CompositeSink
Creates a new CompositeSink.