pub enum RequestDecoratorError {
Permanent(String),
Transient(String),
}Expand description
An error that can occur when decorating a request.
Depending on the type of error, the request may be retried at a later time.
Variants
Permanent(String)
A permanent error occurred while decorating the request.
No further attempts to decorate the request should be made.
Transient(String)
A transient error occurred while decorating the request.
The request may be retried at a later time.