Struct Attempt
pub struct Attempt<'a> { /* private fields */ }Expand description
A type that holds information on the next request and previous requests in redirect chain.
Implementations
impl<'a> Attempt<'a>
impl<'a> Attempt<'a>
pub fn status(&self) -> StatusCode
pub fn status(&self) -> StatusCode
Get the type of redirect.
pub fn previous(&self) -> &[Url]
pub fn previous(&self) -> &[Url]
Get the list of previous URLs that have already been requested in this chain.