Function never
pub fn never() -> BuilderExpand description
Create a retry policy that will never retry any request.
This is useful for disabling the Clients default behavior of retrying
protocol nacks.
pub fn never() -> BuilderCreate a retry policy that will never retry any request.
This is useful for disabling the Clients default behavior of retrying
protocol nacks.