IntoUrl

Trait IntoUrl 

pub trait IntoUrl: IntoUrlSealed { }
A trait to try to convert some type into a Url.

This trait is “sealed”, such that only types within reqwest can implement it.

Implementations on Foreign Types



impl IntoUrl for String



impl<'a> IntoUrl for &'a str



impl<'a> IntoUrl for &'a String

Implementors



impl IntoUrl for Url