pub fn spawn_system_monitor()Expand description
Spawns a new thread to run the send_system_metrics_forever function.
This allows system metrics to be collected and reported in the background.
pub fn spawn_system_monitor()Spawns a new thread to run the send_system_metrics_forever function.
This allows system metrics to be collected and reported in the background.