Enum RetryError
pub enum RetryError<E> {
Permanent(E),
Transient {
err: E,
retry_after: Option<Duration>,
},
}Expand description
Error is the error value in an actions’s retry result.
Based on the two possible values, the operation may be retried.
Variants
Permanent(E)
Permanent means that it’s impossible to execute the operation
successfully. This error is an early return from the retry operation.
Transient
Transient means that the error is temporary. If the retry_after is None
the operation should be retried according to the defined strategy policy, else after
the specified duration. Useful for handling rate limits like a HTTP 429 response.
Implementations
impl<E> Error<E>
impl<E> Error<E>
pub fn permanent(err: E) -> Error<E>
pub fn to_permanent<T>(err: E) -> Result<T, Error<E>>
pub fn transient(err: E) -> Error<E>
pub fn to_transient<T>(err: E) -> Result<T, Error<E>>
pub fn to_retry_after<T>(err: E, duration: Duration) -> Result<T, Error<E>>
pub fn to_retry_after<T>(err: E, duration: Duration) -> Result<T, Error<E>>
Creates a Result::Err container with a transient error which is retried after the specified duration. Useful for handling rate limits like a HTTP 429 response.
pub fn retry_after(err: E, duration: Duration) -> Error<E>
pub fn retry_after(err: E, duration: Duration) -> Error<E>
Creates a transient error which is retried after the specified duration. Useful for handling rate limits like a HTTP 429 response.