install_tracing_interop

Function install_tracing_interop 

pub fn install_tracing_interop(interop_max_level_override: Option<LevelFilter>)
Installs a tracing layer that forwards events to the Micromegas tracing system.

This allows applications using the tracing crate to integrate with Micromegas telemetry.

Arguments

  • interop_max_level_override - An optional LevelFilter to override the maximum level for the tracing layer. If None, the global Micromegas max level is used.