force_uninit

Function force_uninit 

pub unsafe fn force_uninit()
Safety

very unsafe! make sure there is no thread running that could be sending events normally that global state should not be destroyed