pub fn unregister_thread_stream()Expand description
Unregisters the current thread’s stream from the global dispatch to prevent dangling pointers when the thread is destroyed.
pub fn unregister_thread_stream()Unregisters the current thread’s stream from the global dispatch to prevent dangling pointers when the thread is destroyed.