pub struct InMemorySink {
pub state: Mutex<MemSinkState>,
}Expand description
for tests where we want to inspect the collected data
Fields
state: Mutex<MemSinkState>Implementations
Sourceimpl InMemorySink
impl InMemorySink
pub fn new() -> InMemorySink
Sourceimpl InMemorySink
impl InMemorySink
Sourcepub fn thread_block_count(&self) -> usize
pub fn thread_block_count(&self) -> usize
Get the total number of thread blocks collected
Sourcepub fn log_block_count(&self) -> usize
pub fn log_block_count(&self) -> usize
Get the total number of log blocks collected
Sourcepub fn metrics_block_count(&self) -> usize
pub fn metrics_block_count(&self) -> usize
Get the total number of metrics blocks collected
Sourcepub fn total_thread_events(&self) -> usize
pub fn total_thread_events(&self) -> usize
Get the total number of events across all thread blocks
Sourcepub fn total_log_events(&self) -> usize
pub fn total_log_events(&self) -> usize
Get the total number of events across all log blocks
Sourcepub fn total_metrics_events(&self) -> usize
pub fn total_metrics_events(&self) -> usize
Get the total number of events across all metrics blocks