pub trait ExtractDeps {
type DepsQueue;
// Required method
fn extract(&self) -> Self::DepsQueue;
}Expand description
Serialize the dependencies of the events in the primary queue
pub trait ExtractDeps {
type DepsQueue;
// Required method
fn extract(&self) -> Self::DepsQueue;
}Serialize the dependencies of the events in the primary queue