#[repr(u32)]pub enum LodFilter {
Off = 0,
Min = 1,
Med = 2,
Max = 3,
}Expand description
An enum representing the available verbosity level filters of the logger.
Variants
Off = 0
A level lower than all log levels.
Min = 1
Corresponds to the Min log level.
Med = 2
Corresponds to the Med log level.
Max = 3
Corresponds to the Max log level.
Implementations
Sourceimpl LodFilter
impl LodFilter
Sourcepub fn to_level(self) -> Option<Verbosity>
pub fn to_level(self) -> Option<Verbosity>
Converts self to the equivalent Lod.
Returns None if self is LodFilter::Off.
Sourcepub fn as_str(self) -> &'static str
pub fn as_str(self) -> &'static str
Returns the string representation of the LodFilter.
This returns the same string as the fmt::Display implementation.
Sourcepub fn iter() -> impl Iterator<Item = LodFilter>
pub fn iter() -> impl Iterator<Item = LodFilter>
Iterate through all supported filtering levels.
The order of iteration is from less to more verbose filtering.
Examples
use micromegas_tracing::prelude::*;
let mut lod_filters = LodFilter::iter();
assert_eq!(Some(LodFilter::Off), lod_filters.next());
assert_eq!(Some(LodFilter::Max), lod_filters.last());Trait Implementations
Sourceimpl Ord for LodFilter
impl Ord for LodFilter
Sourceimpl PartialOrd<LodFilter> for Verbosity
impl PartialOrd<LodFilter> for Verbosity
Sourceimpl PartialOrd<Verbosity> for LodFilter
impl PartialOrd<Verbosity> for LodFilter
Sourceimpl PartialOrd for LodFilter
impl PartialOrd for LodFilter
impl Copy for LodFilter
impl Eq for LodFilter
impl StructuralPartialEq for LodFilter