pub enum FilterState {
Outdated,
NotSet,
Set(LevelFilter),
}Variants
Outdated
The filter needs to be updated.
NotSet
The filter is up to date but no filter is set.
Set(LevelFilter)
The filter is up to date a filter level is set.