pub struct LogMetadata<'a> {
pub level: Level,
pub level_filter: AtomicU32,
pub fmt_str: &'a str,
pub target: &'a str,
pub module_path: &'a str,
pub file: &'a str,
pub line: u32,
}Fields
level: Levellevel_filter: AtomicU32fmt_str: &'a strtarget: &'a strmodule_path: &'a strfile: &'a strline: u32Implementations
Sourceimpl LogMetadata<'_>
impl LogMetadata<'_>
Sourcepub fn level_filter(&self, generation: u16) -> FilterState
pub fn level_filter(&self, generation: u16) -> FilterState
This is a way to efficiency implement finer grade filtering by amortizing its cost. An atomic is used to store a level filter and a 16 bit generation. Allowing a config update to be applied to the level filter multiple times during the lifetime of the process.
ⓘ
const GENERATION: u16 = 1;
let level_filter = metadata.level_filter(GENERATION).unwrap_or_else(|| {
let level_filter = self.level_filter(metadata.target);
metadata.set_level_filter(level_filter, GENERATION);
level_filter
});
if metadata.level <= level_filter {
...
}Sourcepub fn set_level_filter(
&self,
generation: u16,
level_filter: Option<LevelFilter>,
)
pub fn set_level_filter( &self, generation: u16, level_filter: Option<LevelFilter>, )
Sets the level filter if the generation is greater than the current generation.