pub struct IntegerMetricEvent {
pub desc: &'static StaticMetricMetadata,
pub value: u64,
pub time: i64,
}Expand description
Measure (int) with static metadata Will be converted to a floating point value when processed by the analytics library
Fields
desc: &'static StaticMetricMetadatavalue: u64time: i64Trait Implementations
Sourceimpl Debug for IntegerMetricEvent
impl Debug for IntegerMetricEvent
Sourceimpl InProcSerialize for IntegerMetricEvent
impl InProcSerialize for IntegerMetricEvent
const IN_PROC_SIZE: InProcSize = _
fn get_value_size(&self) -> Option<u32>
fn write_value(&self, buffer: &mut Vec<u8>)
Sourceunsafe fn read_value(window: &[u8]) -> Self
unsafe fn read_value(window: &[u8]) -> Self
Safety Read more
Sourceimpl MetricsMsgQueueTypeIndex for IntegerMetricEvent
impl MetricsMsgQueueTypeIndex for IntegerMetricEvent
const TYPE_INDEX: u8 = 0u8
Sourceimpl Reflect for IntegerMetricEvent
impl Reflect for IntegerMetricEvent
fn reflect() -> UserDefinedType