#[repr(u32)]pub enum LevelFilter {
Off = 0,
Fatal = 1,
Error = 2,
Warn = 3,
Info = 4,
Debug = 5,
Trace = 6,
}Expand description
An enum representing the available verbosity level filters of the logger.
Variants
Off = 0
A level lower than all log levels.
Fatal = 1
Corresponds to the Fatal log level.
Error = 2
Corresponds to the Error log level.
Warn = 3
Corresponds to the Warn log level.
Info = 4
Corresponds to the Info log level.
Debug = 5
Corresponds to the Debug log level.
Trace = 6
Corresponds to the Trace log level.
Implementations
Sourceimpl LevelFilter
impl LevelFilter
Sourcepub fn max() -> LevelFilter
pub fn max() -> LevelFilter
Returns the most verbose logging level filter.
Sourcepub fn to_level(self) -> Option<Level>
pub fn to_level(self) -> Option<Level>
Converts self to the equivalent Level.
Returns None if self is LevelFilter::Off.
Sourcepub fn as_str(self) -> &'static str
pub fn as_str(self) -> &'static str
Returns the string representation of the LevelFilter.
This returns the same string as the fmt::Display implementation.
Sourcepub fn iter() -> impl Iterator<Item = LevelFilter>
pub fn iter() -> impl Iterator<Item = LevelFilter>
Iterate through all supported filtering levels.
The order of iteration is from less to more verbose filtering.
Examples
use micromegas_tracing::prelude::*;
let mut levels = LevelFilter::iter();
assert_eq!(Some(LevelFilter::Off), levels.next());
assert_eq!(Some(LevelFilter::Trace), levels.last());Trait Implementations
Sourceimpl Clone for LevelFilter
impl Clone for LevelFilter
Sourcefn clone(&self) -> LevelFilter
fn clone(&self) -> LevelFilter
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LevelFilter
impl Debug for LevelFilter
Sourceimpl Display for LevelFilter
impl Display for LevelFilter
Sourceimpl FromStr for LevelFilter
impl FromStr for LevelFilter
Sourcetype Err = ParseLevelError
type Err = ParseLevelError
The associated error which can be returned from parsing.
Sourcefn from_str(level: &str) -> Result<LevelFilter, <LevelFilter as FromStr>::Err>
fn from_str(level: &str) -> Result<LevelFilter, <LevelFilter as FromStr>::Err>
Parses a string
s to return a value of this type. Read moreSourceimpl Hash for LevelFilter
impl Hash for LevelFilter
Sourceimpl Ord for LevelFilter
impl Ord for LevelFilter
Sourcefn cmp(&self, other: &LevelFilter) -> Ordering
fn cmp(&self, other: &LevelFilter) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq<Level> for LevelFilter
impl PartialEq<Level> for LevelFilter
Sourceimpl PartialEq<LevelFilter> for Level
impl PartialEq<LevelFilter> for Level
Sourceimpl PartialEq for LevelFilter
impl PartialEq for LevelFilter
Sourceimpl PartialOrd<Level> for LevelFilter
impl PartialOrd<Level> for LevelFilter
Sourceimpl PartialOrd<LevelFilter> for Level
impl PartialOrd<LevelFilter> for Level
Sourcefn partial_cmp(&self, other: &LevelFilter) -> Option<Ordering>
fn partial_cmp(&self, other: &LevelFilter) -> Option<Ordering>
Sourcefn lt(&self, other: &LevelFilter) -> bool
fn lt(&self, other: &LevelFilter) -> bool
Sourcefn le(&self, other: &LevelFilter) -> bool
fn le(&self, other: &LevelFilter) -> bool
Sourcefn gt(&self, other: &LevelFilter) -> bool
fn gt(&self, other: &LevelFilter) -> bool
Sourceimpl PartialOrd for LevelFilter
impl PartialOrd for LevelFilter
Sourcefn partial_cmp(&self, other: &LevelFilter) -> Option<Ordering>
fn partial_cmp(&self, other: &LevelFilter) -> Option<Ordering>
Sourcefn lt(&self, other: &LevelFilter) -> bool
fn lt(&self, other: &LevelFilter) -> bool
Sourcefn le(&self, other: &LevelFilter) -> bool
fn le(&self, other: &LevelFilter) -> bool
Sourcefn gt(&self, other: &LevelFilter) -> bool
fn gt(&self, other: &LevelFilter) -> bool
impl Copy for LevelFilter
impl Eq for LevelFilter
impl StructuralPartialEq for LevelFilter