#[repr(u32)]pub enum Verbosity {
Min = 1,
Med = 2,
Max = 3,
}Expand description
An enum representing the level of verbosity for metrics/thread_spans/spans.
Variants
Min = 1
The “min” level.
Designates vey low details events, meaning overall lower frequency.
Med = 2
The “med” level.
Designates medium level level of details, meaning overall medium frequency
Max = 3
The “Max” level.
Designates very high frequency events.
Implementations
Sourceimpl Verbosity
impl Verbosity
Sourcepub fn to_level_filter(self) -> LodFilter
pub fn to_level_filter(self) -> LodFilter
Converts the Lod to the equivalent LodFilter.
Sourcepub fn as_str(self) -> &'static str
pub fn as_str(self) -> &'static str
Returns the string representation of the Lod.
This returns the same string as the fmt::Display implementation.
Sourcepub fn iter() -> impl Iterator<Item = Verbosity>
pub fn iter() -> impl Iterator<Item = Verbosity>
Iterate through all supported logging levels.
The order of iteration is from more severe to less severe log messages.
Examples
use micromegas_tracing::prelude::*;
let mut lods = Verbosity::iter();
assert_eq!(Some(Verbosity::Min), lods.next());
assert_eq!(Some(Verbosity::Max), lods.last());Trait Implementations
Sourceimpl Ord for Verbosity
impl Ord for Verbosity
Sourceimpl PartialOrd<LodFilter> for Verbosity
impl PartialOrd<LodFilter> for Verbosity
Sourceimpl PartialOrd<Verbosity> for LodFilter
impl PartialOrd<Verbosity> for LodFilter
Sourceimpl PartialOrd for Verbosity
impl PartialOrd for Verbosity
impl Copy for Verbosity
impl Eq for Verbosity
impl StructuralPartialEq for Verbosity