pub async fn delete_empty_processes_batch(
lake: &DataLakeConnection,
expiration: DateTime<Utc>,
) -> Result<bool, Error>Expand description
Deletes a batch of empty processes from the data lake.
Returns true if there are more processes to delete, false otherwise.