pub fn delete_expired_blocks_batch(
lake: &DataLakeConnection,
expiration: DateTime<Utc>,
) -> impl Future<Output = Result<bool, Error>>Expand description
Deletes a batch of expired blocks from the data lake.
Returns true if there are more blocks to delete, false otherwise.