pub async fn generate_process_jit_partitions(
config: &JitPartitionConfig,
lakehouse: Arc<LakehouseContext>,
blocks_view: &BlocksView,
query_time_range: &TimeRange,
process: Arc<ProcessMetadata>,
stream_tag: &str,
) -> Result<Vec<SourceDataBlocksInMemory>, Error>Expand description
generate_process_jit_partitions lists the partitions that are needed to cover a time span for a specific process these partitions may not exist or they could be out of date Generates JIT partitions for a given time range filtered by process.