pub async fn generate_stream_jit_partitions(
config: &JitPartitionConfig,
lakehouse: Arc<LakehouseContext>,
blocks_view: &BlocksView,
query_time_range: &TimeRange,
stream: Arc<StreamMetadata>,
process: Arc<ProcessMetadata>,
) -> Result<Vec<SourceDataBlocksInMemory>, Error>Expand description
generate_stream_jit_partitions lists the partitiions that are needed to cover a time span these partitions may not exist or they could be out of date Generates JIT partitions for a given time range.