pub struct ReaderFactory { /* private fields */ }Expand description
A custom [ParquetFileReaderFactory] that handles opening parquet files
from object storage, and loads metadata on-demand.
Metadata is cached globally across all readers and queries via a shared
MetadataCache, significantly reducing database fetches for repeated
queries on the same partitions.
File contents are cached via a shared FileCache with thundering herd
protection, reducing object storage reads for frequently accessed files.
Implementations
Sourceimpl ReaderFactory
impl ReaderFactory
Sourcepub fn new(
object_store: Arc<dyn ObjectStore>,
pool: Pool<Postgres>,
metadata_cache: Arc<MetadataCache>,
file_cache: Arc<FileCache>,
) -> ReaderFactory
pub fn new( object_store: Arc<dyn ObjectStore>, pool: Pool<Postgres>, metadata_cache: Arc<MetadataCache>, file_cache: Arc<FileCache>, ) -> ReaderFactory
Creates a new ReaderFactory with shared metadata and file caches.