pub fn get_thread_name_from_stream_metadata(
stream: &StreamMetadata,
) -> Result<String, Error>Expand description
Returns the thread name associated with the stream, if available. This function is only meaningful for streams associated with CPU threads. Returns format: “thread-name-thread-id” (e.g., “main-12345”) or just “thread-id” if no name.