pub struct PropertySet { /* private fields */ }Expand description
A set of properties, backed by a transit object.
Implementations
Sourceimpl PropertySet
impl PropertySet
pub fn new(obj: Arc<Object>) -> PropertySet
pub fn empty() -> PropertySet
Sourcepub fn for_each_property<Fun>(&self, fun: Fun) -> Result<(), Error>
pub fn for_each_property<Fun>(&self, fun: Fun) -> Result<(), Error>
Iterates over the properties in the set.
Sourcepub fn as_arc_object(&self) -> &Arc<Object>
pub fn as_arc_object(&self) -> &Arc<Object>
Get a reference to the underlying Arc<Object> for pointer-based operations.
This is used by custom dictionary builders for efficient deduplication based on Arc pointer addresses rather than content hashing.