pub async fn fetch_spans_batch(
client: &mut Client,
stream_id: &str,
frames_rb: RecordBatch,
group_by_config: &GroupBy,
) -> Result<Vec<RecordBatch>>Expand description
Fetches spans for a given stream and frames, grouped by the specified configuration.
This function queries the FlightSQL server for spans within the time range of the provided frames
and groups them according to the group_by_config.