pub async fn get_frames(
client: &mut Client,
stream_id: &str,
time_range: TimeRange,
top_level_span_name: &str,
) -> Result<Vec<RecordBatch>>Expand description
Retrieves frames for a given stream within a time range and top-level span name.
This function queries the thread_spans view to get the begin and end times
of spans that match the top_level_span_name within the specified time_range.