pub struct ProcessQueryBuilder { /* private fields */ }Expand description
Builder for creating process queries with various filters.
This builder allows you to construct queries to find processes based on various criteria like process ID, username, executable name, time ranges, and whether they contain CPU blocks or specific thread names.
Implementations
Sourceimpl ProcessQueryBuilder
impl ProcessQueryBuilder
Sourcepub fn with_process_id(self, process_id: &str) -> Self
pub fn with_process_id(self, process_id: &str) -> Self
Filters processes by exact process ID.
Sourcepub fn with_username(self, username: &str) -> Self
pub fn with_username(self, username: &str) -> Self
Filters processes by exact username.
Sourcepub fn since(self, begin: DateTime<Utc>) -> Self
pub fn since(self, begin: DateTime<Utc>) -> Self
Filters processes that ended at or after the given time.
Sourcepub fn until(self, end: DateTime<Utc>) -> Self
pub fn until(self, end: DateTime<Utc>) -> Self
Filters processes that began at or before the given time.
Sourcepub fn with_cpu_blocks(self) -> Self
pub fn with_cpu_blocks(self) -> Self
Filters processes that have CPU blocks (contain telemetry streams tagged with ‘cpu’).
Sourcepub fn with_thread_named(self, thread_name: &str) -> Self
pub fn with_thread_named(self, thread_name: &str) -> Self
Filters processes that have a thread with the specified name.
Sourcepub fn into_where(&self) -> String
pub fn into_where(&self) -> String
Converts the filters into a SQL WHERE clause.
Sourcepub async fn query(self, client: &mut Client) -> Result<Vec<RecordBatch>>
pub async fn query(self, client: &mut Client) -> Result<Vec<RecordBatch>>
Executes the query and returns the matching processes.
Returns a vector of RecordBatch containing process information including:
- process_id
- begin/end times
- exe (executable name)
- properties
- computer
- username
- cpu_brand
- distro