pub struct Stats {
pub num_total: Option<u64>,
pub num_failed: Option<u64>,
pub num_skipped: Option<u64>,
}Expand description
Stats are emitted only upon Flush() and are monotonic (i.e. they are absolute counters since the beginning of the lifetime of the tracing session and NOT relative to the previous Stats snapshot).
Fields
num_total: Option<u64>Total number of log events seen, including errors and skipped entries (num of events stored in the trace = total - failed - skipped).
num_failed: Option<u64>Parser failures.
num_skipped: Option<u64>Messages skipped due to filters.
Implementations
Sourceimpl Stats
impl Stats
Sourcepub fn num_total(&self) -> u64
pub fn num_total(&self) -> u64
Returns the value of num_total, or the default value if num_total is unset.
Sourcepub fn num_failed(&self) -> u64
pub fn num_failed(&self) -> u64
Returns the value of num_failed, or the default value if num_failed is unset.
Sourcepub fn num_skipped(&self) -> u64
pub fn num_skipped(&self) -> u64
Returns the value of num_skipped, or the default value if num_skipped is unset.