pub struct MajorState {
pub next_action: Option<i32>,
pub begin_impl_frame_state: Option<i32>,
pub begin_main_frame_state: Option<i32>,
pub layer_tree_frame_sink_state: Option<i32>,
pub forced_redraw_state: Option<i32>,
}Expand description
Next id: 6
Fields
next_action: Option<i32>begin_impl_frame_state: Option<i32>begin_main_frame_state: Option<i32>layer_tree_frame_sink_state: Option<i32>forced_redraw_state: Option<i32>Implementations
Sourceimpl MajorState
impl MajorState
Sourcepub fn next_action(&self) -> ChromeCompositorSchedulerAction
pub fn next_action(&self) -> ChromeCompositorSchedulerAction
Returns the enum value of next_action, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_next_action(&mut self, value: ChromeCompositorSchedulerAction)
pub fn set_next_action(&mut self, value: ChromeCompositorSchedulerAction)
Sets next_action to the provided enum value.
Sourcepub fn begin_impl_frame_state(&self) -> BeginImplFrameState
pub fn begin_impl_frame_state(&self) -> BeginImplFrameState
Returns the enum value of begin_impl_frame_state, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_begin_impl_frame_state(&mut self, value: BeginImplFrameState)
pub fn set_begin_impl_frame_state(&mut self, value: BeginImplFrameState)
Sets begin_impl_frame_state to the provided enum value.
Sourcepub fn begin_main_frame_state(&self) -> BeginMainFrameState
pub fn begin_main_frame_state(&self) -> BeginMainFrameState
Returns the enum value of begin_main_frame_state, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_begin_main_frame_state(&mut self, value: BeginMainFrameState)
pub fn set_begin_main_frame_state(&mut self, value: BeginMainFrameState)
Sets begin_main_frame_state to the provided enum value.
Sourcepub fn layer_tree_frame_sink_state(&self) -> LayerTreeFrameSinkState
pub fn layer_tree_frame_sink_state(&self) -> LayerTreeFrameSinkState
Returns the enum value of layer_tree_frame_sink_state, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_layer_tree_frame_sink_state(
&mut self,
value: LayerTreeFrameSinkState,
)
pub fn set_layer_tree_frame_sink_state( &mut self, value: LayerTreeFrameSinkState, )
Sets layer_tree_frame_sink_state to the provided enum value.
Sourcepub fn forced_redraw_state(&self) -> ForcedRedrawOnTimeoutState
pub fn forced_redraw_state(&self) -> ForcedRedrawOnTimeoutState
Returns the enum value of forced_redraw_state, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_forced_redraw_state(&mut self, value: ForcedRedrawOnTimeoutState)
pub fn set_forced_redraw_state(&mut self, value: ForcedRedrawOnTimeoutState)
Sets forced_redraw_state to the provided enum value.