pub struct CodeRange {
pub base_address: Option<u64>,
pub size: Option<u64>,
pub embedded_blob_code_copy_start_address: Option<u64>,
pub is_process_wide: Option<bool>,
}Expand description
A code range is a virtual memory cage that may contain executable code. Depending on the Isolate settings the Isolate might have one or not. See: https://source.chromium.org/chromium/chromium/src/+/main:v8/src/heap/code-range.h If the isolate defines code range this will be tracked here.
Fields
base_address: Option<u64>size: Option<u64>embedded_blob_code_copy_start_address: Option<u64>Used when short builtin calls are enabled, where embedded builtins are copied into the CodeRange so calls can be nearer.
is_process_wide: Option<bool>Whether this code range is shared with other Isolates in the same process
Implementations
Sourceimpl CodeRange
impl CodeRange
Sourcepub fn base_address(&self) -> u64
pub fn base_address(&self) -> u64
Returns the value of base_address, or the default value if base_address is unset.
Sourcepub fn embedded_blob_code_copy_start_address(&self) -> u64
pub fn embedded_blob_code_copy_start_address(&self) -> u64
Returns the value of embedded_blob_code_copy_start_address, or the default value if embedded_blob_code_copy_start_address is unset.
Sourcepub fn is_process_wide(&self) -> bool
pub fn is_process_wide(&self) -> bool
Returns the value of is_process_wide, or the default value if is_process_wide is unset.