HeapSample

Struct HeapSample 

pub struct HeapSample {
    pub callstack_id: Option<u64>,
    pub self_allocated: Option<u64>,
    pub self_freed: Option<u64>,
    pub self_max: Option<u64>,
    pub self_max_count: Option<u64>,
    pub timestamp: Option<u64>,
    pub alloc_count: Option<u64>,
    pub free_count: Option<u64>,
}
Next ID: 9

Fields

callstack_id: Option<u64>self_allocated: Option<u64>

bytes allocated at this callstack.

self_freed: Option<u64>

bytes allocated at this callstack that have been freed.

self_max: Option<u64>

Bytes allocated by this callstack but not freed at the time the malloc heap usage of this process was maximal. This is only set if dump_at_max is true in HeapprofdConfig. In that case, self_allocated, self_freed and self_idle will not be set.

self_max_count: Option<u64>

Number of allocations that were sampled at this callstack but not freed at the time the malloc heap usage of this process was maximal. This is only set if dump_at_max is true in HeapprofdConfig. In that case, self_allocated, self_freed and self_idle will not be set.

timestamp: Option<u64>

timestamp [opt]

alloc_count: Option<u64>

Number of allocations that were sampled at this callstack.

free_count: Option<u64>

Number of allocations that were sampled at this callstack that have been freed.

Implementations

Source

impl HeapSample

pub fn callstack_id(&self) -> u64

Returns the value of callstack_id, or the default value if callstack_id is unset.

pub fn self_allocated(&self) -> u64

Returns the value of self_allocated, or the default value if self_allocated is unset.

pub fn self_freed(&self) -> u64

Returns the value of self_freed, or the default value if self_freed is unset.

pub fn timestamp(&self) -> u64

Returns the value of timestamp, or the default value if timestamp is unset.

pub fn alloc_count(&self) -> u64

Returns the value of alloc_count, or the default value if alloc_count is unset.

pub fn free_count(&self) -> u64

Returns the value of free_count, or the default value if free_count is unset.

pub fn self_max(&self) -> u64

Returns the value of self_max, or the default value if self_max is unset.

pub fn self_max_count(&self) -> u64

Returns the value of self_max_count, or the default value if self_max_count is unset.