pub struct ChromeFrameReporter {Show 14 fields
pub state: Option<i32>,
pub reason: Option<i32>,
pub frame_source: Option<u64>,
pub frame_sequence: Option<u64>,
pub affects_smoothness: Option<bool>,
pub scroll_state: Option<i32>,
pub has_main_animation: Option<bool>,
pub has_compositor_animation: Option<bool>,
pub has_smooth_input_main: Option<bool>,
pub has_missing_content: Option<bool>,
pub layer_tree_host_id: Option<u64>,
pub has_high_latency: Option<bool>,
pub frame_type: Option<i32>,
pub high_latency_contribution_stage: Vec<String>,
}Fields
state: Option<i32>reason: Option<i32>The reason is set only if |state| is not |STATE_UPDATED_ALL|.
frame_source: Option<u64>frame_sequence: Option<u64>affects_smoothness: Option<bool>If this is a droped frame (i.e. if |state| is set to |STATE_DROPPED| or |STATE_PRESENTED_PARTIAL|), then indicates whether this frame impacts smoothness.
scroll_state: Option<i32>The type of active scroll.
has_main_animation: Option<bool>If any main thread animation is active during this frame.
has_compositor_animation: Option<bool>If any compositor thread animation is active during this frame.
has_smooth_input_main: Option<bool>If any touch-driven UX (not scroll) is active during this frame.
has_missing_content: Option<bool>Whether the frame contained any missing content (i.e. whether there was checkerboarding in the frame).
layer_tree_host_id: Option<u64>The id of layer_tree_host that the frame has been produced for.
has_high_latency: Option<bool>If total latency of PipelineReporter exceeds a certain limit.
frame_type: Option<i32>Indicate if the frame is “FORKED” (i.e. a PipelineReporter event starts at the same frame sequence as another PipelineReporter) or “BACKFILL” (i.e. dropped frames when there are no partial compositor updates).
high_latency_contribution_stage: Vec<String>The breakdown stage of PipelineReporter that is most likely accountable for high latency.
Implementations
Sourceimpl ChromeFrameReporter
impl ChromeFrameReporter
Sourcepub fn state(&self) -> State
pub fn state(&self) -> State
Returns the enum value of state, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn reason(&self) -> FrameDropReason
pub fn reason(&self) -> FrameDropReason
Returns the enum value of reason, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_reason(&mut self, value: FrameDropReason)
pub fn set_reason(&mut self, value: FrameDropReason)
Sets reason to the provided enum value.
Sourcepub fn frame_source(&self) -> u64
pub fn frame_source(&self) -> u64
Returns the value of frame_source, or the default value if frame_source is unset.
Sourcepub fn frame_sequence(&self) -> u64
pub fn frame_sequence(&self) -> u64
Returns the value of frame_sequence, or the default value if frame_sequence is unset.
Sourcepub fn affects_smoothness(&self) -> bool
pub fn affects_smoothness(&self) -> bool
Returns the value of affects_smoothness, or the default value if affects_smoothness is unset.
Sourcepub fn scroll_state(&self) -> ScrollState
pub fn scroll_state(&self) -> ScrollState
Returns the enum value of scroll_state, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_scroll_state(&mut self, value: ScrollState)
pub fn set_scroll_state(&mut self, value: ScrollState)
Sets scroll_state to the provided enum value.
Sourcepub fn has_main_animation(&self) -> bool
pub fn has_main_animation(&self) -> bool
Returns the value of has_main_animation, or the default value if has_main_animation is unset.
Sourcepub fn has_compositor_animation(&self) -> bool
pub fn has_compositor_animation(&self) -> bool
Returns the value of has_compositor_animation, or the default value if has_compositor_animation is unset.
Sourcepub fn has_smooth_input_main(&self) -> bool
pub fn has_smooth_input_main(&self) -> bool
Returns the value of has_smooth_input_main, or the default value if has_smooth_input_main is unset.
Sourcepub fn has_missing_content(&self) -> bool
pub fn has_missing_content(&self) -> bool
Returns the value of has_missing_content, or the default value if has_missing_content is unset.
Sourcepub fn layer_tree_host_id(&self) -> u64
pub fn layer_tree_host_id(&self) -> u64
Returns the value of layer_tree_host_id, or the default value if layer_tree_host_id is unset.
Sourcepub fn has_high_latency(&self) -> bool
pub fn has_high_latency(&self) -> bool
Returns the value of has_high_latency, or the default value if has_high_latency is unset.
Sourcepub fn frame_type(&self) -> FrameType
pub fn frame_type(&self) -> FrameType
Returns the enum value of frame_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_frame_type(&mut self, value: FrameType)
pub fn set_frame_type(&mut self, value: FrameType)
Sets frame_type to the provided enum value.