pub struct Ext4RequestBlocksFtraceEvent {
pub dev: Option<u64>,
pub ino: Option<u64>,
pub len: Option<u32>,
pub logical: Option<u32>,
pub lleft: Option<u32>,
pub lright: Option<u32>,
pub goal: Option<u64>,
pub pleft: Option<u64>,
pub pright: Option<u64>,
pub flags: Option<u32>,
}Fields
dev: Option<u64>ino: Option<u64>len: Option<u32>logical: Option<u32>lleft: Option<u32>lright: Option<u32>goal: Option<u64>pleft: Option<u64>pright: Option<u64>flags: Option<u32>Implementations
Sourceimpl Ext4RequestBlocksFtraceEvent
impl Ext4RequestBlocksFtraceEvent
Sourcepub fn logical(&self) -> u32
pub fn logical(&self) -> u32
Returns the value of logical, or the default value if logical is unset.
Sourcepub fn lright(&self) -> u32
pub fn lright(&self) -> u32
Returns the value of lright, or the default value if lright is unset.