F2fsGcBeginFtraceEvent

Struct F2fsGcBeginFtraceEvent 

pub struct F2fsGcBeginFtraceEvent {
Show 13 fields pub dev: Option<u64>, pub sync: Option<u32>, pub background: Option<u32>, pub dirty_nodes: Option<i64>, pub dirty_dents: Option<i64>, pub dirty_imeta: Option<i64>, pub free_sec: Option<u32>, pub free_seg: Option<u32>, pub reserved_seg: Option<i32>, pub prefree_seg: Option<u32>, pub gc_type: Option<i32>, pub no_bg_gc: Option<u32>, pub nr_free_secs: Option<u32>,
}

Fields

dev: Option<u64>sync: Option<u32>background: Option<u32>dirty_nodes: Option<i64>dirty_dents: Option<i64>dirty_imeta: Option<i64>free_sec: Option<u32>free_seg: Option<u32>reserved_seg: Option<i32>prefree_seg: Option<u32>gc_type: Option<i32>no_bg_gc: Option<u32>nr_free_secs: Option<u32>

Implementations

Source

impl F2fsGcBeginFtraceEvent

pub fn dev(&self) -> u64

Returns the value of dev, or the default value if dev is unset.

pub fn sync(&self) -> u32

Returns the value of sync, or the default value if sync is unset.

pub fn background(&self) -> u32

Returns the value of background, or the default value if background is unset.

pub fn dirty_nodes(&self) -> i64

Returns the value of dirty_nodes, or the default value if dirty_nodes is unset.

pub fn dirty_dents(&self) -> i64

Returns the value of dirty_dents, or the default value if dirty_dents is unset.

pub fn dirty_imeta(&self) -> i64

Returns the value of dirty_imeta, or the default value if dirty_imeta is unset.

pub fn free_sec(&self) -> u32

Returns the value of free_sec, or the default value if free_sec is unset.

pub fn free_seg(&self) -> u32

Returns the value of free_seg, or the default value if free_seg is unset.

pub fn reserved_seg(&self) -> i32

Returns the value of reserved_seg, or the default value if reserved_seg is unset.

pub fn prefree_seg(&self) -> u32

Returns the value of prefree_seg, or the default value if prefree_seg is unset.

pub fn gc_type(&self) -> i32

Returns the value of gc_type, or the default value if gc_type is unset.

pub fn no_bg_gc(&self) -> u32

Returns the value of no_bg_gc, or the default value if no_bg_gc is unset.

pub fn nr_free_secs(&self) -> u32

Returns the value of nr_free_secs, or the default value if nr_free_secs is unset.