pub struct FtraceEventBundle {
pub cpu: Option<u32>,
pub event: Vec<FtraceEvent>,
pub lost_events: Option<bool>,
pub compact_sched: Option<CompactSched>,
pub ftrace_clock: Option<i32>,
pub ftrace_timestamp: Option<i64>,
pub boot_timestamp: Option<i64>,
pub error: Vec<FtraceError>,
pub last_read_event_timestamp: Option<u64>,
}Expand description
The result of tracing one or more ftrace data pages from a single per-cpu kernel ring buffer. If collating multiple pages’ worth of events, all of them come from contiguous pages, with no kernel data loss in between.
Fields
cpu: Option<u32>event: Vec<FtraceEvent>lost_events: Option<bool>Set to true if there was data loss between the last time we’ve read from the corresponding per-cpu kernel buffer, and the earliest event recorded in this bundle.
compact_sched: Option<CompactSched>ftrace_clock: Option<i32>traced_probes always sets the ftrace_clock to “boot”. That is not available in older kernels (v3.x). In that case we fallback on “global” or “local”. When we do that, we report the fallback clock in each bundle so we can do proper clock syncing at parsing time in TraceProcessor. We cannot use the TracePacket timestamp_clock_id because: (1) there is no per-packet timestamp for ftrace bundles; (2) “global” does not match CLOCK_MONOTONIC. Having a dedicated and explicit flag allows us to correct further misakes in future by looking at the kernel version. This field has been introduced in perfetto v19 / Android T (13). This field is omitted when the ftrace clock is just “boot”, as that is the default assumption (and for consistency with the past).
ftrace_timestamp: Option<i64>The timestamp according to the ftrace clock, taken at the same instant as |boot_timestamp|. This is used to sync ftrace events when a non-boot clock is used as the ftrace clock. We don’t use the ClockSnapshot packet because the ftrace global/local clocks don’t match any of the clock_gettime domains and can be only read by traced_probes.
Only set when |ftrace_clock| != FTRACE_CLOCK_UNSPECIFIED.
Implementation note: Populated by reading the ‘now ts:’ field in tracefs/per_cpu/cpuX/stat.
boot_timestamp: Option<i64>The timestamp according to CLOCK_BOOTTIME, taken at the same instant as |ftrace_timestamp|. See documentation of |ftrace_timestamp| for more info.
Only set when |ftrace_clock| != FTRACE_CLOCK_UNSPECIFIED.
error: Vec<FtraceError>last_read_event_timestamp: Option<u64>The timestamp (ftrace clock) of the last event consumed from this per-cpu kernel buffer prior to starting this bundle. In other words: the last event in the previous bundle. Lets the trace processing find an initial timestamp after which ftrace data is known to be valid across all cpus. Of particular importance when the perfetto trace buffer is a ring buffer as well, as the overwriting of oldest bundles can skew the first valid timestamp per cpu significantly. Added in: perfetto v44.
Implementations
Sourceimpl FtraceEventBundle
impl FtraceEventBundle
Sourcepub fn lost_events(&self) -> bool
pub fn lost_events(&self) -> bool
Returns the value of lost_events, or the default value if lost_events is unset.
Sourcepub fn ftrace_clock(&self) -> FtraceClock
pub fn ftrace_clock(&self) -> FtraceClock
Returns the enum value of ftrace_clock, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_ftrace_clock(&mut self, value: FtraceClock)
pub fn set_ftrace_clock(&mut self, value: FtraceClock)
Sets ftrace_clock to the provided enum value.
Sourcepub fn ftrace_timestamp(&self) -> i64
pub fn ftrace_timestamp(&self) -> i64
Returns the value of ftrace_timestamp, or the default value if ftrace_timestamp is unset.
Sourcepub fn boot_timestamp(&self) -> i64
pub fn boot_timestamp(&self) -> i64
Returns the value of boot_timestamp, or the default value if boot_timestamp is unset.
Sourcepub fn last_read_event_timestamp(&self) -> u64
pub fn last_read_event_timestamp(&self) -> u64
Returns the value of last_read_event_timestamp, or the default value if last_read_event_timestamp is unset.