MmCompactionEndFtraceEvent

Struct MmCompactionEndFtraceEvent 

pub struct MmCompactionEndFtraceEvent {
    pub zone_start: Option<u64>,
    pub migrate_pfn: Option<u64>,
    pub free_pfn: Option<u64>,
    pub zone_end: Option<u64>,
    pub sync: Option<u32>,
    pub status: Option<i32>,
}

Fields

zone_start: Option<u64>migrate_pfn: Option<u64>free_pfn: Option<u64>zone_end: Option<u64>sync: Option<u32>status: Option<i32>

Implementations

Source

impl MmCompactionEndFtraceEvent

pub fn zone_start(&self) -> u64

Returns the value of zone_start, or the default value if zone_start is unset.

pub fn migrate_pfn(&self) -> u64

Returns the value of migrate_pfn, or the default value if migrate_pfn is unset.

pub fn free_pfn(&self) -> u64

Returns the value of free_pfn, or the default value if free_pfn is unset.

pub fn zone_end(&self) -> u64

Returns the value of zone_end, or the default value if zone_end is unset.

pub fn sync(&self) -> u32

Returns the value of sync, or the default value if sync is unset.

pub fn status(&self) -> i32

Returns the value of status, or the default value if status is unset.