pub struct SchedCpuUtilCfsFtraceEvent {Show 15 fields
pub active: Option<i32>,
pub capacity: Option<u64>,
pub capacity_orig: Option<u64>,
pub cpu: Option<u32>,
pub cpu_importance: Option<u64>,
pub cpu_util: Option<u64>,
pub exit_lat: Option<u32>,
pub group_capacity: Option<u64>,
pub grp_overutilized: Option<u32>,
pub idle_cpu: Option<u32>,
pub nr_running: Option<u32>,
pub spare_cap: Option<i64>,
pub task_fits: Option<u32>,
pub wake_group_util: Option<u64>,
pub wake_util: Option<u64>,
}Fields
active: Option<i32>capacity: Option<u64>capacity_orig: Option<u64>cpu: Option<u32>cpu_importance: Option<u64>cpu_util: Option<u64>exit_lat: Option<u32>group_capacity: Option<u64>grp_overutilized: Option<u32>idle_cpu: Option<u32>nr_running: Option<u32>spare_cap: Option<i64>task_fits: Option<u32>wake_group_util: Option<u64>wake_util: Option<u64>Implementations
Sourceimpl SchedCpuUtilCfsFtraceEvent
impl SchedCpuUtilCfsFtraceEvent
Sourcepub fn active(&self) -> i32
pub fn active(&self) -> i32
Returns the value of active, or the default value if active is unset.
Sourcepub fn capacity(&self) -> u64
pub fn capacity(&self) -> u64
Returns the value of capacity, or the default value if capacity is unset.
Sourcepub fn capacity_orig(&self) -> u64
pub fn capacity_orig(&self) -> u64
Returns the value of capacity_orig, or the default value if capacity_orig is unset.
Sourcepub fn cpu_importance(&self) -> u64
pub fn cpu_importance(&self) -> u64
Returns the value of cpu_importance, or the default value if cpu_importance is unset.
Sourcepub fn cpu_util(&self) -> u64
pub fn cpu_util(&self) -> u64
Returns the value of cpu_util, or the default value if cpu_util is unset.
Sourcepub fn exit_lat(&self) -> u32
pub fn exit_lat(&self) -> u32
Returns the value of exit_lat, or the default value if exit_lat is unset.
Sourcepub fn group_capacity(&self) -> u64
pub fn group_capacity(&self) -> u64
Returns the value of group_capacity, or the default value if group_capacity is unset.
Sourcepub fn grp_overutilized(&self) -> u32
pub fn grp_overutilized(&self) -> u32
Returns the value of grp_overutilized, or the default value if grp_overutilized is unset.
Sourcepub fn idle_cpu(&self) -> u32
pub fn idle_cpu(&self) -> u32
Returns the value of idle_cpu, or the default value if idle_cpu is unset.
Sourcepub fn nr_running(&self) -> u32
pub fn nr_running(&self) -> u32
Returns the value of nr_running, or the default value if nr_running is unset.
Sourcepub fn spare_cap(&self) -> i64
pub fn spare_cap(&self) -> i64
Returns the value of spare_cap, or the default value if spare_cap is unset.
Sourcepub fn task_fits(&self) -> u32
pub fn task_fits(&self) -> u32
Returns the value of task_fits, or the default value if task_fits is unset.
Sourcepub fn wake_group_util(&self) -> u64
pub fn wake_group_util(&self) -> u64
Returns the value of wake_group_util, or the default value if wake_group_util is unset.