pub struct GuardrailOverrides {
pub max_upload_per_day_bytes: Option<u64>,
pub max_tracing_buffer_size_kb: Option<u32>,
}Expand description
Contains flags which override the default values of the guardrails inside Perfetto.
Fields
max_upload_per_day_bytes: Option<u64>👎Deprecated
Override the default limit (in bytes) for uploading data to server within a 24 hour period. On R-, this override only affected userdebug builds. Since S, it also affects user builds. In 24Q3+ (V+), this override is a noop because upload guardrail logic was removed from Perfetto.
max_tracing_buffer_size_kb: Option<u32>Overrides the guardrail for maximum trace buffer size. Available on U+
Implementations
Sourceimpl GuardrailOverrides
impl GuardrailOverrides
Sourcepub fn max_upload_per_day_bytes(&self) -> u64
pub fn max_upload_per_day_bytes(&self) -> u64
Returns the value of max_upload_per_day_bytes, or the default value if max_upload_per_day_bytes is unset.
Sourcepub fn max_tracing_buffer_size_kb(&self) -> u32
pub fn max_tracing_buffer_size_kb(&self) -> u32
Returns the value of max_tracing_buffer_size_kb, or the default value if max_tracing_buffer_size_kb is unset.