pub struct StatsdMetadata {
pub triggering_alert_id: Option<i64>,
pub triggering_config_uid: Option<i32>,
pub triggering_config_id: Option<i64>,
pub triggering_subscription_id: Option<i64>,
}Expand description
Contains statsd-specific metadata about an alert associated with the trace.
Fields
triggering_alert_id: Option<i64>The identifier of the alert which triggered this trace.
triggering_config_uid: Option<i32>The uid which registered the triggering configuration with statsd.
triggering_config_id: Option<i64>The identifier of the config which triggered the alert.
triggering_subscription_id: Option<i64>The identifier of the subscription which triggered this trace.
Implementations
Sourceimpl StatsdMetadata
impl StatsdMetadata
Sourcepub fn triggering_alert_id(&self) -> i64
pub fn triggering_alert_id(&self) -> i64
Returns the value of triggering_alert_id, or the default value if triggering_alert_id is unset.
Sourcepub fn triggering_config_uid(&self) -> i32
pub fn triggering_config_uid(&self) -> i32
Returns the value of triggering_config_uid, or the default value if triggering_config_uid is unset.
Sourcepub fn triggering_config_id(&self) -> i64
pub fn triggering_config_id(&self) -> i64
Returns the value of triggering_config_id, or the default value if triggering_config_id is unset.
Sourcepub fn triggering_subscription_id(&self) -> i64
pub fn triggering_subscription_id(&self) -> i64
Returns the value of triggering_subscription_id, or the default value if triggering_subscription_id is unset.