pub enum EventType {
TracingStarted(bool),
AllDataSourcesStarted(bool),
AllDataSourcesFlushed(bool),
ReadTracingBuffersCompleted(bool),
TracingDisabled(bool),
SeizedForBugreport(bool),
}Expand description
When each of the following booleans are set to true, they report the point in time (through TracePacket’s timestamp) where the condition they describe happened. The order of the booleans below matches the timestamp ordering they would generally be expected to have.
Variants
TracingStarted(bool)
Emitted when we start tracing and specifically, this will be before any producer is notified about the existence of this trace. This is always emitted before the all_data_sources_started event. This event is also guaranteed to be seen (byte-offset wise) before any data packets from producers.
AllDataSourcesStarted(bool)
Emitted after all data sources saw the start event and ACKed it. This identifies the point in time when it’s safe to assume that all data sources have been recording events.
AllDataSourcesFlushed(bool)
Emitted when all data sources have been flushed successfully or with an error (including timeouts). This can generally happen many times over the course of the trace.
ReadTracingBuffersCompleted(bool)
Emitted when reading back the central tracing buffers has been completed. If |write_into_file| is specified, this can happen many times over the course of the trace.
TracingDisabled(bool)
Emitted after tracing has been disabled and specifically, this will be after all packets from producers have been included in the central tracing buffer.
SeizedForBugreport(bool)
Emitted if perfetto –save-for-bugreport was invoked while the current tracing session was running and it had the highest bugreport_score. In this case the original consumer will see a nearly empty trace, because the contents are routed onto the bugreport file. This event flags the situation explicitly. Traces that contain this marker should be discarded by test infrastructures / pipelines. Deprecated since Android U, where –save-for-bugreport uses non-destructive cloning.
Implementations
Sourceimpl EventType
impl EventType
Sourcepub fn merge(
field: &mut Option<EventType>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<EventType>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.