#[repr(i32)]pub enum Type {
Unspecified = 0,
SliceBegin = 1,
SliceEnd = 2,
Instant = 3,
Counter = 4,
}Expand description
Type of the TrackEvent (required if |phase| in LegacyEvent is not set).
Variants
Unspecified = 0
SliceBegin = 1
Slice events are events that have a begin and end timestamp, i.e. a duration. They can be nested similar to a callstack: If, on the same track, event B begins after event A, but before A ends, B is a child event of A and will be drawn as a nested event underneath A in the UI. Note that child events should always end before their parents (e.g. B before A).
Each slice event is formed by a pair of BEGIN + END events. The END event does not need to repeat any TrackEvent fields it has in common with its corresponding BEGIN event. Arguments and debug annotations of the BEGIN + END pair will be merged during trace import.
Note that we deliberately chose not to support COMPLETE events (which would specify a duration directly) since clients would need to delay writing them until the slice is completed, which can result in reordered events in the trace and loss of unfinished events at the end of a trace.
SliceEnd = 2
Instant = 3
Instant events are nestable events without duration. They can be children of slice events on the same track.
Counter = 4
Event that provides a value for a counter track. |track_uuid| should refer to a counter track and |counter_value| set to the new value. Note that most other TrackEvent fields (e.g. categories, name, ..) are not supported for TYPE_COUNTER events. See also CounterDescriptor.
Implementations
Sourceimpl Type
impl Type
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Type>
pub fn from_str_name(value: &str) -> Option<Type>
Creates an enum from field names used in the ProtoBuf definition.