pub async fn check_auth(
req: Request<()>,
auth_provider: &Arc<dyn AuthProvider>,
) -> Result<Request<()>, Status>Expand description
Checks the authentication of a Tonic request using an AuthProvider.
This function extracts request parts from the gRPC metadata and validates them using the provided authentication provider.