pub struct BlobStorage { /* private fields */ }Expand description
A client for interacting with blob storage.
This struct wraps an ObjectStore and prefixes all paths with a root path,
providing a convenient way to interact with a specific “folder” within the blob storage.
Implementations
Sourceimpl BlobStorage
impl BlobStorage
Sourcepub fn new(
blob_store: Arc<dyn ObjectStore>,
blob_store_root: Path,
) -> BlobStorage
pub fn new( blob_store: Arc<dyn ObjectStore>, blob_store_root: Path, ) -> BlobStorage
Creates a new BlobStorage instance.
Sourcepub fn connect(object_store_url: &str) -> Result<BlobStorage, Error>
pub fn connect(object_store_url: &str) -> Result<BlobStorage, Error>
Connects to a blob storage service using the provided URL.
Sourcepub fn inner(&self) -> Arc<dyn ObjectStore>
pub fn inner(&self) -> Arc<dyn ObjectStore>
Returns a shared reference to the inner ObjectStore.
Sourcepub async fn put(&self, obj_path: &str, buffer: Bytes) -> Result<(), Error>
pub async fn put(&self, obj_path: &str, buffer: Bytes) -> Result<(), Error>
Puts a blob into storage at the specified path.
Sourcepub async fn read_blob(&self, obj_path: &str) -> Result<Bytes, Error>
pub async fn read_blob(&self, obj_path: &str) -> Result<Bytes, Error>
Reads a blob from storage at the specified path.