pub fn install_tracing_interop(interop_max_level_override: Option<LevelFilter>)Expand description
Installs a tracing layer that forwards events to the Micromegas tracing system.
This allows applications using the tracing crate to integrate with Micromegas telemetry.
Arguments
interop_max_level_override- An optionalLevelFilterto override the maximum level for thetracinglayer. IfNone, the global Micromegas max level is used.