macro_rules! span_scope_named {
($static_var_name:ident, $name:expr) => { ... };
($name:expr) => { ... };
}Expand description
Records a span with a name that is determined at runtime. The span name still needs to be statically allocated.
Examples
use micromegas_tracing::span_scope_named;
span_scope_named!(get_name());